@@ -35,7 +35,7 @@ namespace pappso
 {
 
 /**
- * @brief
+ * @brief convert  a list of mass to amino acid string codes
  */
 class PMSPP_LIB_DECL AaStringCodeMassMatching
 {
@@ -59,6 +59,8 @@ class PMSPP_LIB_DECL AaStringCodeMassMatching
    */
   ~AaStringCodeMassMatching();
 
+  PrecisionPtr getPrecisionPtr() const;
+
 
   /** @brief get amino acid string code from mass delta list
    * mass delta is a list of masses differences found in a spectrum
@@ -67,6 +69,24 @@ class PMSPP_LIB_DECL AaStringCodeMassMatching
   std::vector<uint32_t>
   getAaCodeFromMassList(std::vector<double> &mass_list) const;
 
+
+  /** @brief get amino acid string code from a single mass delta
+   * @param mass the mass to look for
+   */
+  std::vector<uint32_t> getAaCodeFromMass(double mass) const;
+
+
+  /** @brief get amino acid string code from a single mass delta wearing a
+   * specific modification
+   * @param mass the mass to look for
+   * @param aa amino acid with modification
+   * @param quantifier the minimum number of this aa modified required in the
+   * given aa sequence
+   */
+  std::vector<uint32_t> getAaCodeFromMassWearingModification(
+    double mass, const Aa &aa, int quantifier) const;
+
+
   /** @brief filter a list of amino acid string code
    * find elementary amino acids (one base only) in the list and retrieve 2 or
    * more amino acid string containing only basic aminio acid found
@@ -74,6 +94,7 @@ class PMSPP_LIB_DECL AaStringCodeMassMatching
   std::vector<uint32_t> filterCodeList(std::vector<uint32_t> &code_list) const;
 
   private:
+  PrecisionPtr m_precision = nullptr;
   const AaCode &m_aaCode;
 
   AaStringCodec m_aaCodec;
