@@ -34,4 +34,31 @@ class FastaHandlerInterface
   virtual void setSequence(const QString &description,
                            const QString &sequence) = 0;
 };
+
+
+class FastaSeqHandler : public pappso::FastaHandlerInterface
+{
+  public:
+  const QString &
+  getDescription() const
+  {
+    return description;
+  };
+  const QString &
+  getSequence() const
+  {
+    return sequence;
+  };
+  void
+  setSequence(const QString &description_in,
+              const QString &sequence_in) override
+  {
+    description = description_in;
+    sequence    = sequence_in;
+  };
+
+  private:
+  QString description;
+  QString sequence;
+};
 } // namespace pappso
