@@ -47,17 +47,15 @@ typedef std::shared_ptr<const QualifiedMassSpectrum>
 enum class QualifiedMassSpectrumParameter
 {
 
-  TimsIonMobScanOneOverK0, ///< 1/kO of a simple scan
-  TimsFrameIonMobOneOverK0Begin, ///< Bruker's timsTOF frame's 1/K0 range's
-                                 ///< begin value
-  TimsFrameIonMobOneOverK0End,   ///< Bruker's timsTOF frame's 1/K0 range's end
-                                 ///< value
+  IonMobOneOverK0,      ///< 1/kO value
+  IonMobOneOverK0Begin, ///< 1/K0 range's begin value
+  IonMobOneOverK0End,   ///< 1/K0 range's end value
 
   TimsIonMobScanIndex,
   TimsFrameIonMobScanIndexBegin,
   TimsFrameIonMobScanIndexEnd,
 
-  IsolationMz,      ///< isolation m/z value
+  IsolationMz,      ///< Isolation m/z value
   IsolationMzWidth, ///< m/z isolation window width (left + right)
 
   CollisionEnergy,      ///< Bruker's timsTOF collision energy
@@ -67,7 +65,7 @@ enum class QualifiedMassSpectrumParameter
   TimsFrameMzIndexBegin, ///< Bruker's timsTOF mz index frame start range
   TimsFrameMzIndexEnd,   ///< Bruker's timsTOF mz index frame end range
 
-  ScanNumber, ///< scan number: Ordinal number of the scan indicating its order
+  ScanNumber, ///< Scan number: Ordinal number of the scan indicating its order
               ///< of acquisition within a mass spectrometry acquisition run.
               ///< MS_scan_number = 1003057,
   last
