@@ -21,6 +21,7 @@
 #include "../msrun/private/pwizmsrunreader.h"
 #include "../msrun/private/timsmsrunreader.h"
 #include "../msrun/private/timsmsrunreaderms2.h"
+#include "../msrun/private/timsmsrunreaderdia.h"
 #include "../msrun/bafasciimsrunreader.h"
 #include "../msrun/xymsrunreader.h"
 
@@ -446,6 +447,13 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 
       return std::make_shared<TimsMsRunReaderMs2>(ms_run_id);
     }
+  else if(getpreferredFileReaderType(m_fileFormat) == FileReaderType::tims_dia)
+    {
+      // qDebug() << "Returning a TimsMsRunReaderMs2.";
+
+      //qInfo() << "std::make_shared<TimsMsRunReaderDia>(ms_run_id);";
+      return std::make_shared<TimsMsRunReaderDia>(ms_run_id);
+    }
   else if(getpreferredFileReaderType(m_fileFormat) == FileReaderType::bafascii)
     {
       // qDebug() << "Returning a BafAsciiMsRunReader.";
