@@ -9,6 +9,7 @@
 #include "../msrun/msrunreader.h"
 #include "../msrun/msrunid.h"
 #include "../exportinmportconfig.h"
+#include "../obo/obopsimodterm.h"
 
 
 namespace pappso
@@ -34,7 +35,19 @@ class PMSPP_LIB_DECL MsFileAccessor
 
   /** @brief get the raw format of mz data
    */
-  MzFormat getFileFormat() const;
+  MsDataFormat getFileFormat() const;
+
+
+  /** @brief get OboPsiModTerm corresponding to the raw format of mz data
+   */
+  const OboPsiModTerm getOboPsiModTermFileFormat() const;
+
+
+  /** @brief get OboPsiModTerm corresponding to the nativeID format format of mz
+   * data
+   */
+  const OboPsiModTerm &getOboPsiModTermNativeIDFormat() const;
+
 
   /** @brief get the file reader type
    */
@@ -42,19 +55,19 @@ class PMSPP_LIB_DECL MsFileAccessor
 
   /** @brief given an mz format, explicitly set the preferred reader
    */
-  void setPreferredFileReaderType(MzFormat format, FileReaderType reader_type);
-  FileReaderType getpreferredFileReaderType(MzFormat format);
+  void setPreferredFileReaderType(MsDataFormat format,
+                                  FileReaderType reader_type);
+  FileReaderType getpreferredFileReaderType(MsDataFormat format);
 
   std::vector<MsRunIdCstSPtr> getMsRunIds();
-  
-   void setSelectedMsRunIdIndex(std::size_t index);
-  std::size_t getSelectedMsRunIdIndex() const;
-  MsRunIdCstSPtr getSelectedMsRunId();
-  
+
+  void setSelectedMsRunId(MsRunIdCstSPtr ms_run_id_csp);
+  MsRunIdCstSPtr getSelectedMsRunId() const;
+
   MsRunReaderSPtr msRunReaderSPtr(MsRunIdCstSPtr ms_run_id);
   MsRunReaderSPtr msRunReaderSPtr(std::size_t ms_run_id_index);
-  MsRunReaderSPtr msRunReaderSPtrForSelectedMsRunIdIndex();
-  
+  MsRunReaderSPtr msRunReaderSPtrForSelectedMsRunId();
+
   /** @brief get an msrun reader by finding the run_id in file
    *
    * @param run_id identifier within file of the MSrun
@@ -99,14 +112,16 @@ class PMSPP_LIB_DECL MsFileAccessor
   // need this prefix to craft unabiguous ms run ids.
   const QString m_xmlPrefix;
 
-  MzFormat m_fileFormat = MzFormat::unknown;
+  MsDataFormat m_fileFormat = MsDataFormat::unknown;
 
   // Type of the file reader that could load the file.
   FileReaderType m_fileReaderType;
 
-  std::map<MzFormat, FileReaderType> m_preferredFileReaderTypeMap;
-  
-  std::size_t m_selectedMsRunIdIndex;
+  std::map<MsDataFormat, FileReaderType> m_preferredFileReaderTypeMap;
+
+  MsRunIdCstSPtr mcsp_selectedMsRunId = nullptr;
+
+  OboPsiModTerm m_oboPsiModTermNativeIDFormat;
 };
 
 typedef std::shared_ptr<MsFileAccessor> MsFileAccessorSPtr;
