@@ -14,13 +14,13 @@ class MsFileReader
 {
   protected:
   QString m_fileName;
-  MzFormat m_fileFormat = MzFormat::unknown;
+  MsDataFormat m_fileFormat = MsDataFormat::unknown;
 
   public:
   MsFileReader(const QString &file_name);
   virtual ~MsFileReader();
 
-  virtual MzFormat getFileFormat() = 0;
+  virtual MsDataFormat getFileFormat() = 0;
 
   virtual std::vector<MsRunIdCstSPtr>
   getMsRunIds(const QString &run_prefix) = 0;
