@@ -34,63 +34,64 @@
 using namespace pappso;
 
 const QString
-pappso::MzFormatEnumStr::toString(pappso::MzFormat mz_format_enum)
+pappso::MsDataFormatEnumStr::toString(pappso::MsDataFormat ms_data_format_enum)
 {
 
-  QString mz_format_str;
-  switch(mz_format_enum)
+  QString ms_data_format_str;
+  switch(ms_data_format_enum)
     {
-      case MzFormat::abSciexT2D:
-        mz_format_str = "abSciexT2D";
+      case MsDataFormat::abSciexT2D:
+        ms_data_format_str = "abSciexT2D";
         break;
-      case MzFormat::abSciexWiff:
-        mz_format_str = "abSciexWiff";
+      case MsDataFormat::abSciexWiff:
+        ms_data_format_str = "abSciexWiff";
         break;
-      case MzFormat::agilentMassHunter:
-        mz_format_str = "agilentMassHunter";
+      case MsDataFormat::agilentMassHunter:
+        ms_data_format_str = "agilentMassHunter";
         break;
-      case MzFormat::brukerBaf:
-        mz_format_str = "brukerBaf";
+      case MsDataFormat::brukerBaf:
+        ms_data_format_str = "brukerBaf";
         break;
-      case MzFormat::brukerFid:
-        mz_format_str = "brukerFid";
+      case MsDataFormat::brukerFid:
+        ms_data_format_str = "brukerFid";
         break;
-      case MzFormat::brukerTims:
-        mz_format_str = "brukerTims";
+      case MsDataFormat::brukerTims:
+        ms_data_format_str = "brukerTims";
         break;
-      case MzFormat::brukerYep:
-        mz_format_str = "brukerYep";
+      case MsDataFormat::brukerYep:
+        ms_data_format_str = "brukerYep";
         break;
-      case MzFormat::MGF:
-        mz_format_str = "MGF";
+      case MsDataFormat::MGF:
+        ms_data_format_str = "MGF";
         break;
-      case MzFormat::msn:
-        mz_format_str = "msn";
+      case MsDataFormat::msn:
+        ms_data_format_str = "msn";
         break;
-      case MzFormat::mz5:
-        mz_format_str = "mz5";
+      case MsDataFormat::mz5:
+        ms_data_format_str = "mz5";
         break;
-      case MzFormat::mzML:
-        mz_format_str = "mzML";
+      case MsDataFormat::mzML:
+        ms_data_format_str = "mzML";
         break;
-      case MzFormat::mzXML:
-        mz_format_str = "mzXML";
+      case MsDataFormat::mzXML:
+        ms_data_format_str = "mzXML";
         break;
-      case MzFormat::SQLite3:
-        mz_format_str = "SQLite3";
+      case MsDataFormat::SQLite3:
+        ms_data_format_str = "SQLite3";
         break;
-      case MzFormat::thermoRaw:
-        mz_format_str = "thermoRaw";
+      case MsDataFormat::thermoRaw:
+        ms_data_format_str = "thermoRaw";
         break;
-      case MzFormat::watersRaw:
-        mz_format_str = "watersRaw";
+      case MsDataFormat::watersRaw:
+        ms_data_format_str = "watersRaw";
         break;
-      case MzFormat::xy:
-        mz_format_str = "xy";
+      case MsDataFormat::xy:
+        ms_data_format_str = "xy";
         break;
       default:
-        throw pappso::PappsoException(QObject::tr("MzFormat unknown :\n%1")
-                                        .arg((std::uint8_t)mz_format_enum));
+        throw pappso::PappsoException(
+          QObject::tr("MsDataFormat unknown :\n%1")
+            .arg((std::uint8_t)ms_data_format_enum));
     }
-  return mz_format_str;
+  return ms_data_format_str;
 }
