@@ -43,6 +43,7 @@ PwizMsFileReader::initialize()
   std::string readerName;
   try
     {
+      qDebug() << m_fileName;
       readerName = defaultReaderList.identify(m_fileName.toStdString());
     }
   catch(std::runtime_error &error)
@@ -79,36 +80,36 @@ PwizMsFileReader::initialize()
       return 0;
     }
 
-  // Now convert the string to MzFormat.
+  // Now convert the string to MsDataFormat.
   if(readerName == "mzML")
-    m_fileFormat = MzFormat::mzML;
+    m_fileFormat = MsDataFormat::mzML;
   else if(readerName == "mzXML")
-    m_fileFormat = MzFormat::mzXML;
+    m_fileFormat = MsDataFormat::mzXML;
   else if(readerName == "Mascot Generic")
-    m_fileFormat = MzFormat::MGF;
+    m_fileFormat = MsDataFormat::MGF;
   else if(readerName == "MZ5")
-    m_fileFormat = MzFormat::mz5;
+    m_fileFormat = MsDataFormat::mz5;
   else if(readerName == "MSn")
-    m_fileFormat = MzFormat::msn;
+    m_fileFormat = MsDataFormat::msn;
   else if(readerName == "ABSciex WIFF")
-    m_fileFormat = MzFormat::abSciexWiff;
+    m_fileFormat = MsDataFormat::abSciexWiff;
   else if(readerName == "ABSciex T2D")
-    m_fileFormat = MzFormat::abSciexT2D;
+    m_fileFormat = MsDataFormat::abSciexT2D;
   else if(readerName == "Agilent MassHunter")
-    m_fileFormat = MzFormat::agilentMassHunter;
+    m_fileFormat = MsDataFormat::agilentMassHunter;
   else if(readerName == "Thermo RAW")
-    m_fileFormat = MzFormat::thermoRaw;
+    m_fileFormat = MsDataFormat::thermoRaw;
   else if(readerName == "Water RAW")
-    m_fileFormat = MzFormat::watersRaw;
+    m_fileFormat = MsDataFormat::watersRaw;
   else if(readerName == "Bruker FID")
-    m_fileFormat = MzFormat::brukerFid;
+    m_fileFormat = MsDataFormat::brukerFid;
   else if(readerName == "Bruker YEP")
-    m_fileFormat = MzFormat::brukerYep;
+    m_fileFormat = MsDataFormat::brukerYep;
   else if(readerName == "Bruker BAF")
-    m_fileFormat = MzFormat::brukerBaf;
+    m_fileFormat = MsDataFormat::brukerBaf;
   else
     {
-      m_fileFormat = MzFormat::unknown;
+      m_fileFormat = MsDataFormat::unknown;
       return 0;
     }
 
@@ -159,7 +160,7 @@ PwizMsFileReader::initialize()
 }
 
 
-MzFormat
+MsDataFormat
 PwizMsFileReader::getFileFormat()
 {
   // std::cout << __FILE__ << " @ " << __LINE__ << " " << __FUNCTION__ << " () "
@@ -180,17 +181,12 @@ PwizMsFileReader::getMsRunIds(const QString &run_prefix)
 
   std::size_t iter = 0;
 
-  // If the initialization failed, then there is not a single MSDataPtr in the
-  // vector, so the loop below is not gone through.
-
-  for(pwiz::msdata::MSDataPtr ms_data_ptr : m_msDataPtrVector)
+  for(const pwiz::msdata::MSDataPtr & ms_data_ptr : m_msDataPtrVector)
     {
-      // For each ms run in the file, we will create a MsRunId instance that
-      // will hold the file name of the data file
-
-      // Finally create the MsRunId with the file name.
-      MsRunId ms_run_id(m_fileName, QString::fromStdString(ms_data_ptr->id));
-      ms_run_id.setMzFormat(m_fileFormat);
+      MsRunId ms_run_id(m_fileName, QString::fromStdString(ms_data_ptr->run.id));
+      
+      // Set the MS data format as determined in initialize().
+      ms_run_id.setMsDataFormat(m_fileFormat);
 
       // We need to set the unambiguous xmlId string.
       ms_run_id.setXmlId(QString("%1%2")
@@ -199,7 +195,8 @@ PwizMsFileReader::getMsRunIds(const QString &run_prefix)
 
       // Now set the sample name to the run id :
       ms_run_id.setSampleName(QString::fromStdString(ms_data_ptr->run.id));
-      // and if it is possible, the real sample name because this one is for the
+      
+      // And if it is possible, the real sample name because this one is for the
       // end user to recognize his sample:
       if(ms_data_ptr->run.samplePtr != nullptr)
         {
