@@ -25,7 +25,7 @@ class PwizMsFileReader : MsFileReader
   PwizMsFileReader(const QString &file_name);
   virtual ~PwizMsFileReader();
 
-  virtual MzFormat getFileFormat() override;
+  virtual MsDataFormat getFileFormat() override;
 
   virtual std::vector<MsRunIdCstSPtr>
   getMsRunIds(const QString &run_prefix) override;
