@@ -28,7 +28,6 @@ namespace pappso
 XyMsFileReader::XyMsFileReader(const QString &file_name)
   : MsFileReader{file_name}
 {
-  initialize();
 }
 
 
@@ -37,13 +36,13 @@ XyMsFileReader::~XyMsFileReader()
 }
 
 
-std::size_t
-XyMsFileReader::initialize()
+bool
+XyMsFileReader::initialize(std::size_t &line_count)
 {
   // Here we just test all the lines of the file to check that they comply with
   // the xy format.
 
-  std::size_t line_count = 0;
+  line_count = 0;
 
   QFile file(m_fileName);
 
@@ -62,7 +61,6 @@ XyMsFileReader::initialize()
   while(!file.atEnd())
     {
       line = file.readLine();
-      ++line_count;
 
       // We only read a given number of lines from the file, that would be
       // enough to check if that file has the right syntax or not.
@@ -73,29 +71,39 @@ XyMsFileReader::initialize()
          Utils::endOfLineRegExp.match(line).hasMatch())
         continue;
 
-      // qDebug() << __FILE__ << __LINE__ << "Current xy format line:" << line;
+      qDebug() << "Current xy format line:" << line;
 
       if(Utils::xyMassDataFormatRegExp.match(line).hasMatch())
-        continue;
+        {
+          ++line_count;
+          continue;
+        }
       else
         {
-          file_reading_failed = true;
-          break;
+          // the first line of the text file may include column titles
+          if(line_count > 0)
+            {
+              file_reading_failed = true;
+              break;
+            }
         }
     }
 
   if(!file_reading_failed && line_count >= 1)
-    m_fileFormat = MzFormat::xy;
-  else
-    m_fileFormat = MzFormat::unknown;
+    {
+      m_fileFormat = MsDataFormat::xy;
+      return true;
+    }
+
+  m_fileFormat = MsDataFormat::unknown;
 
   // qDebug() << "m_fileFormat: " << static_cast<int>(m_fileFormat);
 
-  return line_count;
+  return false;
 }
 
 
-MzFormat
+MsDataFormat
 XyMsFileReader::getFileFormat()
 {
   return m_fileFormat;
@@ -107,12 +115,14 @@ XyMsFileReader::getMsRunIds(const QString &run_prefix)
 {
   std::vector<MsRunIdCstSPtr> ms_run_ids;
 
-  if(!initialize())
+  std::size_t line_count = 0;
+
+  if(!initialize(line_count))
     return ms_run_ids;
 
   // Finally create the MsRunId with the file name.
   MsRunId ms_run_id(m_fileName);
-  ms_run_id.setMzFormat(m_fileFormat);
+  ms_run_id.setMsDataFormat(m_fileFormat);
 
   // We need to set the unambiguous xmlId string.
   ms_run_id.setXmlId(
