@@ -17,13 +17,13 @@ namespace pappso
 class XyMsFileReader : MsFileReader
 {
   private:
-  virtual std::size_t initialize();
+  virtual bool initialize(std::size_t &line_count);
 
   public:
   XyMsFileReader(const QString &file_name);
   virtual ~XyMsFileReader();
 
-  virtual MzFormat getFileFormat() override;
+  virtual MsDataFormat getFileFormat() override;
 
   virtual std::vector<MsRunIdCstSPtr>
   getMsRunIds(const QString &run_prefix) override;
