@@ -147,7 +147,7 @@ MsRunDataSetTree::addMassSpectrum(
       // means we have effectively handled a genuine mobility scan spectrum.
       QVariant ion_mobility_variant_value =
         mass_spectrum_csp->getParameterValue(
-          QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+          QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -178,7 +178,7 @@ MsRunDataSetTree::addMassSpectrum(
           // have ion mobility data here.
 
           ion_mobility_variant_value = mass_spectrum_csp->getParameterValue(
-            QualifiedMassSpectrumParameter::TimsFrameIonMobOneOverK0Begin);
+            QualifiedMassSpectrumParameter::IonMobOneOverK0Begin);
 
           if(!ion_mobility_variant_value.isValid())
             {
@@ -613,7 +613,7 @@ MsRunDataSetTree::addMassSpectrum(
       // means we have effectively handled a genuine mobility scan spectrum.
       QVariant ion_mobility_variant_value =
         mass_spectrum_csp->getParameterValue(
-          QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+          QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -644,7 +644,7 @@ MsRunDataSetTree::addMassSpectrum(
           // have ion mobility data here.
 
           ion_mobility_variant_value = mass_spectrum_csp->getParameterValue(
-            QualifiedMassSpectrumParameter::TimsFrameIonMobOneOverK0Begin);
+            QualifiedMassSpectrumParameter::IonMobOneOverK0Begin);
 
           if(!ion_mobility_variant_value.isValid())
             {
