@@ -13,6 +13,7 @@
 
 
 /////////////////////// Local includes
+#include "../exportinmportconfig.h"
 
 namespace pappso
 {
@@ -20,7 +21,7 @@ namespace pappso
 class MsRunDataSetTreeNode;
 
 
-class MsRunDataSetTreeNodeVisitorInterface
+class PMSPP_LIB_DECL MsRunDataSetTreeNodeVisitorInterface
 {
   public:
   virtual bool visit(const MsRunDataSetTreeNode &node) = 0;
