@@ -103,19 +103,19 @@ MsRunId::setFileName(const QString &file_name)
       m_sampleName = file_info.baseName();
     }
 
-  m_mzFormat = MzFormat::unknown;
+  m_mzFormat = MsDataFormat::unknown;
 
   if(extension.toLower() == "mzxml")
     {
-      m_mzFormat = MzFormat::mzXML;
+      m_mzFormat = MsDataFormat::mzXML;
     }
   else if(extension.toLower() == "mgf")
     {
-      m_mzFormat = MzFormat::MGF;
+      m_mzFormat = MsDataFormat::MGF;
     }
   else if(extension.toLower() == "mzml")
     {
-      m_mzFormat = MzFormat::mzML;
+      m_mzFormat = MsDataFormat::mzML;
     }
 }
 
@@ -155,14 +155,14 @@ MsRunId::getFileName() const
 
 
 void
-MsRunId::setMzFormat(MzFormat format)
+MsRunId::setMsDataFormat(MsDataFormat format)
 {
   m_mzFormat = format;
 }
 
 
-MzFormat
-MsRunId::getMzFormat() const
+MsDataFormat
+MsRunId::getMsDataFormat() const
 {
   return m_mzFormat;
 }
@@ -210,7 +210,7 @@ bool
 MsRunId::isValid() const
 {
   return !m_fileName.isEmpty() && !m_runId.isEmpty() && !m_xmlId.isEmpty() &&
-         m_mzFormat != MzFormat::unknown;
+         m_mzFormat != MsDataFormat::unknown;
 }
 
 
