@@ -79,8 +79,8 @@ class PMSPP_LIB_DECL MsRunId
   void setSampleName(const QString &name);
   const QString &getSampleName() const;
 
-  void setMzFormat(MzFormat format);
-  MzFormat getMzFormat() const;
+  void setMsDataFormat(MsDataFormat format);
+  MsDataFormat getMsDataFormat() const;
 
   QString toString() const;
 
@@ -91,7 +91,7 @@ class PMSPP_LIB_DECL MsRunId
   QString m_runId;
   QString m_xmlId; /* a1.... */
   QString m_sampleName;
-  MzFormat m_mzFormat = MzFormat::mzXML;
+  MsDataFormat m_mzFormat = MsDataFormat::mzXML;
 };
 
 
