@@ -144,8 +144,8 @@ bool
 MsRunReadConfig::acceptRetentionTimeInSeconds(
   double retention_time_in_seconds) const
 {
-  qDebug() << "Requested retention_time_in_seconds:"
-           << retention_time_in_seconds;
+  // qDebug() << "Requested retention_time_in_seconds:"
+  //          << retention_time_in_seconds;
 
   // Whatever the member datum below, if it is equal to -1
   // then that means that RT is not a selection criterion.
@@ -244,55 +244,55 @@ MsRunReadConfig::toString() const
   text += " \n";
 
   if(!getParameterValue(
-        MsRunReadConfigParameter::TimsFramesMsRunReader_mobility_index_begin)
+        MsRunReadConfigParameter::TimsFrameIonMobScanIndexBegin)
         .isNull())
     {
       text +=
         QString("Mobility index range: [%1-%2]\n")
           .arg(getParameterValue(MsRunReadConfigParameter::
-                                   TimsFramesMsRunReader_mobility_index_begin)
+                                   TimsFrameIonMobScanIndexBegin)
                  .toUInt())
           .arg(getParameterValue(MsRunReadConfigParameter::
-                                   TimsFramesMsRunReader_mobility_index_end)
+                                   TimsFrameIonMobScanIndexEnd)
                  .toUInt());
     }
 
   if(!getParameterValue(MsRunReadConfigParameter::
-                          TimsFramesMsRunReader_mobility_one_over_k0_begin)
+                          TimsFrameIonMobOneOverK0Begin)
         .isNull())
     {
       text += QString("Mobility 1/K0 range: [%1-%2]\n")
                 .arg(getParameterValue(
                        MsRunReadConfigParameter::
-                         TimsFramesMsRunReader_mobility_one_over_k0_begin)
+                         TimsFrameIonMobOneOverK0Begin)
                        .toDouble())
                 .arg(getParameterValue(
                        MsRunReadConfigParameter::
-                         TimsFramesMsRunReader_mobility_one_over_k0_end)
+                         TimsFrameIonMobOneOverK0End)
                        .toDouble());
     }
 
   if(!getParameterValue(
-        MsRunReadConfigParameter::TimsFramesMsRunReader_mz_begin)
+        MsRunReadConfigParameter::MzRangeBegin)
         .isNull())
     {
       text += QString("m/z range: [%1-%2]\n")
                 .arg(getParameterValue(
-                       MsRunReadConfigParameter::TimsFramesMsRunReader_mz_begin)
+                       MsRunReadConfigParameter::MzRangeBegin)
                        .toDouble())
                 .arg(getParameterValue(
-                       MsRunReadConfigParameter::TimsFramesMsRunReader_mz_end)
+                       MsRunReadConfigParameter::MzRangeEnd)
                        .toDouble());
     }
 
   if(!getParameterValue(
-        MsRunReadConfigParameter::TimsFramesMsRunReader_mz_index_merge_window)
+        MsRunReadConfigParameter::TimsFrameMzIndexMergeWindow)
         .isNull())
     {
       text +=
         QString("m/z merge window %1\n")
           .arg(getParameterValue(MsRunReadConfigParameter::
-                                   TimsFramesMsRunReader_mz_index_merge_window)
+                                   TimsFrameMzIndexMergeWindow)
                  .toUInt());
     }
 
