@@ -29,19 +29,29 @@
 namespace pappso
 {
 
-
 /** \def MsRunReadConfigParameters specific parameters for MsRunReadConfig
  *
  */
 enum class MsRunReadConfigParameter
 {
-  TimsFramesMsRunReader_mobility_index_begin,
-  TimsFramesMsRunReader_mobility_index_end,
-  TimsFramesMsRunReader_mobility_one_over_k0_begin,
-  TimsFramesMsRunReader_mobility_one_over_k0_end,
-  TimsFramesMsRunReader_mz_begin,
-  TimsFramesMsRunReader_mz_end,
-  TimsFramesMsRunReader_mz_index_merge_window,
+  // Only process mobility scans contained in the
+  // scan index range below.
+  TimsFrameIonMobScanIndexBegin,
+  TimsFrameIonMobScanIndexEnd,
+
+  // Only process mobility scans contained in the
+  // inverse mobility range below.
+  TimsFrameIonMobOneOverK0Begin,
+  TimsFrameIonMobOneOverK0End,
+
+  // Only process mass spectra for m/z values contained
+  // in the following m/z range.
+  MzRangeBegin,
+  MzRangeEnd,
+
+  // Merge m/z (TOF, really) indices on the basis of this
+  // count of m/z (TOF, really) indices.
+  TimsFrameMzIndexMergeWindow,
 };
 
 // It is generally admitted that 11 is the max MS levels
