@@ -40,7 +40,8 @@ namespace pappso
 {
 
 
-MsRunReader::MsRunReader(MsRunIdCstSPtr &ms_run_id) : mcsp_msRunId(ms_run_id)
+MsRunReader::MsRunReader(const MsRunIdCstSPtr &ms_run_id)
+  : mcsp_msRunId(ms_run_id)
 {
 }
 
