@@ -42,7 +42,7 @@
 namespace pappso
 {
 
-class PwizMsRunReader : public MsRunReader
+class PMSPP_LIB_DECL PwizMsRunReader : public MsRunReader
 {
   friend class MsFileAccessor;
 
@@ -87,6 +87,12 @@ class PwizMsRunReader : public MsRunReader
 
   virtual bool acquireDevice() override;
 
+
+  /** @brief get OboPsiModTerm corresponding to the nativeID format format of mz
+   * data
+   */
+  const OboPsiModTerm getOboPsiModTermNativeIDFormat() const;
+
   protected:
   virtual void readSpectrumCollectionWithMsrunReadConfig(
     const MsRunReadConfig &config, SpectrumCollectionHandlerInterface &handler);
@@ -114,7 +120,12 @@ class PwizMsRunReader : public MsRunReader
                      std::size_t spectrum_index,
                      bool want_binary_data) const;
 
+  static std::string setGlobalLocaleToEnglish();
+
+  static void setGlobalLocaleToCurrentOs(const std::string &environment_locale);
+
   protected:
+  static QMutex m_mutex;
   pwiz::msdata::MSDataPtr msp_msData = nullptr;
 
 
