@@ -29,16 +29,14 @@
 #include "../../exception/exceptionnotimplemented.h"
 #include "../../exception/exceptioninterrupted.h"
 #include "../../exception/exceptionnotpossible.h"
+#include "../../vendors/tims/timsddaprecursors.h"
 #include <QDebug>
 
 using namespace pappso;
 
 TimsFramesMsRunReader::TimsFramesMsRunReader(MsRunIdCstSPtr &msrun_id_csp)
-  : MsRunReader(msrun_id_csp)
+  : TimsMsRunReaderBase(msrun_id_csp)
 {
-  qDebug() << "Now initializing the TimsFramesMsRunReader.";
-
-  initialize();
 }
 
 TimsFramesMsRunReader::~TimsFramesMsRunReader()
@@ -46,27 +44,6 @@ TimsFramesMsRunReader::~TimsFramesMsRunReader()
   msp_timsData = nullptr;
 }
 
-void
-TimsFramesMsRunReader::initialize()
-{
-  msp_timsData = std::make_shared<TimsData>(mcsp_msRunId.get()->getFileName());
-  if(msp_timsData == nullptr)
-    {
-      throw PappsoException(
-        QObject::tr("ERROR in TimsFramesMsRunReader::initialize "
-                    "msp_timsData is null for MsRunId %1")
-          .arg(mcsp_msRunId.get()->toString()));
-    }
-}
-
-
-bool
-TimsFramesMsRunReader::accept(const QString &file_name) const
-{
-  qDebug() << file_name;
-  return true;
-}
-
 
 pappso::MassSpectrumSPtr
 TimsFramesMsRunReader::massSpectrumSPtr(
@@ -83,7 +60,7 @@ TimsFramesMsRunReader::massSpectrumSPtr(
 pappso::MassSpectrumCstSPtr
 TimsFramesMsRunReader::massSpectrumCstSPtr(std::size_t spectrum_index)
 {
-  return msp_timsData->getMassSpectrumCstSPtrByRawIndex(spectrum_index);
+  return msp_timsData->getMassSpectrumCstSPtrByGlobalScanIndex(spectrum_index);
 }
 
 
@@ -94,7 +71,7 @@ TimsFramesMsRunReader::qualifiedMassSpectrum(std::size_t spectrum_index,
 
   QualifiedMassSpectrum mass_spectrum;
 
-  msp_timsData->getQualifiedMassSpectrumByRawIndex(
+  msp_timsData->getQualifiedMassSpectrumByGlobalScanIndex(
     getMsRunId(), mass_spectrum, spectrum_index, want_binary_data);
   return mass_spectrum;
 }
@@ -190,6 +167,9 @@ TimsFramesMsRunReader::readSpectrumCollection2(
       if(!config.acceptMsLevel(ms_level))
         continue;
 
+      // FIXME: this might be the place where to actually get the list of
+      // precursors' m/z and charge values.
+
       subset_of_tims_frame_ids.push_back(frame_record.frame_id);
 
       if(mobility_scan_num_range_width != std::numeric_limits<int>::max())
@@ -198,7 +178,7 @@ TimsFramesMsRunReader::readSpectrumCollection2(
         }
       else
         {
-          scan_count += frame_id_descr_list[frame_record.frame_id].m_size;
+          scan_count += frame_id_descr_list[frame_record.frame_id].m_scanCount;
         }
     }
 
@@ -276,7 +256,10 @@ TimsFramesMsRunReader::readSpectrumCollection2(
         frame_id_descr_list[tims_frame_id];
       // qDebug() << "tims_frame_id=" << tims_frame_id;
 
-      scan_index = current_frame_record.m_cumulSize;
+      // FIXME: from an outsider point of view, cumulated size does not
+      // convey the notion of sequential scan number.
+
+      scan_index = current_frame_record.m_globalScanIndex;
 
       TimsFrameCstSPtr tims_frame_csp =
         msp_timsData->getTimsFrameCstSPtrCached(tims_frame_id);
@@ -309,11 +292,11 @@ TimsFramesMsRunReader::readSpectrumCollection2(
               .toDouble();
 
           mobility_scan_num_range_begin =
-            tims_frame_csp.get()->getScanNumFromOneOverK0(
+            tims_frame_csp.get()->getScanIndexFromOneOverK0(
               mobility_one_over_k0_range_begin);
 
           mobility_scan_num_range_end =
-            tims_frame_csp.get()->getScanNumFromOneOverK0(
+            tims_frame_csp.get()->getScanIndexFromOneOverK0(
               mobility_one_over_k0_range_end);
 
           asked_ion_mobility_scan_num_range = true;
@@ -355,12 +338,12 @@ TimsFramesMsRunReader::readSpectrumCollection2(
 
       // We want to provide the inverse mobility for the scan that sits in the
       // middle of the defined range or the whole range if none is defined..
-      mobility_one_over_k0 = tims_frame_csp.get()->getScanNumFromOneOverK0(
+      mobility_one_over_k0 = tims_frame_csp.get()->getScanIndexFromOneOverK0(
         mobility_scan_num_range_begin + (mobility_scan_num_range_width / 2));
 
       // Now, with or without the peak list, we have to craft a qualified mass
       // spectrum that will hold all the data about the data in it.
-      QualifiedMassSpectrum mass_spectrum;
+      QualifiedMassSpectrum qualified_mass_spectrum;
 
       MassSpectrumId spectrum_id;
 
@@ -376,19 +359,24 @@ TimsFramesMsRunReader::readSpectrumCollection2(
           .arg(mobility_scan_num_range_begin)
           .arg(mobility_scan_num_range_end));
 
-      mass_spectrum.setMassSpectrumId(spectrum_id);
+      qualified_mass_spectrum.setMassSpectrumId(spectrum_id);
 
       // We want to document the retention time!
-      mass_spectrum.setRtInSeconds(tims_frame_csp.get()->getTime());
+
+      qualified_mass_spectrum.setRtInSeconds(
+        tims_frame_csp.get()->getRtInSeconds());
 
       // We do want to document the ms level of the spectrum and possibly
       // the precursor's m/z and charge.
       unsigned int frame_ms_level = tims_frame_csp.get()->getMsLevel();
-      mass_spectrum.setMsLevel(frame_ms_level);
+      qualified_mass_spectrum.setMsLevel(frame_ms_level);
+      
 
       // Arrival time at half the range.
-      mass_spectrum.setDtInMilliSeconds(tims_frame_csp.get()->getDriftTime(
-        mobility_scan_num_range_begin + (mobility_scan_num_range_width / 2)));
+
+      qualified_mass_spectrum.setDtInMilliSeconds(
+        tims_frame_csp.get()->getDriftTimeInMilliseconds(
+          mobility_scan_num_range_begin + (mobility_scan_num_range_width / 2)));
 
       // 1/K0
       qDebug() << "mobility_one_over_k0:" << mobility_one_over_k0
@@ -405,14 +393,13 @@ TimsFramesMsRunReader::readSpectrumCollection2(
           ExceptionNotPossible("Not possible that mobility_one_over_k0 and its "
                                "range are undefined."));
 
-      mass_spectrum.setParameterValue(
-        QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0,
-        mobility_one_over_k0);
-      mass_spectrum.setParameterValue(
-        QualifiedMassSpectrumParameter::TimsFrameIonMobOneOverK0Begin,
+      qualified_mass_spectrum.setParameterValue(
+        QualifiedMassSpectrumParameter::IonMobOneOverK0, mobility_one_over_k0);
+      qualified_mass_spectrum.setParameterValue(
+        QualifiedMassSpectrumParameter::IonMobOneOverK0Begin,
         mobility_one_over_k0_range_begin);
-      mass_spectrum.setParameterValue(
-        QualifiedMassSpectrumParameter::TimsFrameIonMobOneOverK0End,
+      qualified_mass_spectrum.setParameterValue(
+        QualifiedMassSpectrumParameter::IonMobOneOverK0End,
         mobility_one_over_k0_range_end);
 
       // qDebug() << "mobility_scan_num_range_begin:"
@@ -425,19 +412,20 @@ TimsFramesMsRunReader::readSpectrumCollection2(
         throw(ExceptionNotPossible(
           "Not possible that mobility_scan_num_range values are undefined."));
 
-      mass_spectrum.setParameterValue(
+      qualified_mass_spectrum.setParameterValue(
         QualifiedMassSpectrumParameter::TimsIonMobScanIndex,
         mobility_scan_num_range_begin + (mobility_scan_num_range_width / 2));
-      mass_spectrum.setParameterValue(
+      qualified_mass_spectrum.setParameterValue(
         QualifiedMassSpectrumParameter::TimsFrameIonMobScanIndexBegin,
         mobility_scan_num_range_begin);
-      mass_spectrum.setParameterValue(
+      qualified_mass_spectrum.setParameterValue(
         QualifiedMassSpectrumParameter::TimsFrameIonMobScanIndexEnd,
         mobility_scan_num_range_end);
 
-      mass_spectrum.setParameterValue(
+      qualified_mass_spectrum.setParameterValue(
         QualifiedMassSpectrumParameter::TimsFrameScansCount,
         static_cast<qlonglong>(tims_frame_csp->getTotalNumberOfScans()));
+      
 
       Trace trace;
 
@@ -450,45 +438,47 @@ TimsFramesMsRunReader::readSpectrumCollection2(
 
           if(asked_mz_range)
             {
-              trace = tims_frame_csp->cumulateScansToTraceMzDownResolution2(
-                mz_index_merge_window,
-                mz_range_begin,
-                mz_range_end,
-                mobility_scan_num_range_begin,
-                mobility_scan_num_range_end,
-                min_mz_index_out,
-                max_mz_index_out);
+              trace =
+                tims_frame_csp->combineScansToTraceWithDowngradedMzResolution2(
+                  mz_index_merge_window,
+                  mz_range_begin,
+                  mz_range_end,
+                  mobility_scan_num_range_begin,
+                  mobility_scan_num_range_end,
+                  min_mz_index_out,
+                  max_mz_index_out);
             }
           else
             {
-              trace = tims_frame_csp->cumulateScansToTraceMzDownResolution(
-                mz_index_merge_window,
-                mobility_scan_num_range_begin,
-                mobility_scan_num_range_end,
-                min_mz_index_out,
-                max_mz_index_out);
+              trace =
+                tims_frame_csp->combineScansToTraceWithDowngradedMzResolution(
+                  mz_index_merge_window,
+                  mobility_scan_num_range_begin,
+                  mobility_scan_num_range_end,
+                  min_mz_index_out,
+                  max_mz_index_out);
             }
 
           // qDebug() << "Got min_mz_index_out:" << min_mz_index_out;
           // qDebug() << "Got max_mz_index_out:" << max_mz_index_out;
 
-          mass_spectrum.setParameterValue(
+          qualified_mass_spectrum.setParameterValue(
             QualifiedMassSpectrumParameter::TimsFrameMzIndexBegin,
             min_mz_index_out);
-          mass_spectrum.setParameterValue(
+          qualified_mass_spectrum.setParameterValue(
             QualifiedMassSpectrumParameter::TimsFrameMzIndexEnd,
             max_mz_index_out);
 
-          mass_spectrum.setMassSpectrumSPtr(
+          qualified_mass_spectrum.setMassSpectrumSPtr(
             std::make_shared<MassSpectrum>(trace));
-          mass_spectrum.setEmptyMassSpectrum(false);
+          qualified_mass_spectrum.setEmptyMassSpectrum(false);
         }
       else
         {
-          mass_spectrum.setEmptyMassSpectrum(true);
+          qualified_mass_spectrum.setEmptyMassSpectrum(true);
         }
 
-      handler.setQualifiedMassSpectrum(mass_spectrum);
+      handler.setQualifiedMassSpectrum(qualified_mass_spectrum);
     }
 }
 
@@ -505,76 +495,10 @@ TimsFramesMsRunReader::readSpectrumCollectionByMsLevel(
 std::size_t
 TimsFramesMsRunReader::spectrumListSize() const
 {
-  return msp_timsData->getTotalNumberOfScans();
+  return msp_timsData->getTotalScanCount();
 }
 
 
-bool
-TimsFramesMsRunReader::hasScanNumbers() const
-{
-  return false;
-}
-
-
-bool
-TimsFramesMsRunReader::releaseDevice()
-{
-  msp_timsData = nullptr;
-  return true;
-}
-
-bool
-TimsFramesMsRunReader::acquireDevice()
-{
-  if(msp_timsData == nullptr)
-    {
-      initialize();
-    }
-  return true;
-}
-
-
-XicCoordSPtr
-TimsFramesMsRunReader::newXicCoordSPtrFromSpectrumIndex(
-  std::size_t spectrum_index [[maybe_unused]],
-  pappso::PrecisionPtr precision [[maybe_unused]]) const
-{
-  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
-                                  .arg(__FILE__)
-                                  .arg(__FUNCTION__)
-                                  .arg(__LINE__));
-}
-
-XicCoordSPtr
-TimsFramesMsRunReader::newXicCoordSPtrFromQualifiedMassSpectrum(
-  const pappso::QualifiedMassSpectrum &mass_spectrum [[maybe_unused]],
-  pappso::PrecisionPtr precision [[maybe_unused]]) const
-{
-  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
-                                  .arg(__FILE__)
-                                  .arg(__FUNCTION__)
-                                  .arg(__LINE__));
-}
-
-TimsDataSp
-TimsFramesMsRunReader::getTimsDataSPtr()
-{
-  acquireDevice();
-  return msp_timsData;
-}
-
-
-Trace
-TimsFramesMsRunReader::getTicChromatogram()
-{
-  // Use the Sqlite database to fetch the total ion current chromatogram (TIC
-  // chromatogram).
-
-  acquireDevice();
-
-  return msp_timsData->getTicChromatogram();
-}
-
 
 Trace
 TimsFramesMsRunReader::computeTicChromatogram()
@@ -615,11 +539,12 @@ TimsFramesMsRunReader::computeTicChromatogram()
         {
 
           // Retention times are in seconds in the Bruker world.
-          double rt = tims_frame_csp->getTime();
+          double rt = tims_frame_csp->getRtInSeconds();
 
-          tic_chromatogram.append(DataPoint(
-            rt,
-            tims_frame_csp->cumulateScansIntensities(scan_begin, scan_end)));
+          tic_chromatogram.append(
+            DataPoint(rt,
+                      tims_frame_csp->cumulateScanRangeIntensities(scan_begin,
+                                                                   scan_end)));
         }
       else
         continue;
