@@ -28,8 +28,7 @@
 
 #pragma once
 
-#include "../../msfile/msfileaccessor.h"
-#include "../../vendors/tims/timsdata.h"
+#include "timsmsrunreaderbase.h"
 
 namespace pappso
 {
@@ -40,7 +39,7 @@ namespace pappso
 // binary data file and not using the TIC chromatogram that is stored in the DB
 // file.
 
-class PMSPP_LIB_DECL TimsFramesMsRunReader : public MsRunReader
+class PMSPP_LIB_DECL TimsFramesMsRunReader : public TimsMsRunReaderBase
 {
   friend class MsFileAccessor;
   /**
@@ -70,37 +69,19 @@ class PMSPP_LIB_DECL TimsFramesMsRunReader : public MsRunReader
                                   unsigned int ms_level) override;
 
 
-  virtual pappso::XicCoordSPtr newXicCoordSPtrFromSpectrumIndex(
-    std::size_t spectrum_index, pappso::PrecisionPtr precision) const override;
-
-  virtual pappso::XicCoordSPtr newXicCoordSPtrFromQualifiedMassSpectrum(
-    const pappso::QualifiedMassSpectrum &mass_spectrum,
-    pappso::PrecisionPtr precision) const override;
 
 
   virtual std::size_t spectrumListSize() const override;
 
-  virtual bool hasScanNumbers() const override;
 
-  virtual bool releaseDevice() override;
-
-  virtual bool acquireDevice() override;
-
-
-  /** @brief give an access to the underlying raw data pointer
-   */
-  virtual TimsDataSp getTimsDataSPtr();
-
-  virtual Trace getTicChromatogram() override;
   virtual Trace computeTicChromatogram();
 
 
-  protected:
-  virtual void initialize() override;
-  virtual bool accept(const QString &file_name) const override;
 
-  private:
-  TimsDataSp msp_timsData = nullptr;
 };
 
+typedef std::shared_ptr<TimsFramesMsRunReader> TimsFramesMsRunReaderSPtr;
+typedef std::shared_ptr<const TimsFramesMsRunReader>
+  TimsFramesMsRunReaderCstSPtr;
+
 } // namespace pappso
