@@ -26,6 +26,8 @@
  ******************************************************************************/
 
 #include "timsmsrunreader.h"
+#include "../../vendors/tims/timsddaprecursors.h"
+#include "../../vendors/tims/timsdiaslices.h"
 #include "../../exception/exceptionnotimplemented.h"
 #include "../../exception/exceptioninterrupted.h"
 #include <QDebug>
@@ -33,35 +35,19 @@
 using namespace pappso;
 
 TimsMsRunReader::TimsMsRunReader(MsRunIdCstSPtr &msrun_id_csp)
-  : MsRunReader(msrun_id_csp)
+  : TimsMsRunReaderBase(msrun_id_csp)
+{
+  initialize();
+}
+TimsMsRunReader::TimsMsRunReader(const TimsMsRunReaderBase &msrun_reader_base)
+  : TimsMsRunReaderBase(msrun_reader_base)
 {
   initialize();
 }
 
+
 TimsMsRunReader::~TimsMsRunReader()
 {
-  msp_timsData = nullptr;
-}
-
-void
-TimsMsRunReader::initialize()
-{
-  msp_timsData = std::make_shared<TimsData>(mcsp_msRunId.get()->getFileName());
-
-  if(msp_timsData == nullptr)
-    {
-      throw PappsoException(QObject::tr("ERROR in TimsMsRunReader::initialize "
-                                        "msp_timsData is null for MsRunId %1")
-                              .arg(mcsp_msRunId.get()->toString()));
-    }
-}
-
-
-bool
-TimsMsRunReader::accept(const QString &file_name) const
-{
-  qDebug() << file_name;
-  return true;
 }
 
 
@@ -77,7 +63,7 @@ TimsMsRunReader::massSpectrumSPtr([[maybe_unused]] std::size_t spectrum_index)
 pappso::MassSpectrumCstSPtr
 TimsMsRunReader::massSpectrumCstSPtr(std::size_t spectrum_index)
 {
-  return msp_timsData->getMassSpectrumCstSPtrByRawIndex(spectrum_index);
+  return msp_timsData->getMassSpectrumCstSPtrByGlobalScanIndex(spectrum_index);
 }
 
 
@@ -88,7 +74,7 @@ TimsMsRunReader::qualifiedMassSpectrum(std::size_t spectrum_index,
 
   QualifiedMassSpectrum mass_spectrum;
 
-  msp_timsData->getQualifiedMassSpectrumByRawIndex(
+  msp_timsData->getQualifiedMassSpectrumByGlobalScanIndex(
     getMsRunId(), mass_spectrum, spectrum_index, want_binary_data);
   return mass_spectrum;
 }
@@ -192,7 +178,7 @@ TimsMsRunReader::readSpectrumCollection2(
         }
       else
         {
-          scan_count += frame_id_descr_list[frame_record.frame_id].m_size;
+          scan_count += frame_id_descr_list[frame_record.frame_id].m_scanCount;
         }
     }
 
@@ -200,7 +186,6 @@ TimsMsRunReader::readSpectrumCollection2(
   std::size_t frame_count = subset_of_tims_frame_ids.size();
   qDebug() << "The number of retained RT range- and MS level-matching frames : "
            << frame_count;
-
   // Inform the handler of the spectrum list so that it can handle feedback to
   // the user.
   handler.spectrumListHasSize(scan_count);
@@ -255,7 +240,7 @@ TimsMsRunReader::readSpectrumCollection2(
             QObject::tr("Reading timsTOF data cancelled by the user."));
         }
 
-      // qDebug() << "tims_frame_id=" << tims_frame_id;
+      qDebug() << "tims_frame_id=" << tims_frame_id;
 
       const FrameIdDescr &current_frame_record =
         frame_id_descr_list[tims_frame_id];
@@ -263,6 +248,8 @@ TimsMsRunReader::readSpectrumCollection2(
       TimsFrameCstSPtr tims_frame_csp =
         msp_timsData->getTimsFrameCstSPtrCached(tims_frame_id);
 
+      qDebug() << "tims_frame_id=" << tims_frame_id;
+
       // If the user wants to select 1/Ko values in a given range, we need to
       // compute the ion mobility scan value starting from that 1/Ko value in
       // *each* frame. Note that the computed mobility_scan_num_begin and
@@ -291,16 +278,17 @@ TimsMsRunReader::readSpectrumCollection2(
               .toDouble();
 
           mobility_scan_num_range_begin =
-            tims_frame_csp.get()->getScanNumFromOneOverK0(
+            tims_frame_csp.get()->getScanIndexFromOneOverK0(
               mobility_one_over_k0_range_begin);
 
           mobility_scan_num_range_end =
-            tims_frame_csp.get()->getScanNumFromOneOverK0(
+            tims_frame_csp.get()->getScanIndexFromOneOverK0(
               mobility_one_over_k0_range_end);
 
           asked_ion_mobility_scan_num_range = true;
         }
 
+      qDebug() << "tims_frame_id=" << tims_frame_id;
       // Now that we know if the user has asked for an ion mobility range,
       // either using scan indices or 1/K0 values, we need to double check the
       // range borders.
@@ -320,6 +308,7 @@ TimsMsRunReader::readSpectrumCollection2(
           mobility_scan_num_range_end   = count_of_mobility_scans - 1;
         }
 
+      qDebug() << "tims_frame_id=" << tims_frame_id;
       // Now, with or without the peak list, we have to craft a qualified mass
       // spectrum that will hold all the data about the data in it.
       QualifiedMassSpectrum mass_spectrum;
@@ -331,24 +320,57 @@ TimsMsRunReader::readSpectrumCollection2(
 
       mass_spectrum.setMassSpectrumId(spectrum_id);
 
+      qDebug() << "tims_frame_id=" << tims_frame_id;
       // We want to document the retention time!
-      mass_spectrum.setRtInSeconds(tims_frame_csp.get()->getTime());
+      mass_spectrum.setRtInSeconds(tims_frame_csp.get()->getRtInSeconds());
 
       // We do want to document the ms level of the spectrum and possibly
       // the precursor's m/z and charge.
       unsigned int frame_ms_level = tims_frame_csp.get()->getMsLevel();
       mass_spectrum.setMsLevel(frame_ms_level);
 
+      qDebug() << "tims_frame_id=" << tims_frame_id;
+      std::vector<TimsDdaPrecursors::SpectrumDescr> dda_spectrum_descr_list;
+      TimsDiaSlices::MsMsWindowGroup *p_dia_window_group = nullptr;
+      std::size_t frame_global_slice_begin               = 0;
+      if(frame_ms_level > 1)
+        {
+          if(msp_timsData.get()->isDdaRun())
+            {
+              TimsDdaPrecursors *dda_precursors_p =
+                msp_timsData.get()->getTimsDdaPrecursorsPtr();
+              dda_spectrum_descr_list =
+                dda_precursors_p->getSpectrumDescrListByFrameId(tims_frame_id);
+            }
+
+          if(msp_timsData.get()->isDiaRun())
+            {
+
+              qDebug() << "tims_frame_id=" << tims_frame_id;
+              p_dia_window_group = msp_timsData.get()
+                                     ->getTimsDiaSlicesPtr()
+                                     ->getMapFrame2WindowGroupPtr()
+                                     .at(tims_frame_id);
+              frame_global_slice_begin =
+                msp_timsData.get()
+                  ->getTimsDiaSlicesPtr()
+                  ->getGlobalSliceIndexBeginByFrameId(tims_frame_id);
+            }
+        }
+
+      qDebug() << "tims_frame_id=" << tims_frame_id;
       // The scan index is the index of the scan in the *whole* mass data file,
       // it is a sequential number of scans over all the frames.
-      std::size_t scan_index = current_frame_record.m_cumulSize -
-                               current_frame_record.m_size +
+      std::size_t scan_index = current_frame_record.m_globalScanIndex -
+                               current_frame_record.m_scanCount +
                                mobility_scan_num_range_begin;
 
+      QualifiedMassSpectrum mass_spectrum_no_precursor_data(mass_spectrum);
       for(quint32 iter_scan_index = mobility_scan_num_range_begin;
           iter_scan_index <= mobility_scan_num_range_end;
           iter_scan_index++)
         {
+          mass_spectrum = mass_spectrum_no_precursor_data;
           mass_spectrum.getMassSpectrumId().setSpectrumIndex(scan_index);
 
           mass_spectrum.getMassSpectrumId().setNativeId(
@@ -359,6 +381,112 @@ TimsMsRunReader::readSpectrumCollection2(
 
           // qDebug() << "iter:" << iter;
 
+          // qDebug() << "Scan's mz_minimum_index:" << mz_minimum_index_out
+          //          << "and mz_maximum_index:" << mz_maximum_index_out;
+
+          // Arrival time
+          mass_spectrum.setDtInMilliSeconds(
+
+            tims_frame_csp.get()->getDriftTimeInMilliseconds(iter_scan_index));
+          // 1/K0
+          mass_spectrum.setParameterValue(
+            QualifiedMassSpectrumParameter::IonMobOneOverK0,
+            tims_frame_csp.get()->getOneOverK0Transformation(iter_scan_index));
+
+          if(dda_spectrum_descr_list.size() > 0)
+            {
+              std::size_t scan_index = (std::size_t)iter_scan_index;
+              auto it_spectrum_descr = std::find_if(
+                dda_spectrum_descr_list.begin(),
+                dda_spectrum_descr_list.end(),
+                [scan_index](
+                  const TimsDdaPrecursors::SpectrumDescr &spectrum_descr) {
+                  if(scan_index < spectrum_descr.scan_mobility_start)
+                    return false;
+                  if(scan_index > spectrum_descr.scan_mobility_end)
+                    return false;
+                  return true;
+                });
+
+              if(it_spectrum_descr != dda_spectrum_descr_list.end())
+                {
+                  qDebug() << "scan_index=" << scan_index
+                           << " spectrum_descr.scan_mobility_end="
+                           << it_spectrum_descr->scan_mobility_end;
+                  mass_spectrum.appendPrecursorIonData(
+                    it_spectrum_descr->precursor_ion_data);
+
+                  mass_spectrum.setPrecursorNativeId(
+                    QString(
+                      "frame_id=%1 begin=%2 end=%3 precursor=%4 idxms1=%5")
+                      .arg(it_spectrum_descr->parent_frame)
+                      .arg(it_spectrum_descr->scan_mobility_start)
+                      .arg(it_spectrum_descr->scan_mobility_end)
+                      .arg(it_spectrum_descr->precursor_id)
+                      .arg(it_spectrum_descr->ms1_index));
+
+                  mass_spectrum.setParameterValue(
+                    QualifiedMassSpectrumParameter::IsolationMz,
+                    it_spectrum_descr->isolationMz);
+                  mass_spectrum.setParameterValue(
+                    QualifiedMassSpectrumParameter::IsolationMzWidth,
+                    it_spectrum_descr->isolationWidth);
+
+                  mass_spectrum.setParameterValue(
+                    QualifiedMassSpectrumParameter::CollisionEnergy,
+                    it_spectrum_descr->collisionEnergy);
+                  mass_spectrum.setParameterValue(
+                    QualifiedMassSpectrumParameter::BrukerPrecursorIndex,
+                    (quint64)it_spectrum_descr->precursor_id);
+                }
+            }
+          if(p_dia_window_group != nullptr)
+            {
+
+
+              std::size_t scan_index = (std::size_t)iter_scan_index;
+              auto it_dia_window     = std::find_if(
+                p_dia_window_group->begin(),
+                p_dia_window_group->end(),
+                [scan_index](const TimsDiaSlices::MsMsWindow &dia_window) {
+                  if(scan_index < dia_window.ScanNumBegin)
+                    return false;
+                  if(scan_index > dia_window.ScanNumEnd)
+                    return false;
+                  return true;
+                });
+
+              if(it_dia_window != p_dia_window_group->end())
+                {
+                  qDebug() << "scan_index=" << scan_index
+                           << " it_dia_window->ScanNumEnd="
+                           << it_dia_window->ScanNumEnd;
+
+                  mass_spectrum.setPrecursorNativeId(
+                    QString("window_group=%1 begin=%2 end=%3 frame=%4 scan=%5 "
+                            "global_slice_id=%6")
+                      .arg(it_dia_window->WindowGroup)
+                      .arg(it_dia_window->ScanNumBegin)
+                      .arg(it_dia_window->ScanNumEnd)
+                      .arg(msp_timsData.get()
+                             ->getTimsDiaSlicesPtr()
+                             ->getLastMs1FrameIdByMs2FrameId(tims_frame_id))
+                      .arg(iter_scan_index)
+                      .arg(it_dia_window->SliceIndex +
+                           frame_global_slice_begin));
+
+                  mass_spectrum.setParameterValue(
+                    QualifiedMassSpectrumParameter::IsolationMz,
+                    it_dia_window->IsolationMz);
+                  mass_spectrum.setParameterValue(
+                    QualifiedMassSpectrumParameter::IsolationMzWidth,
+                    it_dia_window->IsolationWidth);
+
+                  mass_spectrum.setParameterValue(
+                    QualifiedMassSpectrumParameter::CollisionEnergy,
+                    it_dia_window->CollisionEnergy);
+                }
+            }
           if(config.needPeakList())
             {
               quint32 mz_minimum_index_out = 0;
@@ -384,23 +512,12 @@ TimsMsRunReader::readSpectrumCollection2(
                 QualifiedMassSpectrumParameter::TimsFrameMzIndexEnd,
                 mz_maximum_index_out);
 
-              // qDebug() << "Scan's mz_minimum_index:" << mz_minimum_index_out
-              //          << "and mz_maximum_index:" << mz_maximum_index_out;
-
-              // Arrival time
-              mass_spectrum.setDtInMilliSeconds(
-                tims_frame_csp.get()->getDriftTime(iter_scan_index));
-              // 1/K0
-              mass_spectrum.setParameterValue(
-                QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0,
-                tims_frame_csp.get()->getOneOverK0Transformation(
-                  iter_scan_index));
 
               qDebug();
               mass_spectrum.setMassSpectrumSPtr(
                 std::make_shared<MassSpectrum>(raw_trace));
 
-              qDebug();
+              qDebug() << mass_spectrum.getRtInSeconds();
             }
           else
             {
@@ -428,8 +545,13 @@ TimsMsRunReader::readSpectrumCollectionByMsLevel(
   try
     {
 
-      msp_timsData.get()->rawReaderSpectrumCollectionByMsLevel(
-        getMsRunId(), handler, ms_level);
+      if(msp_timsData->isDdaRun())
+        {
+          msp_timsData.get()
+            ->getTimsDdaPrecursorsPtr()
+            ->rawReaderSpectrumCollectionByMsLevel(
+              getMsRunId(), handler, ms_level);
+        }
     }
 
   catch(ExceptionInterrupted &)
@@ -449,74 +571,6 @@ TimsMsRunReader::readSpectrumCollectionByMsLevel(
 std::size_t
 TimsMsRunReader::spectrumListSize() const
 {
-  return msp_timsData->getTotalNumberOfScans();
+  return msp_timsData->getTotalScanCount();
 }
 
-
-bool
-TimsMsRunReader::hasScanNumbers() const
-{
-  return false;
-}
-
-
-bool
-TimsMsRunReader::releaseDevice()
-{
-  msp_timsData = nullptr;
-  return true;
-}
-
-bool
-TimsMsRunReader::acquireDevice()
-{
-  if(msp_timsData == nullptr)
-    {
-      initialize();
-    }
-  return true;
-}
-
-
-XicCoordSPtr
-TimsMsRunReader::newXicCoordSPtrFromSpectrumIndex(std::size_t spectrum_index
-                                                  [[maybe_unused]],
-                                                  pappso::PrecisionPtr precision
-                                                  [[maybe_unused]]) const
-{
-  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
-                                  .arg(__FILE__)
-                                  .arg(__FUNCTION__)
-                                  .arg(__LINE__));
-}
-
-XicCoordSPtr
-TimsMsRunReader::newXicCoordSPtrFromQualifiedMassSpectrum(
-  const pappso::QualifiedMassSpectrum &mass_spectrum [[maybe_unused]],
-  pappso::PrecisionPtr precision [[maybe_unused]]) const
-{
-  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
-                                  .arg(__FILE__)
-                                  .arg(__FUNCTION__)
-                                  .arg(__LINE__));
-}
-
-TimsDataSp
-TimsMsRunReader::getTimsDataSPtr()
-{
-  acquireDevice();
-  return msp_timsData;
-}
-
-
-Trace
-TimsMsRunReader::getTicChromatogram()
-{
-  // Use the Sqlite database to fetch the total ion current chromatogram (TIC
-  // chromatogram).
-
-  acquireDevice();
-
-  // The time unit here is seconds, not minutes!!!
-  return msp_timsData->getTicChromatogram();
-}
