@@ -28,13 +28,12 @@
 
 #pragma once
 
-#include "../../msfile/msfileaccessor.h"
-#include "../../vendors/tims/timsdata.h"
+#include "timsmsrunreaderbase.h"
 
 namespace pappso
 {
 
-class PMSPP_LIB_DECL TimsMsRunReader : public MsRunReader
+class PMSPP_LIB_DECL TimsMsRunReader : public TimsMsRunReaderBase
 {
   friend class MsFileAccessor;
   /**
@@ -42,6 +41,8 @@ class PMSPP_LIB_DECL TimsMsRunReader : public MsRunReader
    */
   public:
   TimsMsRunReader(MsRunIdCstSPtr &msrun_id_csp);
+  TimsMsRunReader(const TimsMsRunReaderBase &msrun_reader_base);
+
   virtual ~TimsMsRunReader();
 
   virtual MassSpectrumSPtr
@@ -64,37 +65,9 @@ class PMSPP_LIB_DECL TimsMsRunReader : public MsRunReader
                                   unsigned int ms_level) override;
 
 
-  virtual pappso::XicCoordSPtr newXicCoordSPtrFromSpectrumIndex(
-    std::size_t spectrum_index, pappso::PrecisionPtr precision) const override;
-
-  virtual pappso::XicCoordSPtr newXicCoordSPtrFromQualifiedMassSpectrum(
-    const pappso::QualifiedMassSpectrum &mass_spectrum,
-    pappso::PrecisionPtr precision) const override;
-
-
   virtual std::size_t spectrumListSize() const override;
 
-  virtual bool hasScanNumbers() const override;
 
-  virtual bool releaseDevice() override;
-
-  virtual bool acquireDevice() override;
-
-
-  /** @brief give an access to the underlying raw data pointer
-   */
-  virtual TimsDataSp getTimsDataSPtr();
-
-  virtual Trace getTicChromatogram() override;
-
-
-  protected:
-  virtual void initialize() override;
-  virtual bool accept(const QString &file_name) const override;
-
-
-  private:
-  TimsDataSp msp_timsData = nullptr;
 };
 
 } // namespace pappso
