@@ -30,12 +30,19 @@
 #include "timsmsrunreaderms2.h"
 #include "../../exception/exceptionnotfound.h"
 #include "../../msrun/xiccoord/xiccoordtims.h"
+#include "../../vendors/tims/timsddaprecursors.h"
 #include <QDebug>
 
 using namespace pappso;
 
 TimsMsRunReaderMs2::TimsMsRunReaderMs2(MsRunIdCstSPtr &msrun_id_csp)
-  : MsRunReader(msrun_id_csp)
+  : TimsMsRunReaderBase(msrun_id_csp)
+{
+  initialize();
+}
+
+TimsMsRunReaderMs2::TimsMsRunReaderMs2(const TimsMsRunReaderBase &msrun_reader_base)
+  : TimsMsRunReaderBase(msrun_reader_base)
 {
   initialize();
 }
@@ -51,7 +58,9 @@ TimsMsRunReaderMs2::~TimsMsRunReaderMs2()
 void
 pappso::TimsMsRunReaderMs2::initialize()
 {
-  msp_timsData = std::make_shared<TimsData>(mcsp_msRunId.get()->getFileName());
+  if(msp_timsData == nullptr)
+    msp_timsData =
+      std::make_shared<TimsData>(mcsp_msRunId.get()->getFileName());
 
   if(msp_timsData == nullptr)
     {
@@ -60,21 +69,23 @@ pappso::TimsMsRunReaderMs2::initialize()
                     "msp_timsData is null for MsRunId %1")
           .arg(mcsp_msRunId.get()->toString()));
     }
+
+  mp_timsDdaPrecursors = msp_timsData.get()->getTimsDdaPrecursorsPtr();
 }
 
 void
 TimsMsRunReaderMs2::setMs2BuiltinCentroid(bool centroid)
 {
   m_builtinMs2Centroid = centroid;
-  if(msp_timsData != nullptr)
+  if(mp_timsDdaPrecursors != nullptr)
     {
-      msp_timsData->setMs2BuiltinCentroid(m_builtinMs2Centroid);
+      mp_timsDdaPrecursors->setMs2BuiltinCentroid(m_builtinMs2Centroid);
     }
   else
     {
       throw PappsoException(
         QObject::tr("ERROR in TimsMsRunReaderMs2::setMs2BuiltinCentroid "
-                    "msp_timsData is null"));
+                    "mp_timsDdaPrecursors is null"));
     }
 }
 
@@ -82,15 +93,15 @@ void
 TimsMsRunReaderMs2::setMs2FilterCstSPtr(pappso::FilterInterfaceCstSPtr filter)
 {
   msp_ms2Filter = filter;
-  if(msp_timsData != nullptr)
+  if(mp_timsDdaPrecursors != nullptr)
     {
-      msp_timsData->setMs2FilterCstSPtr(msp_ms2Filter);
+      mp_timsDdaPrecursors->setMs2FilterCstSPtr(msp_ms2Filter);
     }
   else
     {
       throw PappsoException(
         QObject::tr("ERROR in TimsMsRunReaderMs2::setMs2FilterCstSPtr "
-                    "msp_timsData is null"));
+                    "mp_timsDdaPrecursors is null"));
     }
 }
 
@@ -98,9 +109,9 @@ void
 TimsMsRunReaderMs2::setMs1FilterCstSPtr(pappso::FilterInterfaceCstSPtr filter)
 {
   msp_ms1Filter = filter;
-  if(msp_timsData != nullptr)
+  if(mp_timsDdaPrecursors != nullptr)
     {
-      msp_timsData->setMs1FilterCstSPtr(filter);
+      mp_timsDdaPrecursors->setMs1FilterCstSPtr(filter);
     }
   else
     {
@@ -111,9 +122,9 @@ TimsMsRunReaderMs2::setMs1FilterCstSPtr(pappso::FilterInterfaceCstSPtr filter)
 }
 
 bool
-TimsMsRunReaderMs2::accept(const QString &file_name) const
+TimsMsRunReaderMs2::accept(const QString &file_name [[maybe_unused]]) const
 {
-  qDebug() << file_name;
+  // qDebug() << file_name;
   return true;
 }
 
@@ -142,11 +153,11 @@ TimsMsRunReaderMs2::qualifiedMassSpectrum(std::size_t spectrum_index,
 {
 
   std::size_t precursor_index = (spectrum_index / 2) + 1;
-  TimsData::SpectrumDescr spectrum_descr;
+  TimsDdaPrecursors::SpectrumDescr spectrum_descr;
   try
     {
       spectrum_descr =
-        msp_timsData.get()->getSpectrumDescrWithPrecursorId(precursor_index);
+        mp_timsDdaPrecursors->getSpectrumDescrWithPrecursorId(precursor_index);
     }
   catch(ExceptionNotFound &error)
     {
@@ -159,23 +170,23 @@ TimsMsRunReaderMs2::qualifiedMassSpectrum(std::size_t spectrum_index,
 
   if(spectrum_index % 2 == 0)
     {
-      qDebug() << "MS1 spectrum precursor_index=" << precursor_index;
+      // qDebug() << "MS1 spectrum precursor_index=" << precursor_index;
       // this is an MS1 spectrum
       QualifiedMassSpectrum mass_spectrum_ms1;
-      msp_timsData->getQualifiedMs1MassSpectrumByPrecursorId(
+      mp_timsDdaPrecursors->getQualifiedMs1MassSpectrumBySpectrumDescr(
         getMsRunId(), mass_spectrum_ms1, spectrum_descr, want_binary_data);
-      qDebug(); // << mass_spectrum_ms1.toString();
+      // qDebug(); // << mass_spectrum_ms1.toString();
 
       // qDebug() << mass_spectrum_ms1.getMassSpectrumSPtr().get()->toString();
       return mass_spectrum_ms1;
     }
   else
     {
-      qDebug() << "MS2 spectrum precursor_index=" << precursor_index;
+      // qDebug() << "MS2 spectrum precursor_index=" << precursor_index;
       QualifiedMassSpectrum mass_spectrum_ms2;
       if(spectrum_descr.ms2_index != spectrum_index)
         {
-          qDebug();
+          // qDebug();
           throw PappsoException(
             QObject::tr("ERROR in %1 %2 %3 spectrum_descr.ms2_index(%4) != "
                         "spectrum_index(%5)")
@@ -186,9 +197,9 @@ TimsMsRunReaderMs2::qualifiedMassSpectrum(std::size_t spectrum_index,
               .arg(spectrum_index));
         }
 
-      msp_timsData->getQualifiedMs2MassSpectrumByPrecursorId(
+      mp_timsDdaPrecursors->getQualifiedMs2MassSpectrumBySpectrumDescr(
         getMsRunId(), mass_spectrum_ms2, spectrum_descr, want_binary_data);
-      qDebug(); // << mass_spectrum_ms2.toString();
+      // qDebug() << mass_spectrum_ms2.toString();
 
       // qDebug() << mass_spectrum_ms2.getMassSpectrumSPtr().get()->toString();
       return mass_spectrum_ms2;
@@ -215,7 +226,7 @@ void
 TimsMsRunReaderMs2::readSpectrumCollectionByMsLevel(
   SpectrumCollectionHandlerInterface &handler, unsigned int ms_level)
 {
-  qDebug() << " ms_level=" << ms_level;
+  // qDebug() << " ms_level=" << ms_level;
   // We'll need it to perform the looping in the spectrum list.
   std::size_t spectrum_list_size = spectrumListSize();
 
@@ -225,9 +236,9 @@ TimsMsRunReaderMs2::readSpectrumCollectionByMsLevel(
   // the user.
   handler.spectrumListHasSize(spectrum_list_size);
 
-  msp_timsData.get()->setMonoThread(isMonoThread());
+  mp_timsDdaPrecursors->setMonoThread(isMonoThread());
 
-  msp_timsData.get()->ms2ReaderSpectrumCollectionByMsLevel(
+  mp_timsDdaPrecursors->ms2ReaderSpectrumCollectionByMsLevel(
     getMsRunId(), handler, ms_level);
 
   // Now let the loading handler know that the loading of the data has ended.
@@ -242,7 +253,7 @@ TimsMsRunReaderMs2::readSpectrumCollectionByMsLevel(
 std::size_t
 TimsMsRunReaderMs2::spectrumListSize() const
 {
-  return (msp_timsData->getTotalNumberOfPrecursors() * 2);
+  return (mp_timsDdaPrecursors->getTotalPrecursorCount() * 2);
 }
 
 
@@ -266,9 +277,9 @@ TimsMsRunReaderMs2::acquireDevice()
   if(msp_timsData == nullptr)
     {
       initialize();
-      msp_timsData->setMs2BuiltinCentroid(m_builtinMs2Centroid);
-      msp_timsData->setMs1FilterCstSPtr(msp_ms1Filter);
-      msp_timsData->setMs2FilterCstSPtr(msp_ms2Filter);
+      mp_timsDdaPrecursors->setMs2BuiltinCentroid(m_builtinMs2Centroid);
+      mp_timsDdaPrecursors->setMs1FilterCstSPtr(msp_ms1Filter);
+      mp_timsDdaPrecursors->setMs2FilterCstSPtr(msp_ms2Filter);
     }
   return true;
 }
@@ -279,7 +290,8 @@ pappso::TimsMsRunReaderMs2::getPrecursorsIDFromMzRt(int charge,
                                                     double rt_sec,
                                                     double k0)
 {
-  return msp_timsData->getPrecursorsFromMzRtCharge(charge, mz_val, rt_sec, k0);
+  return mp_timsDdaPrecursors->getPrecursorsByMzRtCharge(
+    charge, mz_val, rt_sec, k0);
 }
 
 pappso::TimsDataSp
@@ -296,8 +308,9 @@ TimsMsRunReaderMs2::newXicCoordSPtrFromSpectrumIndex(
 {
   XicCoordTimsSPtr xic_coord  = std::make_shared<XicCoordTims>();
   std::size_t precursor_index = (spectrum_index / 2) + 1;
-  auto xic = this->msp_timsData.get()->getXicCoordTimsFromPrecursorId(
-    precursor_index, precision);
+  auto xic                    = this->msp_timsData.get()
+               ->getTimsDdaPrecursorsPtr()
+               ->getXicCoordTimsFromPrecursorId(precursor_index, precision);
 
   xic_coord.get()->mzRange      = xic.mzRange;
   xic_coord.get()->rtTarget     = xic.rtTarget;
@@ -320,7 +333,7 @@ TimsMsRunReaderMs2::newXicCoordSPtrFromQualifiedMassSpectrum(
 std::vector<double>
 pappso::TimsMsRunReaderMs2::getRetentionTimeLine()
 {
-  return msp_timsData.get()->getRetentionTimeLine();
+  return msp_timsData.get()->getRetentionTimeLineInSeconds();
 }
 
 Trace
