@@ -30,15 +30,12 @@
 #pragma once
 
 #include "../../types.h"
-#include "../../msfile/msfileaccessor.h"
-#include "../../vendors/tims/timsdata.h"
-
-#include "../../exportinmportconfig.h"
+#include "timsmsrunreaderbase.h"
 
 namespace pappso
 {
 
-class PMSPP_LIB_DECL TimsMsRunReaderMs2 : public MsRunReader
+class PMSPP_LIB_DECL TimsMsRunReaderMs2 : public TimsMsRunReaderBase
 {
   friend class MsFileAccessor;
   /**
@@ -46,6 +43,7 @@ class PMSPP_LIB_DECL TimsMsRunReaderMs2 : public MsRunReader
    */
   public:
   TimsMsRunReaderMs2(MsRunIdCstSPtr &msrun_id_csp);
+  TimsMsRunReaderMs2(const TimsMsRunReaderBase &msrun_reader_base);
   virtual ~TimsMsRunReaderMs2();
 
   virtual MassSpectrumSPtr
@@ -114,6 +112,7 @@ class PMSPP_LIB_DECL TimsMsRunReaderMs2 : public MsRunReader
   protected:
   virtual void initialize() override;
   virtual bool accept(const QString &file_name) const override;
+  TimsDdaPrecursors *mp_timsDdaPrecursors = nullptr;
 
   private:
   TimsDataSp msp_timsData = nullptr;
