@@ -29,6 +29,7 @@
 
 #include "timsmsrunreaderms2selected.h"
 #include "../../exception/exceptionnotimplemented.h"
+#include "../../vendors/tims/timsddaprecursors.h"
 #include <QDebug>
 #include <QtConcurrent>
 
@@ -53,21 +54,23 @@ void
 pappso::TimsMsRunReaderMs2Selected::initialize()
 {
   mpa_timsData = new TimsData(mcsp_msRunId.get()->getFileName());
+
+  mp_timsDdaPrecursors = mpa_timsData->getTimsDdaPrecursorsPtr();
 }
 
 void
 TimsMsRunReaderMs2Selected::setMs2FilterCstSPtr(
   pappso::FilterInterfaceCstSPtr filter)
 {
-  if(mpa_timsData != nullptr)
+  if(mp_timsDdaPrecursors != nullptr)
     {
-      mpa_timsData->setMs2FilterCstSPtr(filter);
+      mp_timsDdaPrecursors->setMs2FilterCstSPtr(filter);
     }
   else
     {
       throw PappsoException(
         QObject::tr("ERROR in TimsMsRunReaderMs2Selected::setMs2FilterCstSPtr "
-                    "mpa_timsData is null"));
+                    "mp_timsDdaPrecursors is null"));
     }
 }
 
@@ -75,15 +78,15 @@ void
 TimsMsRunReaderMs2Selected::setMs1FilterCstSPtr(
   pappso::FilterInterfaceCstSPtr filter)
 {
-  if(mpa_timsData != nullptr)
+  if(mp_timsDdaPrecursors != nullptr)
     {
-      mpa_timsData->setMs1FilterCstSPtr(filter);
+      mp_timsDdaPrecursors->setMs1FilterCstSPtr(filter);
     }
   else
     {
       throw PappsoException(
         QObject::tr("ERROR in TimsMsRunReaderMs2Selected::setMs1FilterCstSPtr "
-                    "mpa_timsData is null"));
+                    "mp_timsDdaPrecursors is null"));
     }
 }
 
@@ -120,15 +123,15 @@ TimsMsRunReaderMs2Selected::qualifiedMassSpectrum(std::size_t spectrum_index,
 
   std::size_t precursor_index = (spectrum_index / 2) + 1;
 
-  TimsData::SpectrumDescr spectrum_descr =
-    mpa_timsData->getSpectrumDescrWithPrecursorId(precursor_index);
+  TimsDdaPrecursors::SpectrumDescr spectrum_descr =
+    mp_timsDdaPrecursors->getSpectrumDescrWithPrecursorId(precursor_index);
 
   if(spectrum_index % 2 == 0)
     {
       qDebug();
       // this is an MS1 spectrum
       QualifiedMassSpectrum mass_spectrum_ms1;
-      mpa_timsData->getQualifiedMs1MassSpectrumByPrecursorId(
+      mp_timsDdaPrecursors->getQualifiedMs1MassSpectrumBySpectrumDescr(
         getMsRunId(), mass_spectrum_ms1, spectrum_descr, want_binary_data);
       qDebug(); // << mass_spectrum_ms1.toString();
 
@@ -149,7 +152,7 @@ TimsMsRunReaderMs2Selected::qualifiedMassSpectrum(std::size_t spectrum_index,
               .arg(__FUNCTION__)
               .arg(__LINE__));
         }
-      mpa_timsData->getQualifiedMs2MassSpectrumByPrecursorId(
+      mp_timsDdaPrecursors->getQualifiedMs2MassSpectrumBySpectrumDescr(
         getMsRunId(), mass_spectrum_ms2, spectrum_descr, want_binary_data);
       qDebug(); // << mass_spectrum_ms2.toString();
 
@@ -315,7 +318,7 @@ TimsMsRunReaderMs2Selected::readSpectrumCollection2(
 std::size_t
 TimsMsRunReaderMs2Selected::spectrumListSize() const
 {
-  return (mpa_timsData->getTotalNumberOfPrecursors() * 2);
+  return (mp_timsDdaPrecursors->getTotalPrecursorCount() * 2);
 }
 
 
