@@ -181,13 +181,13 @@ class PMSPP_LIB_DECL MsRunReaderTicChromatogram
 };
 
 
-/** @brief store all qualified spectrum into a vector */
-class PMSPP_LIB_DECL MsRunReaderQualifiedSpectrumList
+/** @brief Load all qualified spectrum into a vector */
+class PMSPP_LIB_DECL MsRunQualifiedSpectrumLoader
   : public SpectrumCollectionHandlerInterface
 {
   public:
-  MsRunReaderQualifiedSpectrumList();
-  virtual ~MsRunReaderQualifiedSpectrumList();
+  MsRunQualifiedSpectrumLoader();
+  virtual ~MsRunQualifiedSpectrumLoader();
   virtual void setQualifiedMassSpectrum(
     const QualifiedMassSpectrum &qualified_mass_spectrum) override;
   virtual bool needPeakList() const override;
