@@ -29,6 +29,7 @@
 
 
 #include <QObject>
+#include <QVariant>
 
 #include "xiccoordtims.h"
 #include "../../exception/exceptionnotpossible.h"
@@ -148,5 +149,34 @@ XicCoordTims::toString() const
     .arg(scanNumEnd);
 }
 
-} // namespace pappso
 
+const QVariant
+XicCoordTims::getParam(XicCoordParam param) const
+{
+  switch(param)
+    {
+      case XicCoordParam::TimsTofIonMobilityScanNumberStart:
+        return QVariant((quint64)scanNumBegin);
+        break;
+      case XicCoordParam::TimsTofIonMobilityScanNumberStop:
+        return QVariant((quint64)scanNumEnd);
+        break;
+      default:
+        return QVariant();
+    }
+}
+void
+XicCoordTims::scanNumBeginRangeCorrection(long start_dev, long stop_dev)
+{
+  long begin = scanNumBegin + start_dev;
+  long end   = scanNumEnd + stop_dev;
+  if(begin < 0)
+    scanNumBegin = 0;
+  else
+    scanNumBegin = begin;
+  if(end < 0)
+    scanNumEnd = 0;
+  else
+    scanNumEnd = end;
+}
+} // namespace pappso
