@@ -39,7 +39,7 @@ initMyResource()
 namespace pappso
 {
 
-QRegularExpression OboPsiModTerm::m_firstParse("^([a-z,A-Z]+):\\s(.*)$");
+QRegularExpression OboPsiModTerm::m_firstParse("^([a-z,A-Z,_]+):\\s(.*)$");
 QRegularExpression OboPsiModTerm::m_findExactPsiModLabel(
   "^(.*)\\sEXACT\\sPSI-MOD-label\\s\\[\\]$");
 
@@ -63,9 +63,12 @@ OboPsiModTerm::OboPsiModTerm(const OboPsiModTerm &other)
   m_psiModLabel = other.m_psiModLabel;
   m_psiMsLabel  = other.m_psiMsLabel;
   m_diffFormula = other.m_diffFormula;
+  m_formula     = other.m_formula;
   m_origin      = other.m_origin;
 
   m_diffMono = other.m_diffMono;
+  m_massMono = other.m_massMono;
+  m_isA      = other.m_isA;
 }
 
 OboPsiModTerm &
@@ -80,6 +83,8 @@ OboPsiModTerm::operator=(const OboPsiModTerm &other)
   m_origin      = other.m_origin;
 
   m_diffMono = other.m_diffMono;
+  m_massMono = other.m_massMono;
+  m_isA      = other.m_isA;
   return *this;
 }
 
@@ -90,11 +95,18 @@ OboPsiModTerm::isValid() const
   return (!m_accession.isEmpty());
 }
 
+bool
+OboPsiModTerm::isA(const QString &accession) const
+{
+  return m_isA.contains(accession);
+}
+
 void
 OboPsiModTerm::parseLine(const QString &line)
 {
   // qDebug() << "OboPsiModTerm::parseLine begin " << line;
-  // id: MOD:00007
+  //  id: MOD:00007
+  //  is_a: MOD:01441 ! natural, standard, encoded residue
   QRegularExpressionMatch match_line = m_firstParse.match(line);
   if(match_line.hasMatch())
     {
@@ -110,6 +122,11 @@ OboPsiModTerm::parseLine(const QString &line)
           m_name = pline[2].trimmed();
           // qDebug() << "OboPsiModTerm::parseLine accession = " << m_accession;
         }
+      else if(pline[1] == "is_a")
+        {
+          m_isA << pline[2].section(" ", 0, 0);
+          // qDebug() << "OboPsiModTerm::parseLine is_a = " << m_isA.join(" ");
+        }
       else if(pline[1] == "xref")
         {
           // xref: DiffMono: "1.007276"
@@ -129,6 +146,12 @@ OboPsiModTerm::parseLine(const QString &line)
                   // qDebug() << "OboPsiModTerm::parseLine m_diffFormula = |" <<
                   // m_diffFormula<<"|";
                 }
+              else if(psecond[1] == "Formula")
+                {
+                  m_formula = psecond[2].trimmed().replace("\"", "");
+                  // qDebug() << "OboPsiModTerm::parseLine m_diffFormula = |" <<
+                  // m_diffFormula<<"|";
+                }
               else if(psecond[1] == "Origin")
                 {
                   m_origin =
@@ -136,6 +159,20 @@ OboPsiModTerm::parseLine(const QString &line)
                   // qDebug() << "OboPsiModTerm::parseLine m_diffFormula = |" <<
                   // m_diffFormula<<"|";
                 }
+              // xref: MassMono: "71.037114"
+
+              else if(psecond[1] == "MassMono")
+                {
+                  bool is_ok = false;
+                  double mass_mono =
+                    psecond[2].replace("\"", "").toDouble(&is_ok);
+                  if(is_ok)
+                    m_massMono = mass_mono;
+                  else
+                    m_massMono = 0;
+                  // qDebug() << "OboPsiModTerm::parseLine m_diffFormula = |" <<
+                  // m_diffFormula<<"|";
+                }
             }
         }
       else if(pline[1] == "synonym")
@@ -181,6 +218,8 @@ OboPsiModTerm::clearTerm()
   m_diffFormula = "";
   m_diffMono    = 0;
   m_origin      = "";
+  m_massMono    = 0;
+  m_isA.clear();
 }
 
 } // namespace pappso
