@@ -20,13 +20,13 @@ namespace pappso
 
 IntegrationScopeRhomb::IntegrationScopeRhomb() : IntegrationScopeBase()
 {
-  qDebug() << "Constructing" << this;
+  // qDebug() << "Constructing" << this;
 }
 
 IntegrationScopeRhomb::IntegrationScopeRhomb(const std::vector<QPointF> &points)
   : m_points(points)
 {
-  qDebug() << "Constructing" << this << "with" << m_points.size() << "points.";
+  // qDebug() << "Constructing" << this << "with" << m_points.size() << "points.";
 }
 
 IntegrationScopeRhomb::IntegrationScopeRhomb(const std::vector<QPointF> &points,
@@ -37,9 +37,9 @@ IntegrationScopeRhomb::IntegrationScopeRhomb(const std::vector<QPointF> &points,
     m_dataKindX(data_kind_x),
     m_dataKindY(data_kind_y)
 {
-  qDebug() << "Constructing" << this << "with" << m_points.size() << "points."
-           << "data_kind_x:" << static_cast<int>(data_kind_x)
-           << "data_kind_y:" << static_cast<int>(data_kind_y);
+  // qDebug() << "Constructing" << this << "with" << m_points.size() << "points."
+  //          << "data_kind_x:" << static_cast<int>(data_kind_x)
+  //          << "data_kind_y:" << static_cast<int>(data_kind_y);
 }
 IntegrationScopeRhomb::IntegrationScopeRhomb(const IntegrationScopeRhomb &other)
   : IntegrationScopeBase(),
@@ -51,7 +51,7 @@ IntegrationScopeRhomb::IntegrationScopeRhomb(const IntegrationScopeRhomb &other)
 
 IntegrationScopeRhomb::~IntegrationScopeRhomb()
 {
-  qDebug() << "Destructing" << this;
+  // qDebug() << "Destructing" << this;
 }
 
 IntegrationScopeRhomb &
@@ -711,20 +711,20 @@ IntegrationScopeRhomb::getWidth(double &width) const
   // As visible here, the fixed size of the rhomboid (using the S key in the
   // plot widget) is the *vertical* side (this is the plot context's
   // m_integrationScopeRhombHeight). In this case the width of the scope is 0.
-  
+
   // The width of the rhomboid is the entire span that it has on the x axis.
-  
+
   QPointF left_most_point;
   QPointF right_most_point;
-  
+
   if(!getLeftMostPoint(left_most_point))
    qFatal("Failed to get the left most point.");
- 
+
  if(!getRightMostPoint(right_most_point))
   qFatal("Failed to get the right most point.");
- 
+
  width = fabs(right_most_point.x() - left_most_point.x());
- 
+
  return IntegrationScopeFeatures::SUCCESS;
 }
 
@@ -732,23 +732,23 @@ IntegrationScopeFeatures
 IntegrationScopeRhomb::getHeight(double &height) const
 {
   // See getWidth() for explanations.
- 
+
  if(m_points.size() < 4)
   qFatal("The IntegrationScopeRhomb has less than four points.");
- 
+
  // The height of the rhomboid is the entire span that it has on the y axis.
 
  QPointF top_most_point;
  QPointF bottom_most_point;
- 
+
  if(!getTopMostPoint(top_most_point))
   qFatal("Failed to get the top most point.");
- 
+
  if(!getBottomMostPoint(bottom_most_point))
   qFatal("Failed to get the bottom most point.");
- 
+
  height = fabs(top_most_point.y() - bottom_most_point.y());
- 
+
  return IntegrationScopeFeatures::SUCCESS;
 }
 
@@ -757,9 +757,9 @@ IntegrationScopeRhomb::getRhombHorizontalSize(double &size) const
 {
  if(m_points.size() < 4)
   qFatal("The IntegrationScopeRhomb has less than four points.");
- 
+
  // There are two kinds of rhomboid integration scopes:
- 
+
  /*
   *              4 +-----------+3
   *                |          |
@@ -772,14 +772,14 @@ IntegrationScopeRhomb::getRhombHorizontalSize(double &size) const
   *    1+----------+2
   *     ----width---
   */
- 
+
  // As visible here, the fixed size of the rhomboid (using the S key in the
  // plot widget) is the *horizontal* side (this is the plot context's
  // m_integrationScopeRhombWidth). In this case the height of the scope is 0.
- 
+
  // and
- 
- 
+
+
  /*
   *                                       +3
   *                                     . |
@@ -796,39 +796,39 @@ IntegrationScopeRhomb::getRhombHorizontalSize(double &size) const
   *                      1+
   *
   */
- 
+
  // As visible here, the fixed size of the rhomboid (using the S key in the
  // plot widget) is the *vertical* side (this is the plot context's
  // m_integrationScopeRhombHeight). In this case the width of the scope is 0.
- 
+
  // In this function we need to establish what kind of rhomboid (horizontal or
  // vertical) we are dealing with.
- 
+
  // If the scope is horizontal, then two points of same y value (either top or
  // bottom) have different x values. That is, leftmost top point has the same y
  // value as the rightmost top point. Similarly, the leftmost bottom point has
  // the same y value as the rightmost bottom point.
- 
+
  // If the scope is vertical, then there is only one single point that has the
  // greatest y value. Likewise, there is only one single point having the
  // smallest y value. Conversely, there are going to be two points of differing
  // y values having the same x value (2 leftmost points and two rightmost
  // points).
- 
+
  std::vector<QPointF> points;
- 
+
  // First get the top most point, we'll use the y value to check if there is
  // only one point sharing that value or not.
- 
- qDebug() << "The rhomboid integration scope:" << toString();
- 
+
+ // qDebug() << "The rhomboid integration scope:" << toString();
+
  IntegrationScopeFeatures scope_features = getTopMostPoints(points);
- 
+
  if(scope_features == IntegrationScopeFeatures::FAILURE)
   qFatal("Failed to get top most points.");
- 
- qDebug() << "getTopMostPoints() got" << points.size() << "points.";
- 
+
+ // qDebug() << "getTopMostPoints() got" << points.size() << "points.";
+
  if(scope_features & IntegrationScopeFeatures::FLAT_ON_X_AXIS)
  {
   // Do not change anything to the width passed as parameter.
@@ -845,7 +845,7 @@ IntegrationScopeRhomb::getRhombHorizontalSize(double &size) const
   // We are dealing with a vertical rhomboid.
   size = 0;
  }
- 
+
  return scope_features;
 }
 
@@ -853,32 +853,32 @@ IntegrationScopeFeatures
 IntegrationScopeRhomb::getRhombVerticalSize(double &size) const
 {
  // See getRhombHorizontalSize() for explanations.
- 
+
  // If the scope is horizontal, then two points of same y value (either top or
  // bottom) have different x values. That is, leftmost top point has the same y
  // value as the rightmost top point. Similarly, the leftmost bottom point has
  // the same y value as the rightmost bottom point.
- 
+
  // If the scope is vertical, then there is only one single point that has the
  // greatest y value. Likewise, there is only one single point having the
  // smallest y value. Conversely, there are going to be two points of differing
  // y values having the same x value (2 leftmost points and two rightmost
  // points).
- 
+
  std::vector<QPointF> points;
- 
+
  // Get the leftmost points (there are going to be 1 or 2 points in the
  // vector depending on the kind of rhomboid.
- 
- qDebug() << "The rhomboid integration scope:" << toString();
- 
+
+ // qDebug() << "The rhomboid integration scope:" << toString();
+
  IntegrationScopeFeatures scope_features = getLeftMostPoints(points);
- 
+
  if(scope_features == IntegrationScopeFeatures::FAILURE)
   qFatal("Failed to get left most points.");
- 
- qDebug() << "getLeftMostPoints() got" << points.size() << "points.";
- 
+
+ // qDebug() << "getLeftMostPoints() got" << points.size() << "points.";
+
  if(scope_features & IntegrationScopeFeatures::FLAT_ON_Y_AXIS)
  {
   // Do not change anything to the width passed as parameter.
@@ -894,7 +894,7 @@ IntegrationScopeRhomb::getRhombVerticalSize(double &size) const
   // gotten 2 points.
   size = fabs(points.at(0).y() - points.at(1).y());
  }
- 
+
  return scope_features;
 }
 
@@ -1051,9 +1051,9 @@ IntegrationScopeRhomb::toString() const
 
 #if 0
 
-  // This version is bad because it has reentrancy problems: it might be 
-  // called by functions that are actually called in turn here. 
-  
+  // This version is bad because it has reentrancy problems: it might be
+  // called by functions that are actually called in turn here.
+
   // First the bottom points pair
   getLeftMostBottomPoint(point);
   text.append(QString("(%1, %2)").arg(point.x()).arg(point.y()));
@@ -1074,8 +1074,8 @@ IntegrationScopeRhomb::toString() const
     text.append(QString("(%1, %2)").arg(point.x()).arg(point.y()));
 
   text.append("]");
-  
-  qDebug() << "Returning toString():" << text;
+
+  // qDebug() << "Returning toString():" << text;
 
   return text;
 }
