@@ -20,10 +20,11 @@ namespace pappso
 
 SelectionPolygon::SelectionPolygon()
 {
-  // When we create a polygon, we create it as immense as possible, so that any
-  // other polygon will fill inside it and *this polygon by necessity will
-  // contain another one based on experimental data. See the header file for the
-  // creation of the four points.
+  // When we create a polygon, we create it as immense as possible, so that 
+ // if this polygon is not modified, any other polygon created on the basis
+ // of experimental data will fit inside it.
+ 
+ // See the definition of the points in the header file.
 }
 
 
@@ -41,6 +42,8 @@ SelectionPolygon::SelectionPolygon(QPointF top_left_point,
   // that specified x range and
   //
   // the widest y range possible.
+  
+  // In other words, we are crafting a 1D selection polygon.
 
   // top left point
   m_points.push_back(
@@ -87,14 +90,14 @@ SelectionPolygon::SelectionPolygon(QPointF top_left_point,
 
 SelectionPolygon::SelectionPolygon(const SelectionPolygon &other)
 {
-  if(other.m_points.size() != static_cast<int>(PointSpecs::ENUM_LAST))
+  if(other.m_points.size() != static_cast<int>(PointSpec::ENUM_LAST))
     qFatal(
       "The template selection polygon must have four points, no less, no more");
 
   // First clear the default values points.
   m_points.clear();
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       m_points.push_back(other.m_points[iter]);
     }
@@ -113,7 +116,7 @@ SelectionPolygon::~SelectionPolygon()
 
 
 void
-SelectionPolygon::setPoint(PointSpecs point_spec, double x, double y)
+SelectionPolygon::setPoint(PointSpec point_spec, double x, double y)
 {
   m_points[static_cast<int>(point_spec)].setX(x);
   m_points[static_cast<int>(point_spec)].setY(y);
@@ -123,7 +126,7 @@ SelectionPolygon::setPoint(PointSpecs point_spec, double x, double y)
 
 
 void
-SelectionPolygon::setPoint(PointSpecs point_spec, QPointF point)
+SelectionPolygon::setPoint(PointSpec point_spec, QPointF point)
 {
   setPoint(point_spec, point.x(), point.y());
 
@@ -132,8 +135,8 @@ SelectionPolygon::setPoint(PointSpecs point_spec, QPointF point)
 
 
 void
-SelectionPolygon::copyPoint(PointSpecs point_spec_src,
-                            PointSpecs point_spec_dest)
+SelectionPolygon::copyPoint(PointSpec point_spec_src,
+                            PointSpec point_spec_dest)
 {
   QPointF src_point = getPoint(point_spec_src);
   setPoint(point_spec_dest, src_point);
@@ -156,19 +159,19 @@ SelectionPolygon::set1D(double x_range_start, double x_range_end)
   resetPoints();
 
   // top left point
-  setPoint(PointSpecs::TOP_LEFT_POINT,
+  setPoint(PointSpec::TOP_LEFT_POINT,
            QPointF(x_range_start, std::numeric_limits<double>::max()));
 
   // top right point
-  setPoint(PointSpecs::TOP_RIGHT_POINT,
+  setPoint(PointSpec::TOP_RIGHT_POINT,
            QPointF(x_range_end, std::numeric_limits<double>::max()));
 
   // bottom right point
-  setPoint(PointSpecs::BOTTOM_RIGHT_POINT,
+  setPoint(PointSpec::BOTTOM_RIGHT_POINT,
            QPointF(x_range_end, std::numeric_limits<double>::min()));
 
   // bottom left point
-  setPoint(PointSpecs::BOTTOM_LEFT_POINT,
+  setPoint(PointSpec::BOTTOM_LEFT_POINT,
            QPointF(x_range_start, std::numeric_limits<double>::min()));
 
   // Compute the min|max x|y coordinates of the polygon that will be used to
@@ -186,19 +189,19 @@ SelectionPolygon::set2D(QPointF top_left,
   resetPoints();
 
   // top left point
-  setPoint(PointSpecs::TOP_LEFT_POINT, top_left);
+  setPoint(PointSpec::TOP_LEFT_POINT, top_left);
   // qDebug() << "PointSpecs::TOP_LEFT_POINT:" << top_left;
 
   // top right point
-  setPoint(PointSpecs::TOP_RIGHT_POINT, top_right);
+  setPoint(PointSpec::TOP_RIGHT_POINT, top_right);
   // qDebug() << "PointSpecs::TOP_RIGHT_POINT:" << top_right;
 
   // bottom right point
-  setPoint(PointSpecs::BOTTOM_RIGHT_POINT, bottom_right);
+  setPoint(PointSpec::BOTTOM_RIGHT_POINT, bottom_right);
   // qDebug() << "PointSpecs::BOTTOM_RIGHT_POINT:" << bottom_right;
 
   // bottom left point
-  setPoint(PointSpecs::BOTTOM_LEFT_POINT, bottom_left);
+  setPoint(PointSpec::BOTTOM_LEFT_POINT, bottom_left);
   // qDebug() << "PointSpecs::BOTTOM_LEFT_POINT:" << bottom_left;
 
   // Compute the min|max x|y coordinates of the polygon that will be used to
@@ -230,7 +233,7 @@ SelectionPolygon::getLeftMostPoint() const
 
   QPointF temp_point(std::numeric_limits<double>::max(), 0);
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       if(m_points[iter].x() < temp_point.x())
         {
@@ -250,7 +253,7 @@ SelectionPolygon::getRightMostPoint() const
 
   QPointF temp_point(std::numeric_limits<double>::min(), 0);
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       if(m_points[iter].x() > temp_point.x())
         {
@@ -270,7 +273,7 @@ SelectionPolygon::getTopMostPoint() const
 
   QPointF temp_point(0, std::numeric_limits<double>::min());
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       if(m_points[iter].y() > temp_point.y())
         {
@@ -290,7 +293,7 @@ SelectionPolygon::getBottomMostPoint() const
 
   QPointF temp_point(0, std::numeric_limits<double>::max());
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       if(m_points[iter].y() < temp_point.y())
         {
@@ -310,7 +313,7 @@ SelectionPolygon::getPoints() const
 
 
 QPointF
-SelectionPolygon::getPoint(PointSpecs point_spec) const
+SelectionPolygon::getPoint(PointSpec point_spec) const
 {
   return m_points[static_cast<int>(point_spec)];
 }
@@ -327,7 +330,7 @@ SelectionPolygon::computeMinMaxCoordinates()
   m_maxX = std::numeric_limits<double>::min();
   m_maxY = std::numeric_limits<double>::min();
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       m_minX = std::min(m_points.at(iter).x(), m_minX);
       m_maxX = std::max(m_points.at(iter).x(), m_maxX);
@@ -354,7 +357,7 @@ SelectionPolygon::computeMinMaxCoordinates(double &min_x,
   max_x = std::numeric_limits<double>::min();
   max_y = std::numeric_limits<double>::min();
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       min_x = std::min(m_points.at(iter).x(), min_x);
       max_x = std::max(m_points.at(iter).x(), max_x);
@@ -452,31 +455,31 @@ SelectionPolygon::transpose() const
 
   // Make sure we do this for a polygon with four sides.
 
-  if(m_points.size() != static_cast<int>(PointSpecs::ENUM_LAST))
+  if(m_points.size() != static_cast<int>(PointSpec::ENUM_LAST))
     qFatal("The polygon must have four points, no less, no more");
 
   // The two invariant points, that is, the two points that do no change
   // position in the polygon corners. Of course, x becomes y.
   selection_polygon.setPoint(
-    PointSpecs::TOP_RIGHT_POINT,
-    QPointF(getPoint(PointSpecs::TOP_RIGHT_POINT).y(),
-            getPoint(PointSpecs::TOP_RIGHT_POINT).x()));
+    PointSpec::TOP_RIGHT_POINT,
+    QPointF(getPoint(PointSpec::TOP_RIGHT_POINT).y(),
+            getPoint(PointSpec::TOP_RIGHT_POINT).x()));
 
   selection_polygon.setPoint(
-    PointSpecs::BOTTOM_LEFT_POINT,
-    QPointF(getPoint(PointSpecs::BOTTOM_LEFT_POINT).y(),
-            getPoint(PointSpecs::BOTTOM_LEFT_POINT).x()));
+    PointSpec::BOTTOM_LEFT_POINT,
+    QPointF(getPoint(PointSpec::BOTTOM_LEFT_POINT).y(),
+            getPoint(PointSpec::BOTTOM_LEFT_POINT).x()));
 
   // The two other points.
 
-  selection_polygon.setPoint(PointSpecs::BOTTOM_RIGHT_POINT,
-                             QPointF(getPoint(PointSpecs::TOP_LEFT_POINT).y(),
-                                     getPoint(PointSpecs::TOP_LEFT_POINT).x()));
+  selection_polygon.setPoint(PointSpec::BOTTOM_RIGHT_POINT,
+                             QPointF(getPoint(PointSpec::TOP_LEFT_POINT).y(),
+                                     getPoint(PointSpec::TOP_LEFT_POINT).x()));
 
   selection_polygon.setPoint(
-    PointSpecs::TOP_LEFT_POINT,
-    QPointF(getPoint(PointSpecs::BOTTOM_RIGHT_POINT).y(),
-            getPoint(PointSpecs::BOTTOM_RIGHT_POINT).x()));
+    PointSpec::TOP_LEFT_POINT,
+    QPointF(getPoint(PointSpec::BOTTOM_RIGHT_POINT).y(),
+            getPoint(PointSpec::BOTTOM_RIGHT_POINT).x()));
 
   return selection_polygon;
 }
@@ -575,9 +578,9 @@ SelectionPolygon::contains(const SelectionPolygon &selection_polygon) const
 
   bool is_inside = true;
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
-      if(!contains(selection_polygon.getPoint(static_cast<PointSpecs>(iter))))
+      if(!contains(selection_polygon.getPoint(static_cast<PointSpec>(iter))))
         is_inside = false;
     }
 
@@ -591,13 +594,13 @@ SelectionPolygon::operator=(const SelectionPolygon &other)
   if(this == &other)
     return *this;
 
-  if(other.m_points.size() != static_cast<int>(PointSpecs::ENUM_LAST))
+  if(other.m_points.size() != static_cast<int>(PointSpec::ENUM_LAST))
     qFatal("Programming error.");
 
-  if(m_points.size() != static_cast<int>(PointSpecs::ENUM_LAST))
+  if(m_points.size() != static_cast<int>(PointSpec::ENUM_LAST))
     qFatal("Programming error.");
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     m_points[iter] = other.m_points[iter];
 
   m_minX = other.m_minX;
@@ -701,19 +704,19 @@ SelectionPolygon::isRectangle() const
 
   // Try the horiontal top|bottom lines.
 
-  if(getPoint(PointSpecs::TOP_LEFT_POINT).y() ==
-       getPoint(PointSpecs::TOP_RIGHT_POINT).y() &&
-     getPoint(PointSpecs::BOTTOM_LEFT_POINT).y() ==
-       getPoint(PointSpecs::BOTTOM_RIGHT_POINT).y())
+  if(getPoint(PointSpec::TOP_LEFT_POINT).y() ==
+       getPoint(PointSpec::TOP_RIGHT_POINT).y() &&
+     getPoint(PointSpec::BOTTOM_LEFT_POINT).y() ==
+       getPoint(PointSpec::BOTTOM_RIGHT_POINT).y())
     {
       // We have horizontal top|bottom lines
 
       // Try the vertical lines
 
-      if(getPoint(PointSpecs::TOP_LEFT_POINT).x() ==
-           getPoint(PointSpecs::BOTTOM_LEFT_POINT).x() &&
-         getPoint(PointSpecs::TOP_RIGHT_POINT).x() ==
-           getPoint(PointSpecs::BOTTOM_RIGHT_POINT).x())
+      if(getPoint(PointSpec::TOP_LEFT_POINT).x() ==
+           getPoint(PointSpec::BOTTOM_LEFT_POINT).x() &&
+         getPoint(PointSpec::TOP_RIGHT_POINT).x() ==
+           getPoint(PointSpec::BOTTOM_RIGHT_POINT).x())
         {
           // The top|bottom lines are vertical
 
@@ -730,14 +733,14 @@ SelectionPolygon::toString() const
 {
   // By essence, a selection polygon is designed to always have 4 points.
 
-  if(m_points.size() != static_cast<int>(PointSpecs::ENUM_LAST))
+  if(m_points.size() != static_cast<int>(PointSpec::ENUM_LAST))
     qFatal("Programming error.");
 
   // qDebug() << "size:" << m_points.size();
 
   QString text = "Selection polygon points, from top left, clockwise\n";
 
-  for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+  for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
     {
       QPointF iter_point = m_points[iter];
 
@@ -789,7 +792,7 @@ SelectionPolygon::toShort4PointsString() const
 {
   // By essence, a selection polygon is designed to always have 4 points.
 
-  if(m_points.size() != static_cast<int>(PointSpecs::ENUM_LAST))
+  if(m_points.size() != static_cast<int>(PointSpec::ENUM_LAST))
     qFatal("Programming error.");
 
   // qDebug() << "size:" << m_points.size();
@@ -812,7 +815,7 @@ SelectionPolygon::toShort4PointsString() const
     }
   else
     {
-      for(int iter = 0; iter < static_cast<int>(PointSpecs::ENUM_LAST); ++iter)
+      for(int iter = 0; iter < static_cast<int>(PointSpec::ENUM_LAST); ++iter)
         {
           QPointF iter_point = m_points[iter];
 
