@@ -27,6 +27,9 @@
 #include "../../exception/exceptionoutofrange.h"
 #include "../../exception/exceptionnotpossible.h"
 
+#include <QObject>
+
+
 namespace pappso
 {
 TraceDetectionZivy::TraceDetectionZivy(
@@ -104,7 +107,8 @@ TraceDetectionZivy::getDetectionThresholdOnMaxmin() const
 
 void
 TraceDetectionZivy::detect(const Trace &xic,
-                           TraceDetectionSinkInterface &sink) const
+                           TraceDetectionSinkInterface &sink,
+                           bool remove_peak_base) const
 {
 
   // detect peak positions on close curve : a peak is an intensity value
@@ -211,7 +215,7 @@ TraceDetectionZivy::detect(const Trace &xic,
               // peak.setMaxXicElement(*maxYDataPoint(it, xic_position));
 
               // areaTrace()
-              TracePeak peak(it, xic_position);
+              TracePeak peak(it, xic_position, remove_peak_base);
               sink.setTracePeak(peak);
               // }
               //++i;
