@@ -85,10 +85,19 @@ pappso::FilterComplementIonEnhancer::buildFilterFromString(
     }
 }
 
+
+QString
+pappso::FilterComplementIonEnhancer::name() const
+{
+  return "complementIonEnhancer";
+}
+
+
 QString
 pappso::FilterComplementIonEnhancer::toString() const
 {
-  QString strCode = QString("complementIonEnhancer|%1;%2")
+  QString strCode = QString("%1|%2;%3")
+                      .arg(name())
                       .arg(QString::number(m_targetMzSum, 'g', 15))
                       .arg(m_precisionPtr->toString());
   strCode.replace(" ", "");
