@@ -247,36 +247,69 @@ FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon()
 
 
 FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon(
-  const SelectionPolygon &selection_polygon, DataKind data_kind)
+  IntegrationScopeBaseSPtr integration_scope_sp, DataKind data_kind)
 {
-  // It is assumed that the selection polygon always has x:MZ and y:DT|RT
-  // depending on the spec data kind.
+  m_integrationScopeSpecs.push_back(
+    IntegrationScopeSpec(integration_scope_sp, data_kind));
 
-  m_selectionPolygonSpecs.push_back(
-    SelectionPolygonSpec(selection_polygon, data_kind));
+  QPointF point;
+  if(!m_integrationScopeSpecs.front().integrationScopeSPtr->getPoint(point))
+    qFatal("Failed to get point.");
+  m_lowestMz = point.y();
 
-  m_lowestMz =
-    m_selectionPolygonSpecs.front().selectionPolygon.getBottomMostPoint().y();
-  m_greatestMz =
-    m_selectionPolygonSpecs.front().selectionPolygon.getTopMostPoint().y();
+  double height;
+  if(!m_integrationScopeSpecs.front().integrationScopeSPtr->getHeight(height))
+    qFatal("Failed to get height.");
+  m_greatestMz = m_lowestMz + height;
 }
 
 
 FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon(
-  const SelectionPolygonSpecVector &selection_polygon_specs)
+  const IntegrationScopeSpecVector &integration_scope_specs)
 {
   // qDebug();
 
-  m_selectionPolygonSpecs.assign(selection_polygon_specs.begin(),
-                                 selection_polygon_specs.end());
+  m_integrationScopeSpecs.assign(integration_scope_specs.begin(),
+                                 integration_scope_specs.end());
 
-  for(auto &&item : m_selectionPolygonSpecs)
+  for(auto &&item : m_integrationScopeSpecs)
     {
-      m_lowestMz =
-        std::min(m_lowestMz, item.selectionPolygon.getBottomMostPoint().y());
+      if(item.integrationScopeSPtr->isRectangle())
+        {
+          // qDebug() << "item is Rectangle.";
 
-      m_greatestMz =
-        std::max(m_greatestMz, item.selectionPolygon.getTopMostPoint().y());
+          QPointF point;
+          if(!item.integrationScopeSPtr->getPoint(point))
+            qFatal("Failed to get point.");
+          m_lowestMz = std::min(m_lowestMz, point.y());
+
+          double height;
+          if(!item.integrationScopeSPtr->getHeight(height))
+            qFatal("Failed to get height.");
+          m_greatestMz = std::max(m_greatestMz, m_lowestMz + height);
+        }
+      else
+        {
+          if(!item.integrationScopeSPtr->isRhomboid())
+            qFatal(
+              "If integration scope is not Rectangle, then it must be "
+              "Rhomboid.");
+
+          // qDebug() << "item is Rhomboid.";
+
+          QPointF point;
+
+          // Because the mz scale is on the coordinate, we ask for
+          // bottom-most and top-most points of the rhomboid polygon.
+
+          if(!item.integrationScopeSPtr->getBottomMostPoint(point))
+            qFatal("Failed to get point.");
+          m_lowestMz = std::min(m_lowestMz, point.y());
+
+          if(!item.integrationScopeSPtr->getTopMostPoint(point))
+            qFatal("Failed to get point.");
+          m_greatestMz = std::max(m_greatestMz, point.y());
+        }
     }
 }
 
@@ -286,36 +319,40 @@ FilterResampleKeepPointInPolygon::FilterResampleKeepPointInPolygon(
 {
   // qDebug();
 
-  m_selectionPolygonSpecs.assign(other.m_selectionPolygonSpecs.begin(),
-                                 other.m_selectionPolygonSpecs.end());
+  m_integrationScopeSpecs.assign(other.m_integrationScopeSpecs.begin(),
+                                 other.m_integrationScopeSpecs.end());
 
-  for(auto &&item : m_selectionPolygonSpecs)
+  for(auto &&item : m_integrationScopeSpecs)
     {
-      m_lowestMz =
-        std::min(m_lowestMz, item.selectionPolygon.getBottomMostPoint().y());
+      QPointF point;
+      if(!item.integrationScopeSPtr->getPoint(point))
+        qFatal("Failed to get point.");
+      m_lowestMz = std::min(m_lowestMz, point.y());
 
-      m_greatestMz =
-        std::max(m_greatestMz, item.selectionPolygon.getTopMostPoint().y());
+      double height;
+      if(!item.integrationScopeSPtr->getHeight(height))
+        qFatal("Failed to get height.");
+      m_greatestMz = std::max(m_greatestMz, m_lowestMz + height);
     }
 }
 
 
 void
 FilterResampleKeepPointInPolygon::newSelectionPolygonSpec(
-  const SelectionPolygonSpec &selection_polygon_spec)
+  const IntegrationScopeSpec &integration_scope_spec)
 {
-  // It is assumed that the selection polygon always has x:MZ and y:DT|RT
-  // depending on the spec data kind.
 
-  m_selectionPolygonSpecs.push_back(selection_polygon_spec);
+  m_integrationScopeSpecs.push_back(integration_scope_spec);
 
-  m_lowestMz = std::min(
-    m_lowestMz,
-    m_selectionPolygonSpecs.back().selectionPolygon.getBottomMostPoint().y());
+  QPointF point;
+  if(!m_integrationScopeSpecs.back().integrationScopeSPtr->getPoint(point))
+    qFatal("Failed to get point.");
+  m_lowestMz = std::min(m_lowestMz, point.y());
 
-  m_greatestMz = std::max(
-    m_greatestMz,
-    m_selectionPolygonSpecs.back().selectionPolygon.getTopMostPoint().y());
+  double height;
+  if(!m_integrationScopeSpecs.back().integrationScopeSPtr->getHeight(height))
+    qFatal("Failed to get height.");
+  m_greatestMz = std::max(m_greatestMz, m_lowestMz + height);
 }
 
 
@@ -326,8 +363,8 @@ FilterResampleKeepPointInPolygon::operator=(
   if(this == &other)
     return *this;
 
-  m_selectionPolygonSpecs.assign(other.m_selectionPolygonSpecs.begin(),
-                                 other.m_selectionPolygonSpecs.end());
+  m_integrationScopeSpecs.assign(other.m_integrationScopeSpecs.begin(),
+                                 other.m_integrationScopeSpecs.end());
 
   m_lowestMz   = other.m_lowestMz;
   m_greatestMz = other.m_greatestMz;
@@ -349,7 +386,7 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
                                          double dt_value,
                                          double rt_value) const
 {
-  // Each time a new selection polygon spec is added, the lowest and greatest
+  // Each time a new integration scope spec is added, the lowest and greatest
   // m/z values are computed. We use these values to remove from the spectrum
   // all the points that are outside of that lowest-gratest range.
 
@@ -358,7 +395,7 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
 
   // Note that the m_lowestMz and m_greatestMz are set during construction of
   // this FilterResampleKeepPointInPolygon filter using the
-  // selection polygon specs.
+  // integration scope specs.
 
   // qDebug() << "The lowest and greatest m/z values:" << m_lowestMz << "and"
   //<< m_greatestMz;
@@ -399,7 +436,7 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
 
       double checked_value;
 
-      for(auto &&spec : m_selectionPolygonSpecs)
+      for(auto &&spec : m_integrationScopeSpecs)
         {
           // qDebug() << "Iterating in selection polygon spec:" <<
           // spec.toString();
@@ -425,118 +462,9 @@ FilterResampleKeepPointInPolygon::filter(Trace &trace,
           // First version doing the whole computation on the basis of the
           // selection polygon's all faces.
           //
-          if(!spec.selectionPolygon.contains(QPointF(checked_value, iter->x)))
+          if(!spec.integrationScopeSPtr->contains(
+               QPointF(checked_value, iter->x)))
             iter = trace.erase(iter);
-
-#if 0 
-
-          //This code does not work because depending on the orientation of the
-            //skewed selection polygon (left bottom to right top or left top to
-                //right bottom or or Or depending on the axes of the
-                //bi-dimensional colormap, requiring transposition or not), the
-            //notion of "left line" and of "right line" changes.
-
-          // Second version checking that point is right of left vertical line
-          // of polygon and left of right vertical line.
-
-          // double res = sideofline(XX;YY;xA;yA;xB;yB) =
-          // (xB-xA) * (YY-yA) - (yB-yA) * (XX-xA)
-
-          // If res == 0, the point is on the line
-          // If rest < 0, the point is on the right of the line
-          // If rest > 0, the point is on the left of the line
-
-          // Left vertical line of the polygon
-
-          // Bottom point
-          double xA_left =
-            spec.selectionPolygon.getPoint(PointSpecs::BOTTOM_LEFT_POINT).x();
-          double yA_left =
-            spec.selectionPolygon.getPoint(PointSpecs::BOTTOM_LEFT_POINT).y();
-
-          // Top point
-          double xB_left =
-            spec.selectionPolygon.getPoint(PointSpecs::TOP_LEFT_POINT).x();
-          double yB_left =
-            spec.selectionPolygon.getPoint(PointSpecs::TOP_LEFT_POINT).y();
-
-          qDebug() << "The left line goes: (" << xA_left << "," << yA_left
-                   << ")->(" << xB_left << "," << yB_left << ")";
-
-          if((xB_left - xA_left) * (iter->x - yA_left) -
-               (yB_left - yA_left) * (checked_value - xA_left) >
-             0)
-            {
-              // The point is left of the left line. We can remove the point
-              // from the mass spectrum.
-
-              qDebug() << qSetRealNumberPrecision(10)
-                       << "Filtered out point (left of left line):"
-                       << checked_value << "-" << iter->x;
-
-              iter = trace.erase(iter);
-
-              // No need to go on with the analysis, just go to the next (that
-              // is, previous, since we iterate backwards) data point.
-
-              continue;
-            }
-          else
-            {
-              qDebug() << qSetRealNumberPrecision(10)
-                       << "Kept point (right of left line):" << checked_value
-                       << "-" << iter->x;
-            }
-
-          // Right vertical line of the polygon
-
-          // Bottom point
-          double xA_right =
-            spec.selectionPolygon.getPoint(PointSpecs::BOTTOM_RIGHT_POINT).x();
-          double yA_right =
-            spec.selectionPolygon.getPoint(PointSpecs::BOTTOM_RIGHT_POINT).y();
-
-          // Top point
-          double xB_right =
-            spec.selectionPolygon.getPoint(PointSpecs::TOP_RIGHT_POINT).x();
-          double yB_right =
-            spec.selectionPolygon.getPoint(PointSpecs::TOP_RIGHT_POINT).y();
-
-          qDebug() << "The right line goes: (" << xA_right << "," << yA_right
-                   << ")->(" << xB_right << "," << yB_right << ")";
-
-          if((xB_right - xA_right) * (iter->x - yA_right) -
-               (yB_right - yA_right) * (checked_value - xA_right) <
-             0)
-            {
-              qDebug() << qSetRealNumberPrecision(10)
-                       << "Filtered out point (right of right line):"
-                       << checked_value << "-" << iter->x;
-
-              // The point is right of the right line. We can remove the point
-              // from the mass spectrum.
-              iter = trace.erase(iter);
-
-              // Here, continue is implicit.
-              // No need to go on with the analysis, just go to the next (that
-              // is, previous, since we iterate backwards) data point.
-              // continue;
-            }
-          else
-            {
-              if(iter->x >= 449 && iter->x <= 450 && checked_value > 19.5 &&
-                 checked_value < 20)
-                qDebug()
-                  << qSetRealNumberPrecision(10)
-                  << "SHOULD NOT Definitively kept point (left of right line):"
-                  << checked_value << "-" << iter->x;
-              else
-                qDebug()
-                  << qSetRealNumberPrecision(10)
-                  << "MIGHT Definitively kept point (left of right line):"
-                  << checked_value << "-" << iter->x;
-            }
-#endif
         }
       // End of
       // for(auto &&spec : m_selectionPolygonSpecs)
