@@ -51,6 +51,10 @@ namespace pappso
   (a)   = (b);     \
   (b)   = tempr
 
+FilterSavitzkyGolay::FilterSavitzkyGolay()
+{
+  // m_params will have defaults that work well with mass spectra.
+}
 
 FilterSavitzkyGolay::FilterSavitzkyGolay(
   int nL, int nR, int m, int lD, bool convolveWithNr)
@@ -73,6 +77,12 @@ FilterSavitzkyGolay::FilterSavitzkyGolay(const SavGolParams sav_gol_params)
 }
 
 
+FilterSavitzkyGolay::FilterSavitzkyGolay(const QString &parameters)
+{
+  buildFilterFromString(parameters);
+}
+
+
 FilterSavitzkyGolay::FilterSavitzkyGolay(const FilterSavitzkyGolay &other)
 {
   // This function only copies the parameters, not the data.
@@ -107,12 +117,6 @@ FilterSavitzkyGolay::operator=(const FilterSavitzkyGolay &other)
 }
 
 
-FilterSavitzkyGolay::FilterSavitzkyGolay(const QString &parameters)
-{
-  buildFilterFromString(parameters);
-}
-
-
 void
 FilterSavitzkyGolay::buildFilterFromString(const QString &parameters)
 {
