@@ -110,6 +110,49 @@ SpectralAlignment::align(PeptideSpectraCsp peptide_spectrum,
     }
 }
 
+PeptideModel
+SpectralAlignment::rtrim(PrecisionPtr precision_ptr)
+{
+  pappso::specglob::PeptideModel model;
+  pappso::specglob::PeptideSpectraCsp ref_peptide = mcsp_peptideSpectrum;
+
+  double precursor_mass = mcsp_experimentalSpectrum.get()->getPrecursorMass();
+  std::size_t start     = 1;
+  int max_score         = m_maxScore;
+  pappso::specglob::PeptideSpectraCsp ref_best_peptide = ref_peptide;
+
+  while(start < ref_peptide.get()->getPeptideSp().get()->size() - 5)
+    {
+      pappso::PeptideSp peptide_sp = std::make_shared<pappso::Peptide>(
+        ref_peptide.get()->getPeptideSp().get()->getSequence().mid(start));
+      std::size_t length = peptide_sp.get()->size();
+      while(peptide_sp.get()->getMass() > (precursor_mass * 1.1))
+        {
+          peptide_sp = std::make_shared<pappso::Peptide>(
+            peptide_sp.get()->getSequence().mid(0, length - 1));
+          if(length > 1)
+            length--;
+        }
+      pappso::specglob::PeptideSpectraCsp peptide_spectra =
+        std::make_shared<pappso::specglob::PeptideSpectrum>(peptide_sp);
+      align(peptide_spectra, mcsp_experimentalSpectrum);
+
+      if(max_score < m_maxScore)
+        {
+          if(m_maxScore > 0)
+            {
+              model = buildPeptideModel();
+              model.eliminateComplementaryDelta(precision_ptr);
+              model.ltrimOnRemoval();
+              max_score        = m_maxScore;
+              ref_best_peptide = mcsp_peptideSpectrum;
+            }
+        }
+      start++;
+    }
+  align(ref_best_peptide, mcsp_experimentalSpectrum);
+  return model;
+}
 
 void
 SpectralAlignment::fillMatricesWithScores(
@@ -133,7 +176,7 @@ SpectralAlignment::fillMatricesWithScores(
 
   switch(expePeakType)
     {
-      case ExperimentalSpectrumDataPointType::symetric:
+      case ExperimentalSpectrumDataPointType::symmetric:
         // this is a symmetric peak
         alignScoreToAdd   = m_scoreValues.get(ScoreValueType::scoreAlignSym);
         reAlignScoreToAdd = m_scoreValues.get(ScoreValueType::scoreReAlignSym);
@@ -341,7 +384,7 @@ SpectralAlignment::fillMassDelta(
             (*itr2).alignment_type = SpectralAlignmentType::nonAlign;
           (*itr2).origin_column_indices = 0;
           (*itr2).score                 = 0;
-          (*itr2).mass_difference = it_spectrum->symetric_mz - it_peptide->mz;
+          (*itr2).mass_difference = it_spectrum->symmetric_mz - it_peptide->mz;
           // qDebug() << " i=" << itr2.index1() << " j=" << itr2.index2()
           //         << " mass_difference=" << (*itr2).mass_difference;
         }
@@ -554,7 +597,7 @@ SpectralAlignment::buildPeptideModel() const
   if(m_maxScore < 1)
     {
       throw pappso::PappsoException(
-        QObject::tr("Spectral alignment failed m_maxScore == %1")
+        QObject::tr("building peptide model failed m_maxScore == %1")
           .arg(m_maxScore));
     }
   PeptideModel sg_peptide_model(
