@@ -366,59 +366,73 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
     }
 
 
-  /*
-   *
-  XtandemInputSaxHandler wrap_input(
-    mzxml_data_file_name, wrapped_tandem_input, wrapped_tandem_output);
-  QFile qfile(tandem_input_file);
-  if(!qfile.exists())
+  if(m_tandemBinary.endsWith("tandemng") ||
+     m_tandemBinary.endsWith("tandemng.exe") ||
+     m_tandemBinary.endsWith("tandemng2015") ||
+     m_tandemBinary.endsWith("tandemng2015.exe") ||
+     m_tandemBinary.endsWith("tandemng2015p") ||
+     m_tandemBinary.endsWith("tandemng2015p.exe"))
     {
-      throw pappso::PappsoException(
-        QObject::tr("Tandem input file %1 does not exists")
-          .arg(QFileInfo(tandem_input_file).absoluteFilePath()));
-    }
-  QXmlInputSource xmlInputSource(&qfile);
-  QXmlSimpleReader simplereader;
-  simplereader.setContentHandler(&wrap_input);
-  simplereader.setErrorHandler(&wrap_input);
-
-  if(simplereader.parse(xmlInputSource))
-    {
-    }
-  else
-    {
-      throw pappso::PappsoException(
-        QObject::tr("Error reading %1 X!Tandem input file :\n %2")
-          .arg(tandem_input_file)
-          .arg(wrap_input.errorString()));
-    }
-*/
-  // get number of threads and centroid parameters from tandem preset
-  readTandemPresetFile(wrap_tandem_input.getOriginalTandemPresetFileName());
-
-
-  // convert to mzXML
-  QString original_msdata_file_name =
-    wrap_tandem_input.getOriginalMsDataFileName();
-  if(convertOrginalMsData2mzXmlData(original_msdata_file_name,
-                                    mzxml_data_file_name))
-    {
-
-
-      // launch tandem
-      runTandem(wrapped_tandem_input);
-
-      // rewrite tandem result file
-      writeFinalTandemOutput(
-        wrapped_tandem_output,
-        wrap_tandem_input.getOriginalTandemOutputFileName(),
-        original_msdata_file_name);
-    }
-  else
-    {
-      // launch tandem on original file
+      // no wrapper
+      //  launch tandem on original file
       runTandem(tandem_input_file);
     }
+  else
+    {
+      /*
+       *
+      XtandemInputSaxHandler wrap_input(
+        mzxml_data_file_name, wrapped_tandem_input, wrapped_tandem_output);
+      QFile qfile(tandem_input_file);
+      if(!qfile.exists())
+        {
+          throw pappso::PappsoException(
+            QObject::tr("Tandem input file %1 does not exists")
+              .arg(QFileInfo(tandem_input_file).absoluteFilePath()));
+        }
+      QXmlInputSource xmlInputSource(&qfile);
+      QXmlSimpleReader simplereader;
+      simplereader.setContentHandler(&wrap_input);
+      simplereader.setErrorHandler(&wrap_input);
+
+      if(simplereader.parse(xmlInputSource))
+        {
+        }
+      else
+        {
+          throw pappso::PappsoException(
+            QObject::tr("Error reading %1 X!Tandem input file :\n %2")
+              .arg(tandem_input_file)
+              .arg(wrap_input.errorString()));
+        }
+    */
+      // get number of threads and centroid parameters from tandem preset
+      readTandemPresetFile(wrap_tandem_input.getOriginalTandemPresetFileName());
+
+
+      // convert to mzXML
+      QString original_msdata_file_name =
+        wrap_tandem_input.getOriginalMsDataFileName();
+      if(convertOrginalMsData2mzXmlData(original_msdata_file_name,
+                                        mzxml_data_file_name))
+        {
+
+
+          // launch tandem
+          runTandem(wrapped_tandem_input);
+
+          // rewrite tandem result file
+          writeFinalTandemOutput(
+            wrapped_tandem_output,
+            wrap_tandem_input.getOriginalTandemOutputFileName(),
+            original_msdata_file_name);
+        }
+      else
+        {
+          // launch tandem on original file
+          runTandem(tandem_input_file);
+        }
+    }
 }
 
 bool
@@ -427,23 +441,23 @@ TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
 {
   qDebug();
   pappso::MsFileAccessor origin_access(origin, "runa1");
-  origin_access.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
-                                          pappso::FileReaderType::tims_ms2);
+  origin_access.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
+                                           pappso::FileReaderType::tims_ms2);
   origin_access.getMsRunIds();
   m_mzFormat = origin_access.getFileFormat();
-  if(m_mzFormat == pappso::MzFormat::unknown)
+  if(m_mzFormat == pappso::MsDataFormat::unknown)
     {
       throw pappso::PappsoException(
         QObject::tr("%1 file format not known").arg(origin));
     }
 
-  if(origin_access.getFileFormat() == pappso::MzFormat::brukerTims)
+  if(origin_access.getFileFormat() == pappso::MsDataFormat::brukerTims)
     {
       m_convertMzDataUsingSpectrumIndex = true;
     }
 
-  if((origin_access.getFileFormat() == pappso::MzFormat::mzML) ||
-     (origin_access.getFileFormat() == pappso::MzFormat::brukerTims))
+  if((origin_access.getFileFormat() == pappso::MsDataFormat::mzML) ||
+     (origin_access.getFileFormat() == pappso::MsDataFormat::brukerTims))
     {
       mp_monitor->setStatus(
         QObject::tr("Converting %1 to mzXML %2").arg(origin).arg(target));
