@@ -33,11 +33,11 @@
 #include <QTemporaryDir>
 #include <QMutex>
 
-#include "../../exportinmportconfig.h"
-#include "../../processing/filters/filtersuitestring.h"
+#include "../filters/filtersuitestring.h"
 #include "../uimonitor/uimonitorinterface.h"
 #include "../../pappsoexception.h"
 #include "../../types.h"
+#include "../../exportinmportconfig.h"
 
 /**
  * @todo write docs
@@ -145,7 +145,7 @@ class PMSPP_LIB_DECL TandemWrapperRun : public QObject
 
   bool m_convertMzDataUsingSpectrumIndex = false;
 
-  pappso::MzFormat m_mzFormat = pappso::MzFormat::unknown;
+  pappso::MsDataFormat m_mzFormat = pappso::MsDataFormat::unknown;
 
   qint64 m_conversionTime = 0;
 };
