@@ -157,7 +157,8 @@ Protein::getMass() const
       // it is not perfect)
       QString sequence(m_sequence);
       sequence.replace(QRegularExpression("[^WGASPVTLINDKQEMHFRCYUBZX]"), "");
-      pappso::Peptide peptide(sequence.replace(QRegularExpression("[BZX]"), "E"));
+      pappso::Peptide peptide(
+        sequence.replace(QRegularExpression("[BZX]"), "E"));
       return peptide.getMass();
     }
   catch(pappso::PappsoException &error)
