@@ -48,27 +48,15 @@ typedef std::shared_ptr<const Protein> ProteinSp;
 
 class PMSPP_LIB_DECL Protein
 {
-  private:
-  /** \brief  free text to describe the protein */
-  QString m_description;
-  /** \brief  a single unique identifier of the protein (usually the first word
-   * of description) */
-  QString m_accession;
-  /** \brief the amino acid sequence */
-  QString m_sequence;
-  /** \brief number of amino acid */
-  unsigned int m_length = 0;
-
-  static QRegularExpression m_removeTranslationStopRegExp;
 
   public:
   Protein();
   Protein(const QString &description, const QString &sequence);
   Protein(const Protein &protein);
+  virtual ~Protein();
   ProteinSp makeProteinSp() const;
 
   bool operator==(const Protein &other) const;
-  ~Protein();
 
   const QString &getSequence() const;
 
@@ -97,6 +85,19 @@ class PMSPP_LIB_DECL Protein
   /** \brief get monoisotopic mass of ProteinSp Protein::makeProteinSp() const
    */
   pappso_double getMass() const;
+
+  private:
+  /** \brief  free text to describe the protein */
+  QString m_description;
+  /** \brief  a single unique identifier of the protein (usually the first word
+   * of description) */
+  QString m_accession;
+  /** \brief the amino acid sequence */
+  QString m_sequence;
+  /** \brief number of amino acid */
+  unsigned int m_length = 0;
+
+  static QRegularExpression m_removeTranslationStopRegExp;
 };
 
 
