@@ -173,7 +173,7 @@ pappso::ProteinIntegerCode::convolution(
   auto it_trio   = m_peptideCodedFragments[1].begin();
   auto it_quatro = m_peptideCodedFragments[2].begin();
   auto it_cinqo  = m_peptideCodedFragments[3].begin();
-  for(std::uint8_t aa_code : m_seqAaCode)
+  for(std::uint8_t aa_code [[maybe_unused]] : m_seqAaCode)
     {
       convolution_score.push_back(convolutionKernel(code_list_from_spectrum,
                                                     it_aa,
