@@ -821,7 +821,7 @@ Trace::containsX(pappso_double value, PrecisionPtr precision_p) const
 
                        // FIXME: unbelievable behaviour: when building in
                        // release mode this code, under i386 (but not x86_64),
-                       // this code fails if the following cout statement is
+                       // this code fails if the following%S statement is
                        // missing.
 
                        // std::cout << std::setprecision(10)
@@ -1157,8 +1157,7 @@ Trace::toString() const
 
   for(auto &&dataPoint : *this)
     {
-      text.append(QString("%1\n")
-                    .arg(dataPoint.toString()));
+      text.append(QString("%1\n").arg(dataPoint.toString()));
     }
 
   return text;
