@@ -33,6 +33,7 @@
 
 
 /////////////////////// Local includes
+#include "config.h"
 #include "utils.h"
 #include "types.h"
 #include "exception/exceptionnotfound.h"
@@ -42,9 +43,30 @@
 namespace pappso
 {
 
+// Matches a double (decimal value, that is, m/z
+// value)
+QRegularExpression Utils::unsignedDoubleNumberNoExponentialRegExp =
+  QRegularExpression("\\d*\\.?\\d+");
 
+// Matches anything that is not digit, '.', or '-'
+// (that is, matches a separator
+QRegularExpression Utils::anythingButDigitDotDash =
+  QRegularExpression("[^\\d^\\.^-]+");
+
+// Matches a double (with exp notation
+// possibly) and also potentially a '-' sign. This is the intensity.
+QRegularExpression Utils::signedDoubleNumberExponentialRegExp =
+  QRegularExpression("-?\\d*\\.?\\d*[e-]?\\d*");
+
+// Matches <number><separator><number>, that is: m/z<separator>intensity.
 QRegularExpression Utils::xyMassDataFormatRegExp =
-  QRegularExpression("^(\\d*\\.?\\d+)([^\\d^\\.^-]+)(-?\\d*\\.?\\d*[e-]?\\d*)");
+  // QRegularExpression("^(\\d*\\.?\\d+)([^\\d^\\.^-]+)(-?\\d*\\.?\\d*[e-]?\\d*)");
+  QRegularExpression(
+    QString("^(%1)(%2)(%3)")
+      .arg(Utils::unsignedDoubleNumberNoExponentialRegExp.pattern())
+      .arg(Utils::anythingButDigitDotDash.pattern())
+      .arg(Utils::signedDoubleNumberExponentialRegExp.pattern()));
+
 
 QRegularExpression Utils::endOfLineRegExp = QRegularExpression("^\\s+$");
 
@@ -142,16 +164,22 @@ Utils::roundToDecimal32bitsAsLongLongInt(pappso::pappso_double input)
 std::string
 Utils::toUtf8StandardString(const QString &text)
 {
-  std::string env_backup = setlocale(LC_ALL, "");
-
-  // struct lconv *lc_backup = localeconv();
-  // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-  //<< "env_backup=" << env_backup.c_str() << "lc_backup->decimal_point"
-  //<< lc_backup->decimal_point;
-
-  // Force locale to be "C".
-  setlocale(LC_ALL, "C");
-
+  std::string env_backup;
+  try
+    {
+#ifdef MXE
+      // std::locale::global(std::locale("C")); // set locale to default locale
+      env_backup = std::setlocale(LC_ALL, nullptr);
+      std::setlocale(LC_ALL, "C");
+#else
+      std::locale::global(std::locale("C")); // set locale to default locale
+#endif
+    }
+  catch(std::exception &error)
+    {
+      throw pappso::PappsoException(
+        QObject::tr("Error trying to set local to C : %1").arg(error.what()));
+    }
   // Now perform the conversion.
   QByteArray byte_array = text.toUtf8();
   std::string stdText   = "";
@@ -161,8 +189,24 @@ Utils::toUtf8StandardString(const QString &text)
       stdText += c;
     }
 
-  // Set back the locale to the backed-up one.
-  setlocale(LC_ALL, env_backup.c_str());
+  try
+    {
+#ifdef MXE
+      // std::locale::global(std::locale("C")); // set locale to default locale
+      std::setlocale(LC_ALL, env_backup.c_str());
+#else // Set back the locale to the backed-up one.
+      std::locale::global(
+        std::locale("")); // sets locale according to OS environment
+#endif
+    }
+  catch(std::exception &error)
+    {
+
+      throw pappso::PappsoException(
+        QObject::tr("Error trying to set local to original system one %1 : %2")
+          .arg(env_backup.c_str())
+          .arg(error.what()));
+    }
 
   return stdText;
 }
@@ -429,41 +473,43 @@ Utils::booleanToString(bool value)
 }
 
 QString
-Utils::mzFormatAsString(MzFormat mz_format)
+Utils::msDataFormatAsString(MsDataFormat mz_format)
 {
 
-  if(mz_format == MzFormat::mzML)
+  if(mz_format == MsDataFormat::mzML)
     return "mzML";
-  else if(mz_format == MzFormat::mzXML)
+  else if(mz_format == MsDataFormat::mzXML)
     return "mzXML";
-  else if(mz_format == MzFormat::MGF)
+  else if(mz_format == MsDataFormat::MGF)
     return "MGF";
-  else if(mz_format == MzFormat::SQLite3)
+  else if(mz_format == MsDataFormat::SQLite3)
     return "SQLite3";
-  else if(mz_format == MzFormat::xy)
+  else if(mz_format == MsDataFormat::xy)
     return "xy";
-  else if(mz_format == MzFormat::mz5)
+  else if(mz_format == MsDataFormat::mz5)
     return "mz5";
-  else if(mz_format == MzFormat::msn)
+  else if(mz_format == MsDataFormat::msn)
     return "msn";
-  else if(mz_format == MzFormat::abSciexWiff)
+  else if(mz_format == MsDataFormat::abSciexWiff)
     return "abSciexWiff";
-  else if(mz_format == MzFormat::abSciexT2D)
+  else if(mz_format == MsDataFormat::abSciexT2D)
     return "abSciexT2D";
-  else if(mz_format == MzFormat::agilentMassHunter)
+  else if(mz_format == MsDataFormat::agilentMassHunter)
     return "agilentMassHunter";
-  else if(mz_format == MzFormat::thermoRaw)
+  else if(mz_format == MsDataFormat::thermoRaw)
     return "thermoRaw";
-  else if(mz_format == MzFormat::watersRaw)
+  else if(mz_format == MsDataFormat::watersRaw)
     return "watersRaw";
-  else if(mz_format == MzFormat::brukerFid)
+  else if(mz_format == MsDataFormat::brukerFid)
     return "brukerFid";
-  else if(mz_format == MzFormat::brukerYep)
+  else if(mz_format == MsDataFormat::brukerYep)
     return "brukerYep";
-  else if(mz_format == MzFormat::brukerBaf)
+  else if(mz_format == MsDataFormat::brukerBaf)
     return "brukerBaf";
-  else if(mz_format == MzFormat::brukerTims)
+  else if(mz_format == MsDataFormat::brukerTims)
     return "brukerTims";
+  else if(mz_format == MsDataFormat::brukerBafAscii)
+    return "brukerBafAscii";
   else
     return "unknown";
 }
@@ -509,18 +555,24 @@ Utils::toString(specglob::ExperimentalSpectrumDataPointType type)
 {
   switch(type)
     {
-    case specglob::ExperimentalSpectrumDataPointType::both:
+      case specglob::ExperimentalSpectrumDataPointType::both:
         return "both";
         break;
-    case specglob::ExperimentalSpectrumDataPointType::native:
+      case specglob::ExperimentalSpectrumDataPointType::native:
         return "native";
         break;
-    case specglob::ExperimentalSpectrumDataPointType::symetric:
-        return "symetric";
+      case specglob::ExperimentalSpectrumDataPointType::symmetric:
+        return "symmetric";
         break;
       default:
         return "synthetic";
     }
 }
 
+QString
+Utils::getVersion()
+{
+  QString version(PAPPSOMSPP_VERSION);
+  return version;
+}
 } // namespace pappso
