@@ -91,7 +91,7 @@ TimsBinDec::~TimsBinDec()
 void
 pappso::TimsBinDec::closeLinearRead()
 {
-  qDebug();
+  // qDebug();
   if(mp_fileLinear != nullptr)
     {
       mp_fileLinear->close();
@@ -101,7 +101,7 @@ pappso::TimsBinDec::closeLinearRead()
   m_firstFrameId = 0;
   m_lastFrameId  = 0;
   m_linearAccessRawDataChunckList.resize(0);
-  qDebug();
+  // qDebug();
 }
 
 
@@ -195,7 +195,7 @@ TimsBinDec::getTimsFrameSPtrByOffset(
     }
 
   // random access file
-  qDebug();
+  // qDebug();
   p_file          = getQfileRandom();
   bool seekpos_ok = p_file->seek(frame_record_list[frameId].tims_offset);
   if(!seekpos_ok)
@@ -231,7 +231,7 @@ void
 pappso::TimsBinDec::moveLinearReadForward(
   const std::vector<pappso::TimsFrameRecord> &frame_record_list)
 {
-  qDebug();
+  // qDebug();
   for(std::size_t i = 0; i < m_linearForwardThreshold; i++)
     {
       auto it = std::min_element(
@@ -246,7 +246,7 @@ pappso::TimsBinDec::moveLinearReadForward(
         break;
       it->readTimsFrame(mp_fileLinear, m_lastFrameId, frame_record_list);
     }
-  qDebug();
+  // qDebug();
 }
 
 
@@ -254,17 +254,17 @@ TimsFrameSPtr
 TimsBinDec::getTimsFrameFromRawDataChunck(
   const TimsFrameRawDataChunck &raw_data_chunck)
 {
-  qDebug();
+  // qDebug();
   TimsFrameSPtr frame_sptr;
   if(raw_data_chunck.getCompressedSize() > 0)
     {
-      qDebug();
+      // qDebug();
       if(m_timsCompressionType == 2)
         {
           auto decompressed_size2 =
             ZSTD_getFrameContentSize(raw_data_chunck.getMemoryBuffer(),
                                      raw_data_chunck.getCompressedSize());
-          qDebug();
+          // qDebug();
           if(decompressed_size2 == ZSTD_CONTENTSIZE_UNKNOWN)
             {
               throw PappsoException(
@@ -276,10 +276,10 @@ TimsBinDec::getTimsFrameFromRawDataChunck(
                   .arg(m_timsBinFile)
                   .arg(raw_data_chunck.getFrameLength()));
             }
-          qDebug();
+          // qDebug();
           if(decompressed_size2 == ZSTD_CONTENTSIZE_ERROR)
             {
-              qDebug();
+              // qDebug();
               throw PappsoException(
                 QObject::tr("ERROR TimsBinDec::getTimsFrameFromRawDataChunck "
                             "reading TIMS frame %1 TIMS binary file %2: "
@@ -306,7 +306,7 @@ TimsBinDec::getTimsFrameFromRawDataChunck(
                             m_decompressMemoryBufferSize,
                             raw_data_chunck.getMemoryBuffer(),
                             raw_data_chunck.getCompressedSize());
-          qDebug();
+          // qDebug();
 
           if(decompressed_size != decompressed_size2)
             {
@@ -320,7 +320,7 @@ TimsBinDec::getTimsFrameFromRawDataChunck(
                   .arg(decompressed_size2));
             }
 
-          qDebug();
+          // qDebug();
 
           frame_sptr =
             std::make_shared<TimsFrame>(raw_data_chunck.getFrameId(),
@@ -366,7 +366,7 @@ pappso::TimsBinDec::startLinearRead(
   std::size_t chunk_deque_size,
   const std::vector<pappso::TimsFrameRecord> &frame_record_list)
 {
-  qDebug();
+  // qDebug();
   m_linearAccessRawDataChunckList.resize(chunk_deque_size);
   m_firstFrameId = start_frame_id;
   m_lastFrameId  = start_frame_id;
@@ -413,5 +413,5 @@ pappso::TimsBinDec::startLinearRead(
           .arg(error.qwhat()));
     }
 
-  qDebug();
+  // qDebug();
 }
