@@ -68,7 +68,7 @@ TimsFrame::TimsFrame(std::size_t timsId,
   // /gorgone/pappso/fichiers_fabricants/Bruker/Demo_TimsTOF_juin2019/Samples/1922001/1922001-1_S-415_Pep_Pur-1ul_Slot1-10_1_2088.d/
   qDebug() << timsId;
 
-  m_timsDataFrame.resize(len);
+  m_binaryData.resize(len);
 
   if(p_bytes != nullptr)
     {
@@ -76,13 +76,13 @@ TimsFrame::TimsFrame(std::size_t timsId,
     }
   else
     {
-      if(m_scanNumber == 0)
+      if(m_scanCount == 0)
         {
 
           throw pappso::PappsoException(
             QObject::tr("TimsFrame::TimsFrame(%1,%2,nullptr,%3) FAILED")
-              .arg(m_timsId)
-              .arg(m_scanNumber)
+              .arg(m_frameId)
+              .arg(m_scanCount)
               .arg(len));
         }
     }
@@ -101,7 +101,7 @@ void
 TimsFrame::unshufflePacket(const char *src)
 {
   qDebug();
-  quint64 len = m_timsDataFrame.size();
+  quint64 len = m_binaryData.size();
   if(len % 4 != 0)
     {
       throw pappso::PappsoException(
@@ -110,7 +110,7 @@ TimsFrame::unshufflePacket(const char *src)
 
   quint64 nb_uint4 = len / 4;
 
-  char *dest         = m_timsDataFrame.data();
+  char *dest         = m_binaryData.data();
   quint64 src_offset = 0;
 
   for(quint64 j = 0; j < 4; j++)
@@ -125,9 +125,9 @@ TimsFrame::unshufflePacket(const char *src)
 }
 
 std::size_t
-TimsFrame::getNbrPeaks(std::size_t scanNum) const
+TimsFrame::getScanPeakCount(std::size_t scanNum) const
 {
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return 0;
   /*
     if(scanNum == 0)
@@ -136,14 +136,14 @@ TimsFrame::getNbrPeaks(std::size_t scanNum) const
                       (*(quint32 *)(m_timsDataFrame.constData()-4));
         return res / 2;
       }*/
-  if(scanNum == (m_scanNumber - 1))
+  if(scanNum == (m_scanCount - 1))
     {
-      auto nb_uint4 = m_timsDataFrame.size() / 4;
+      auto nb_uint4 = m_binaryData.size() / 4;
 
       std::size_t cumul = 0;
-      for(quint32 i = 0; i < m_scanNumber; i++)
+      for(quint32 i = 0; i < m_scanCount; i++)
         {
-          cumul += (*(quint32 *)(m_timsDataFrame.constData() + (i * 4)));
+          cumul += (*(quint32 *)(m_binaryData.constData() + (i * 4)));
         }
       return (nb_uint4 - cumul) / 2;
     }
@@ -151,7 +151,7 @@ TimsFrame::getNbrPeaks(std::size_t scanNum) const
 
   // quint32 *res = (quint32 *)(m_timsDataFrame.constData() + (scanNum * 4));
   // qDebug() << " res=" << *res;
-  return (*(quint32 *)(m_timsDataFrame.constData() + ((scanNum + 1) * 4))) / 2;
+  return (*(quint32 *)(m_binaryData.constData() + ((scanNum + 1) * 4))) / 2;
 }
 
 std::size_t
@@ -160,22 +160,22 @@ TimsFrame::getScanOffset(std::size_t scanNum) const
   std::size_t offset = 0;
   for(std::size_t i = 0; i < (scanNum + 1); i++)
     {
-      offset += (*(quint32 *)(m_timsDataFrame.constData() + (i * 4)));
+      offset += (*(quint32 *)(m_binaryData.constData() + (i * 4)));
     }
   return offset;
 }
 
 
 std::vector<quint32>
-TimsFrame::getScanIndexList(std::size_t scanNum) const
+TimsFrame::getScanTofIndexList(std::size_t scanNum) const
 {
-  qDebug();
+  // qDebug();
   checkScanNum(scanNum);
   std::vector<quint32> scan_tof;
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return scan_tof;
-  scan_tof.resize(getNbrPeaks(scanNum));
+  scan_tof.resize(getScanPeakCount(scanNum));
 
   std::size_t offset = getScanOffset(scanNum);
 
@@ -183,50 +183,50 @@ TimsFrame::getScanIndexList(std::size_t scanNum) const
   for(std::size_t i = 0; i < scan_tof.size(); i++)
     {
       scan_tof[i] =
-        (*(quint32 *)(m_timsDataFrame.constData() + (offset * 4) + (i * 8))) +
+        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8))) +
         previous;
       previous = scan_tof[i];
     }
-  qDebug();
+  // qDebug();
   return scan_tof;
 }
 
 std::vector<quint32>
-TimsFrame::getScanIntensities(std::size_t scanNum) const
+TimsFrame::getScanIntensityList(std::size_t scanNum) const
 {
-  qDebug();
+  // qDebug();
   checkScanNum(scanNum);
   std::vector<quint32> scan_intensities;
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return scan_intensities;
 
-  scan_intensities.resize(getNbrPeaks(scanNum));
+  scan_intensities.resize(getScanPeakCount(scanNum));
 
   std::size_t offset = getScanOffset(scanNum);
 
   for(std::size_t i = 0; i < scan_intensities.size(); i++)
     {
-      scan_intensities[i] = (*(quint32 *)(m_timsDataFrame.constData() +
-                                          (offset * 4) + (i * 8) + 4));
+      scan_intensities[i] =
+        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
     }
-  qDebug();
+  // qDebug();
   return scan_intensities;
 }
 
 
 quint64
-TimsFrame::cumulateSingleScanIntensities(std::size_t scanNum) const
+TimsFrame::cumulateScanIntensities(std::size_t scanNum) const
 {
   qDebug();
 
   quint64 summed_intensities = 0;
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return summed_intensities;
   // checkScanNum(scanNum);
 
-  std::size_t size = getNbrPeaks(scanNum);
+  std::size_t size = getScanPeakCount(scanNum);
 
   std::size_t offset = getScanOffset(scanNum);
 
@@ -235,11 +235,11 @@ TimsFrame::cumulateSingleScanIntensities(std::size_t scanNum) const
   for(std::size_t i = 0; i < size; i++)
     {
       quint32 x =
-        (*(quint32 *)((m_timsDataFrame.constData() + (offset * 4) + (i * 8))) +
+        (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
          previous);
 
-      quint32 y = (*(quint32 *)(m_timsDataFrame.constData() + (offset * 4) +
-                                (i * 8) + 4));
+      quint32 y =
+        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
 
       previous = x;
 
@@ -247,7 +247,7 @@ TimsFrame::cumulateSingleScanIntensities(std::size_t scanNum) const
     }
 
   // Normalization over the accumulation time for this frame.
-  summed_intensities *= ((double)100.0 / m_accumulationTime);
+  summed_intensities *= ((double)100.0 / m_acqDurationInMilliseconds);
 
   qDebug();
 
@@ -263,15 +263,15 @@ TimsFrame::cumulateSingleScanIntensities(std::size_t scanNum) const
  * @return quint64
  */
 quint64
-TimsFrame::cumulateScansIntensities(std::size_t mobility_scan_begin,
-                                    std::size_t mobility_scan_end) const
+TimsFrame::cumulateScanRangeIntensities(std::size_t mobility_scan_begin,
+                                        std::size_t mobility_scan_end) const
 {
   quint64 summed_intensities = 0;
 
   // qDebug() << "begin mobility_scan_begin =" << mobility_scan_begin
   //<< "mobility_scan_end =" << mobility_scan_end;
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return summed_intensities;
 
   try
@@ -281,7 +281,7 @@ TimsFrame::cumulateScansIntensities(std::size_t mobility_scan_begin,
       for(std::size_t i = mobility_scan_begin; i < mobility_scan_max; i++)
         {
           qDebug() << i;
-          summed_intensities += cumulateSingleScanIntensities(i);
+          summed_intensities += cumulateScanIntensities(i);
           qDebug() << i;
         }
     }
@@ -304,32 +304,32 @@ void
 TimsFrame::cumulateScan(std::size_t scanNum,
                         TimsDataFastMap &accumulate_into) const
 {
-  // qDebug();
+  qDebug();
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return;
-
+  qDebug();
   // checkScanNum(scanNum);
 
-  std::size_t scan_size = getNbrPeaks(scanNum);
+  std::size_t scan_size = getScanPeakCount(scanNum);
 
   std::size_t scan_offset = getScanOffset(scanNum);
 
   qint32 previous = -1;
   for(std::size_t i = 0; i < scan_size; i++)
     {
-      quint32 x = (*(quint32 *)((m_timsDataFrame.constData() +
-                                 (scan_offset * 4) + (i * 8))) +
+      quint32 x = (*(quint32 *)((m_binaryData.constData() + (scan_offset * 4) +
+                                 (i * 8))) +
                    previous);
-      quint32 y = (*(quint32 *)(m_timsDataFrame.constData() +
-                                (scan_offset * 4) + (i * 8) + 4));
+      quint32 y = (*(quint32 *)(m_binaryData.constData() + (scan_offset * 4) +
+                                (i * 8) + 4));
 
       previous = x;
-
+      qDebug() << "x=" << x << " y=" << y;
       accumulate_into.accumulateIntensity(x, y);
     }
 
-  // qDebug();
+  qDebug();
 }
 
 // Proof of concept m/z range-conditions for accumulations
@@ -341,38 +341,39 @@ TimsFrame::cumulateScan2(std::size_t scanNum,
 {
   // qDebug();
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return;
 
   // checkScanNum(scanNum);
 
-  std::size_t scan_size   = getNbrPeaks(scanNum);
+  std::size_t scan_size   = getScanPeakCount(scanNum);
   std::size_t scan_offset = getScanOffset(scanNum);
   qint32 previous         = -1;
 
   for(std::size_t i = 0; i < scan_size; i++)
     {
-      quint32 x = (*(quint32 *)((m_timsDataFrame.constData() +
-                                 (scan_offset * 4) + (i * 8))) +
+      quint32 x = (*(quint32 *)((m_binaryData.constData() + (scan_offset * 4) +
+                                 (i * 8))) +
                    previous);
 
+      previous = x;
+
       if(x < accepted_tof_index_range_begin)
         {
-          // qDebug() << "TOF index still not in range, x:" << x;
+
+          qDebug() << "TOF index still not in range, x:" << x;
           continue;
         }
       if(x > accepted_tof_index_range_end)
         {
-          // qDebug() << "TOF index already out of range, x:" << x;
+          qDebug() << "TOF index already out of range, x:" << x;
           break;
         }
 
-      // qDebug() << "TOF index in range, x:" << x;
+      qDebug() << "TOF index in range, x:" << x;
 
-      quint32 y = (*(quint32 *)(m_timsDataFrame.constData() +
-                                (scan_offset * 4) + (i * 8) + 4));
-
-      previous = x;
+      quint32 y = (*(quint32 *)(m_binaryData.constData() + (scan_offset * 4) +
+                                (i * 8) + 4));
 
       accumulate_into.accumulateIntensity(x, y);
     }
@@ -391,11 +392,11 @@ TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
 
   try
     {
-      if(m_timsDataFrame.size() == 0)
+      if(m_binaryData.size() == 0)
         return new_trace;
       TimsDataFastMap &raw_spectrum =
         TimsDataFastMap::getTimsDataFastMapInstance();
-      raw_spectrum.tofIndexList.clear();
+      raw_spectrum.clear();
       // double local_accumulationTime = 0;
 
       std::size_t mobility_scan_max = mobility_scan_end + 1;
@@ -418,12 +419,12 @@ TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
         getMzCalibrationInterfaceSPtr().get();
 
 
-      for(quint32 tof_index : raw_spectrum.tofIndexList)
+      for(quint32 tof_index : raw_spectrum.getTofIndexList())
         {
           data_point_cumul.x = mz_calibration_p->getMzFromTofIndex(tof_index);
           // normalization
           data_point_cumul.y = raw_spectrum.readIntensity(tof_index) *
-                               ((double)100.0 / m_accumulationTime);
+                               ((double)100.0 / m_acqDurationInMilliseconds);
           new_trace.push_back(data_point_cumul);
         }
       new_trace.sortX();
@@ -442,7 +443,7 @@ TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
 }
 
 Trace
-TimsFrame::cumulateScansToTraceMzDownResolution(
+TimsFrame::combineScansToTraceWithDowngradedMzResolution(
   std::size_t mz_index_merge_window,
   std::size_t mobility_scan_begin,
   std::size_t mobility_scan_end,
@@ -455,7 +456,7 @@ TimsFrame::cumulateScansToTraceMzDownResolution(
 
   try
     {
-      if(m_timsDataFrame.size() == 0)
+      if(m_binaryData.size() == 0)
         {
           qDebug() << "The frame is empty, returning empty trace.";
           return new_trace;
@@ -466,7 +467,7 @@ TimsFrame::cumulateScansToTraceMzDownResolution(
 
       TimsDataFastMap &raw_spectrum =
         TimsDataFastMap::getTimsDataFastMapInstance();
-      raw_spectrum.tofIndexList.clear();
+      raw_spectrum.clear();
       // double local_accumulationTime = 0;
 
       std::size_t mobility_scan_max = mobility_scan_end + 1;
@@ -501,7 +502,9 @@ TimsFrame::cumulateScansToTraceMzDownResolution(
       mz_minimum_index_out = std::numeric_limits<quint32>::max();
       mz_maximum_index_out = 0;
 
-      for(quint32 tof_index : raw_spectrum.tofIndexList)
+      // FIXME: donc je comprends que les index sont contigus
+      // puisqu'on utilise at(key) ?
+      for(quint32 tof_index : raw_spectrum.getTofIndexList())
         {
           if(tof_index > mz_maximum_index_out)
             mz_maximum_index_out = tof_index;
@@ -513,7 +516,7 @@ TimsFrame::cumulateScansToTraceMzDownResolution(
 
           // Normalization
           data_point_cumul.y = raw_spectrum.readIntensity(tof_index) *
-                               ((double)100.0 / m_accumulationTime);
+                               ((double)100.0 / m_acqDurationInMilliseconds);
 
           // Finally make the data point a new Trace point.
           new_trace.push_back(data_point_cumul);
@@ -544,7 +547,7 @@ TimsFrame::cumulateScansToTraceMzDownResolution(
 
 
 Trace
-TimsFrame::cumulateScansToTraceMzDownResolution2(
+TimsFrame::combineScansToTraceWithDowngradedMzResolution2(
   std::size_t mz_index_merge_window,
   double mz_range_begin,
   double mz_range_end,
@@ -560,7 +563,7 @@ TimsFrame::cumulateScansToTraceMzDownResolution2(
 
   try
     {
-      if(m_timsDataFrame.size() == 0)
+      if(m_binaryData.size() == 0)
         {
           qDebug() << "The frame is empty, returning empty trace.";
           return new_trace;
@@ -571,7 +574,7 @@ TimsFrame::cumulateScansToTraceMzDownResolution2(
 
       TimsDataFastMap &raw_spectrum =
         TimsDataFastMap::getTimsDataFastMapInstance();
-      raw_spectrum.tofIndexList.clear();
+      raw_spectrum.clear();
       // double local_accumulationTime = 0;
 
       std::size_t mobility_scan_max = mobility_scan_end + 1;
@@ -622,7 +625,7 @@ TimsFrame::cumulateScansToTraceMzDownResolution2(
       mz_maximum_index_out = 0;
 
       // for(std::pair<quint32, quint32> pair_tof_intensity : raw_spectrum)
-      for(quint32 tof_index : raw_spectrum.tofIndexList)
+      for(quint32 tof_index : raw_spectrum.getTofIndexList())
         {
           std::size_t intensity = raw_spectrum.readIntensity(tof_index);
           if(tof_index > mz_maximum_index_out)
@@ -634,7 +637,8 @@ TimsFrame::cumulateScansToTraceMzDownResolution2(
           data_point_cumul.x = mz_calibration_p->getMzFromTofIndex(tof_index);
 
           // Normalization
-          data_point_cumul.y = intensity * ((double)100.0 / m_accumulationTime);
+          data_point_cumul.y =
+            intensity * ((double)100.0 / m_acqDurationInMilliseconds);
 
           // Finally make the data point a new Trace point.
           new_trace.push_back(data_point_cumul);
@@ -665,21 +669,22 @@ TimsFrame::cumulateScansToTraceMzDownResolution2(
 
 
 void
-TimsFrame::cumulateScansInRawMap(TimsDataFastMap &rawSpectrum,
-                                 std::size_t mobility_scan_begin,
-                                 std::size_t mobility_scan_end) const
+TimsFrame::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum,
+                                              std::size_t scan_index_begin,
+                                              std::size_t scan_index_end) const
 {
   // qDebug() << "begin mobility_scan_begin=" << mobility_scan_begin
   //<< " mobility_scan_end=" << mobility_scan_end;
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return;
   try
     {
 
-      std::size_t mobility_scan_max = mobility_scan_end + 1;
+      std::size_t mobility_scan_max = scan_index_end + 1;
+      // if (mobility_scan_max > m_scanCount) mobility_scan_max = m_scanCount;
       qDebug();
-      for(std::size_t i = mobility_scan_begin; i < mobility_scan_max; i++)
+      for(std::size_t i = scan_index_begin; i < mobility_scan_max; i++)
         {
           qDebug() << i;
           cumulateScan(i, rawSpectrum);
@@ -692,8 +697,8 @@ TimsFrame::cumulateScansInRawMap(TimsDataFastMap &rawSpectrum,
     {
       qDebug() << QString("Failure in %1 %2 to %3 :\n %4")
                     .arg(__FUNCTION__)
-                    .arg(mobility_scan_begin)
-                    .arg(mobility_scan_end)
+                    .arg(scan_index_begin)
+                    .arg(scan_index_end)
                     .arg(error.what());
     }
 
@@ -701,6 +706,46 @@ TimsFrame::cumulateScansInRawMap(TimsDataFastMap &rawSpectrum,
 }
 
 
+void
+TimsFrame::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum,
+                                              std::size_t scan_index_begin,
+                                              std::size_t scan_index_end,
+                                              quint32 tof_index_begin,
+                                              quint32 tof_index_end) const
+{
+  qDebug() << "tof_index_begin=" << tof_index_begin
+           << " tof_index_end=" << tof_index_end;
+  //<< " mobility_scan_end=" << mobility_scan_end;
+
+  if(m_binaryData.size() == 0)
+    return;
+  try
+    {
+
+      std::size_t mobility_scan_max = scan_index_end + 1;
+      // if (mobility_scan_max > m_scanCount) mobility_scan_max = m_scanCount;
+      qDebug();
+      for(std::size_t i = scan_index_begin; i < mobility_scan_max; i++)
+        {
+          qDebug() << i;
+          cumulateScan2(i, rawSpectrum, tof_index_begin, tof_index_end);
+          qDebug() << i << rawSpectrum.getTofIndexList().size();
+          // local_accumulationTime += m_accumulationTime;
+        }
+    }
+
+  catch(std::exception &error)
+    {
+      qDebug() << QString("Failure in %1 %2 to %3 :\n %4")
+                    .arg(__FUNCTION__)
+                    .arg(scan_index_begin)
+                    .arg(scan_index_end)
+                    .arg(error.what());
+    }
+
+  // qDebug() << "end";
+}
+
 pappso::MassSpectrumSPtr
 TimsFrame::getMassSpectrumSPtr(std::size_t scanNum) const
 {
@@ -715,12 +760,12 @@ TimsFrame::getMassSpectrumSPtr(std::size_t scanNum) const
     std::make_shared<pappso::MassSpectrum>();
   // std::vector<DataPoint>
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return mass_spectrum_sptr;
 
   // qDebug();
 
-  std::size_t size = getNbrPeaks(scanNum);
+  std::size_t size = getScanPeakCount(scanNum);
 
   std::size_t offset = getScanOffset(scanNum);
 
@@ -735,13 +780,13 @@ TimsFrame::getMassSpectrumSPtr(std::size_t scanNum) const
   for(std::size_t i = 0; i < size; i++)
     {
       tof_index =
-        (*(quint32 *)((m_timsDataFrame.constData() + (offset * 4) + (i * 8))) +
+        (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
          previous);
-      data_point.y = (*(quint32 *)(m_timsDataFrame.constData() + (offset * 4) +
-                                   (i * 8) + 4));
+      data_point.y =
+        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
 
       // intensity normalization
-      data_point.y *= 100.0 / m_accumulationTime;
+      data_point.y *= 100.0 / m_acqDurationInMilliseconds;
 
       previous = tof_index;
 
@@ -795,23 +840,23 @@ TimsFrame::getMobilityScan(std::size_t scanNum,
     {
       qDebug() << "mz_index_merge_window;=" << mz_index_merge_window
                << " raw_spectrum.size()=" << raw_spectrum.size();
-      raw_spectrum =
-        downsizeMzRawValuePairList(mz_index_merge_window, raw_spectrum);
+      raw_spectrum = downgradeResolutionOfTofIndexIntensityPairList(
+        mz_index_merge_window, raw_spectrum);
     }
 
   if(raw_spectrum.size() > 0)
     {
-      mz_minimum_index_out = raw_spectrum.front().mz_tof_index;
-      mz_maximum_index_out = raw_spectrum.back().mz_tof_index;
+      mz_minimum_index_out = raw_spectrum.front().tof_index;
+      mz_maximum_index_out = raw_spectrum.back().tof_index;
 
       for(auto &&element : raw_spectrum)
         {
           spectrum.push_back(DataPoint(
-            msp_mzCalibration.get()->getMzFromTofIndex(element.mz_tof_index),
+            msp_mzCalibration.get()->getMzFromTofIndex(element.tof_index),
             static_cast<double>(element.intensity_index)));
 
           // intensity normalization
-          spectrum.back().y *= 100.0 / m_accumulationTime;
+          spectrum.back().y *= 100.0 / m_acqDurationInMilliseconds;
         }
     }
 
@@ -854,7 +899,7 @@ TimsFrame::extractTimsXicListInRtRange(
   for(auto &&struct_xic : tmp_xic_list)
     {
       for(std::size_t scan = struct_xic.mobilityIndexBegin;
-          (scan <= struct_xic.mobilityIndexEnd) && (scan < m_scanNumber);
+          (scan <= struct_xic.mobilityIndexEnd) && (scan < m_scanCount);
           scan++)
         {
           unique_scan_num_list.push_back(scan);
@@ -903,7 +948,7 @@ TimsFrame::extractTimsXicListInRtRange(
         {
           qDebug() << tmp_xic_struct.xic_ptr;
           tmp_xic_struct.xic_ptr->push_back(
-            {m_time, tmp_xic_struct.tmpIntensity});
+            {m_rtInSeconds, tmp_xic_struct.tmpIntensity});
         }
     }
 
@@ -920,11 +965,11 @@ TimsFrame::getRawTraceSPtr(std::size_t scanNum) const
   pappso::TraceSPtr trace_sptr = std::make_shared<pappso::Trace>();
   // std::vector<DataPoint>
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return trace_sptr;
   // qDebug();
 
-  std::size_t size = getNbrPeaks(scanNum);
+  std::size_t size = getScanPeakCount(scanNum);
 
   std::size_t offset = getScanOffset(scanNum);
 
@@ -933,13 +978,12 @@ TimsFrame::getRawTraceSPtr(std::size_t scanNum) const
   for(std::size_t i = 0; i < size; i++)
     {
       DataPoint data_point(
-        (*(quint32 *)((m_timsDataFrame.constData() + (offset * 4) + (i * 8))) +
+        (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
          previous),
-        (*(quint32 *)(m_timsDataFrame.constData() + (offset * 4) + (i * 8) +
-                      4)));
+        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4)));
 
       // intensity normalization
-      data_point.y *= 100.0 / m_accumulationTime;
+      data_point.y *= 100.0 / m_acqDurationInMilliseconds;
 
       previous = data_point.x;
       trace_sptr.get()->push_back(data_point);
@@ -949,21 +993,21 @@ TimsFrame::getRawTraceSPtr(std::size_t scanNum) const
 }
 
 
-std::vector<TimsFrame::RawValuePair>
+std::vector<TimsFrame::TofIndexIntensityPair>
 TimsFrame::getRawValuePairList(std::size_t scanNum,
                                quint32 accepted_tof_index_range_begin,
                                quint32 accepted_tof_index_range_end) const
 {
   // qDebug() << accepted_tof_index_range_begin;
 
-  std::vector<TimsFrame::RawValuePair> raw_value_pairs;
+  std::vector<TimsFrame::TofIndexIntensityPair> raw_value_pairs;
   // std::vector<DataPoint>
 
-  if(m_timsDataFrame.size() == 0)
+  if(m_binaryData.size() == 0)
     return raw_value_pairs;
   // qDebug();
 
-  std::size_t size = getNbrPeaks(scanNum);
+  std::size_t size = getScanPeakCount(scanNum);
 
   std::size_t offset = getScanOffset(scanNum);
 
@@ -974,19 +1018,19 @@ TimsFrame::getRawValuePairList(std::size_t scanNum,
     {
 
       // qDebug() << i;
-      TimsFrame::RawValuePair raw_value_pair(
-        {(*(quint32 *)((m_timsDataFrame.constData() + (offset * 4) + (i * 8))) +
+      TimsFrame::TofIndexIntensityPair raw_value_pair(
+        {(*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
           previous),
-         (*(quint32 *)(m_timsDataFrame.constData() + (offset * 4) + (i * 8) +
+         (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) +
                        4))});
 
-      previous = raw_value_pair.mz_tof_index;
-      if(raw_value_pair.mz_tof_index < accepted_tof_index_range_begin)
+      previous = raw_value_pair.tof_index;
+      if(raw_value_pair.tof_index < accepted_tof_index_range_begin)
         {
           // qDebug() << "TOF index still not in range, x:" << x;
           continue;
         }
-      if(raw_value_pair.mz_tof_index > accepted_tof_index_range_end)
+      if(raw_value_pair.tof_index > accepted_tof_index_range_end)
         {
           // qDebug() << "TOF index already out of range, x:" << x;
           break;
