@@ -77,15 +77,15 @@ class TimsFrame : public TimsFrameBase
   virtual ~TimsFrame();
 
 
-  virtual std::size_t getNbrPeaks(std::size_t scanNum) const override;
+  virtual std::size_t getScanPeakCount(std::size_t scanIndex) const override;
 
   /** @brief cumulate scan list into a trace
    * @param scanNumBegin first scan to cumulate
    * @param scanNumEnd last scan to cumulate
    * @return Trace mz and intensity values
    */
-  virtual Trace cumulateScansToTrace(std::size_t scanNumBegin,
-                                     std::size_t scanNumEnd) const override;
+  virtual Trace cumulateScansToTrace(std::size_t scanIndexBegin,
+                                     std::size_t scanIndexEnd) const override;
 
 
   /** @brief cumulate spectrum given a scan number range
@@ -106,7 +106,7 @@ class TimsFrame : public TimsFrameBase
    * resulting trace
    *
    */
-  virtual Trace cumulateScansToTraceMzDownResolution(
+  virtual Trace combineScansToTraceWithDowngradedMzResolution(
     std::size_t mzindex_merge_window,
     std::size_t scanNumBegin,
     std::size_t scanNumEnd,
@@ -134,7 +134,7 @@ class TimsFrame : public TimsFrameBase
    * resulting trace (constrained by the mz_range_end)
    *
    */
-  virtual Trace cumulateScansToTraceMzDownResolution2(
+  virtual Trace combineScansToTraceWithDowngradedMzResolution2(
     std::size_t mz_index_merge_window,
     double mz_range_begin,
     double mz_range_end,
@@ -148,9 +148,18 @@ class TimsFrame : public TimsFrameBase
    * @param scanNumBegin first scan to cumulate
    * @param scanNumEnd last scan to cumulate
    */
-  virtual void cumulateScansInRawMap(TimsDataFastMap &rawSpectrum,
-                                     std::size_t scanNumBegin,
-                                     std::size_t scanNumEnd) const override;
+  void
+  combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum,
+                                     std::size_t scan_index_begin,
+                                     std::size_t scan_index_end) const override;
+                                     
+                                      virtual void
+  combineScansInTofIndexIntensityMap(TimsDataFastMap &tof_index_intensity_map,
+                                     std::size_t scan_index_begin,
+                                     std::size_t scan_index_end,
+                                     quint32 tof_index_begin,
+                                     quint32 tof_index_end) const override;
+
 
 
   /** @brief get a single mobility scan m/z + intensities
@@ -174,24 +183,23 @@ class TimsFrame : public TimsFrameBase
                                 quint32 &mz_minimum_index_out,
                                 quint32 &mz_maximum_index_out) const override;
 
-  virtual quint64
-  cumulateSingleScanIntensities(std::size_t scanNum) const override;
+  virtual quint64 cumulateScanIntensities(std::size_t scanNum) const override;
 
   virtual quint64
-  cumulateScansIntensities(std::size_t scanNumBegin,
-                           std::size_t scanNumEnd) const override;
+  cumulateScanRangeIntensities(std::size_t scanNumBegin,
+                               std::size_t scanNumEnd) const override;
 
   /** @brief get raw index list for one given scan
    * index are not TOF nor m/z, just index on digitizer
    */
   virtual std::vector<quint32>
-  getScanIndexList(std::size_t scanNum) const override;
+  getScanTofIndexList(std::size_t scanNum) const override;
 
   /** @brief get raw intensities without transformation from one scan
    * it needs intensity normalization
    */
   virtual std::vector<quint32>
-  getScanIntensities(std::size_t scanNum) const override;
+  getScanIntensityList(std::size_t scanNum) const override;
 
   virtual pappso::MassSpectrumSPtr
   getMassSpectrumSPtr(std::size_t scanNum) const override;
@@ -205,7 +213,7 @@ class TimsFrame : public TimsFrameBase
    * @return vector of RawValuePair
    *
    */
-  virtual std::vector<RawValuePair>
+  virtual std::vector<TofIndexIntensityPair>
   getRawValuePairList(std::size_t scanNum,
                       quint32 accepted_tof_index_range_begin,
                       quint32 accepted_tof_index_range_end) const;
@@ -276,6 +284,6 @@ class TimsFrame : public TimsFrameBase
   };
 
   protected:
-  QByteArray m_timsDataFrame;
+  QByteArray m_binaryData;
 };
 } // namespace pappso
