@@ -36,12 +36,12 @@
 namespace pappso
 {
 
-TimsFrameBase::TimsFrameBase(std::size_t timsId, quint32 scanNum)
+TimsFrameBase::TimsFrameBase(std::size_t frame_id, quint32 scanCount)
 {
-  qDebug() << timsId;
-  m_timsId = timsId;
+  qDebug() << frame_id;
+  m_frameId = frame_id;
 
-  m_scanNumber = scanNum;
+  m_scanCount = scanCount;
 }
 
 TimsFrameBase::TimsFrameBase([[maybe_unused]] const TimsFrameBase &other)
@@ -53,9 +53,9 @@ TimsFrameBase::~TimsFrameBase()
 }
 
 void
-TimsFrameBase::setAccumulationTime(double accumulation_time_ms)
+TimsFrameBase::setAcqDurationInMilliseconds(double acquisition_duration_ms)
 {
-  m_accumulationTime = accumulation_time_ms;
+  m_acqDurationInMilliseconds = acquisition_duration_ms;
 }
 
 
@@ -102,19 +102,19 @@ TimsFrameBase::setMzCalibration(double T1_frame,
 bool
 TimsFrameBase::checkScanNum(std::size_t scanNum) const
 {
-  if(scanNum >= m_scanNumber)
+  if(scanNum >= m_scanCount)
     {
       throw pappso::ExceptionOutOfRange(
         QObject::tr("Invalid scan number : scanNum %1  > m_scanNumber %2")
           .arg(scanNum)
-          .arg(m_scanNumber));
+          .arg(m_scanCount));
     }
 
   return true;
 }
 
 std::size_t
-TimsFrameBase::getNbrPeaks(std::size_t scanNum) const
+TimsFrameBase::getScanPeakCount(std::size_t scanNum) const
 {
   throw PappsoException(
     QObject::tr(
@@ -125,7 +125,7 @@ TimsFrameBase::getNbrPeaks(std::size_t scanNum) const
 std::size_t
 TimsFrameBase::getTotalNumberOfScans() const
 {
-  return m_scanNumber;
+  return m_scanCount;
 }
 
 MassSpectrumSPtr
@@ -157,12 +157,12 @@ TimsFrameBase::cumulateScansToTrace(std::size_t scanNumBegin,
 }
 
 Trace
-TimsFrameBase::cumulateScansToTraceMzDownResolution(
+TimsFrameBase::combineScansToTraceWithDowngradedMzResolution(
   std::size_t mzindex_merge_window [[maybe_unused]],
   std::size_t scanNumBegin [[maybe_unused]],
   std::size_t scanNumEnd [[maybe_unused]],
-  quint32 &minimum_index [[maybe_unused]],
-  quint32 &maximum_index [[maybe_unused]]) const
+  quint32 &minimum_tof_index_out [[maybe_unused]],
+  quint32 &maximum_tof_index_out [[maybe_unused]]) const
 {
   throw PappsoException(QObject::tr("Non implemented function %1 %2 %3")
                           .arg(__FILE__)
@@ -171,7 +171,7 @@ TimsFrameBase::cumulateScansToTraceMzDownResolution(
 }
 
 Trace
-TimsFrameBase::cumulateScansToTraceMzDownResolution2(
+TimsFrameBase::combineScansToTraceWithDowngradedMzResolution2(
   std::size_t mz_index_merge_window [[maybe_unused]],
   double mz_range_begin [[maybe_unused]],
   double mz_range_end [[maybe_unused]],
@@ -203,10 +203,10 @@ TimsFrameBase::getMobilityScan(std::size_t scanNum [[maybe_unused]],
 }
 
 void
-TimsFrameBase::cumulateScansInRawMap(TimsDataFastMap &rawSpectrum
-                                     [[maybe_unused]],
-                                     std::size_t scanNumBegin,
-                                     std::size_t scanNumEnd) const
+TimsFrameBase::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum
+                                                  [[maybe_unused]],
+                                                  std::size_t scanNumBegin,
+                                                  std::size_t scanNumEnd) const
 {
   throw PappsoException(
     QObject::tr(
@@ -217,8 +217,26 @@ TimsFrameBase::cumulateScansInRawMap(TimsDataFastMap &rawSpectrum
 }
 
 
+void
+TimsFrameBase::combineScansInTofIndexIntensityMap(TimsDataFastMap &rawSpectrum
+                                                  [[maybe_unused]],
+                                                  std::size_t scanNumBegin,
+                                                  std::size_t scanNumEnd,
+                                                  quint32 tof_index_begin,
+                                                  quint32 tof_index_end) const
+{
+  throw PappsoException(
+    QObject::tr(
+      "ERROR unable to cumulateScansInRawMap in TimsFrameBase for scan "
+      "number begin %1 end %2, tof index begin %3, tof index end %4")
+      .arg(scanNumBegin)
+      .arg(scanNumEnd)
+      .arg(tof_index_begin)
+      .arg(tof_index_end));
+}
+
 quint64
-TimsFrameBase::cumulateSingleScanIntensities(std::size_t scanNum) const
+TimsFrameBase::cumulateScanIntensities(std::size_t scanNum) const
 {
   throw PappsoException(
     QObject::tr(
@@ -231,8 +249,8 @@ TimsFrameBase::cumulateSingleScanIntensities(std::size_t scanNum) const
 
 
 quint64
-TimsFrameBase::cumulateScansIntensities(std::size_t scanNumBegin,
-                                        std::size_t scanNumEnd) const
+TimsFrameBase::cumulateScanRangeIntensities(std::size_t scanNumBegin,
+                                            std::size_t scanNumEnd) const
 {
   throw PappsoException(
     QObject::tr(
@@ -245,9 +263,9 @@ TimsFrameBase::cumulateScansIntensities(std::size_t scanNumBegin,
 }
 
 void
-TimsFrameBase::setTime(double time)
+TimsFrameBase::setRtInSeconds(double time)
 {
-  m_time = time;
+  m_rtInSeconds = time;
 }
 
 void
@@ -267,15 +285,15 @@ TimsFrameBase::getMsLevel() const
 }
 
 double
-TimsFrameBase::getTime() const
+TimsFrameBase::getRtInSeconds() const
 {
-  return m_time;
+  return m_rtInSeconds;
 }
 
 std::size_t
 TimsFrameBase::getId() const
 {
-  return m_timsId;
+  return m_frameId;
 }
 void
 TimsFrameBase::setTimsCalibration(int tims_model_type,
@@ -318,7 +336,9 @@ TimsFrameBase::getVoltageTransformation(std::size_t scanNum) const
     {
       throw pappso::PappsoException(
         QObject::tr("ERROR in TimsFrame::getVoltageTransformation invalid tims "
-                    "calibration, v < m_timsVmin"));
+                    "calibration, v < m_timsVmin %1 < %2")
+          .arg(v)
+          .arg(m_timsVmin));
     }
 
 
@@ -326,14 +346,17 @@ TimsFrameBase::getVoltageTransformation(std::size_t scanNum) const
     {
       throw pappso::PappsoException(
         QObject::tr("ERROR in TimsFrame::getVoltageTransformation invalid tims "
-                    "calibration, v > m_timsVmax"));
+                    "calibration, v > m_timsVmax  %1 > %2")
+          .arg(v)
+          .arg(m_timsVmax));
     }
   return v;
 }
 double
-TimsFrameBase::getDriftTime(std::size_t scanNum) const
+TimsFrameBase::getDriftTimeInMilliseconds(std::size_t scanNum) const
 {
-  return (m_accumulationTime / (double)m_scanNumber) * ((double)scanNum);
+  return (m_acqDurationInMilliseconds / (double)m_scanCount) *
+         ((double)scanNum);
 }
 
 double
@@ -344,7 +367,7 @@ TimsFrameBase::getOneOverK0Transformation(std::size_t scanNum) const
 
 
 std::size_t
-TimsFrameBase::getScanNumFromOneOverK0(double one_over_k0) const
+TimsFrameBase::getScanIndexFromOneOverK0(double one_over_k0) const
 {
   double temp = 1 / one_over_k0;
   temp        = temp - m_timsC6;
@@ -371,7 +394,7 @@ TimsFrameBase::hasSameCalibrationData(const TimsFrameBase &other) const
 
 
 pappso::Trace
-TimsFrameBase::getTraceFromCumulatedScans(
+TimsFrameBase::getTraceFromTofIndexIntensityMap(
   TimsDataFastMap &accumulated_scans) const
 {
   qDebug();
@@ -384,11 +407,11 @@ TimsFrameBase::getTraceFromCumulatedScans(
 
 
   DataPoint element;
-  for(quint32 tof_index : accumulated_scans.tofIndexList)
+  for(quint32 tof_index : accumulated_scans.getTofIndexList())
     {
       // intensity normalization
       element.y = ((double)accumulated_scans.readIntensity(tof_index)) * 100.0 /
-                  m_accumulationTime;
+                  m_acqDurationInMilliseconds;
 
       // mz calibration
       element.x = mz_calibration_p->getMzFromTofIndex(tof_index);
@@ -439,10 +462,10 @@ quint32
 TimsFrameBase::getMaximumRawMassIndex() const
 {
   quint32 max_value = 0;
-  for(quint32 i = 0; i < m_scanNumber; i++)
+  for(quint32 i = 0; i < m_scanCount; i++)
     {
-      qDebug() << "m_scanNumber=" << m_scanNumber << " i=" << i;
-      std::vector<quint32> index_list = getScanIndexList(i);
+      qDebug() << "m_scanNumber=" << m_scanCount << " i=" << i;
+      std::vector<quint32> index_list = getScanTofIndexList(i);
       auto it = std::max_element(index_list.begin(), index_list.end());
       if(it != index_list.end())
         {
@@ -453,7 +476,7 @@ TimsFrameBase::getMaximumRawMassIndex() const
 }
 
 std::vector<quint32>
-TimsFrameBase::getScanIndexList(std::size_t scanNum) const
+TimsFrameBase::getScanTofIndexList(std::size_t scanNum) const
 {
   throw PappsoException(
     QObject::tr(
@@ -463,7 +486,7 @@ TimsFrameBase::getScanIndexList(std::size_t scanNum) const
 
 
 std::vector<quint32>
-TimsFrameBase::getScanIntensities(std::size_t scanNum) const
+TimsFrameBase::getScanIntensityList(std::size_t scanNum) const
 {
   throw PappsoException(
     QObject::tr(
@@ -472,23 +495,27 @@ TimsFrameBase::getScanIntensities(std::size_t scanNum) const
 }
 
 Trace
-TimsFrameBase::getIonMobilityTraceByMzIndexRange(
-  std::size_t mz_index_lower_bound,
-  std::size_t mz_index_upper_bound,
-  XicExtractMethod method) const
+TimsFrameBase::getIonMobilityTraceByTofIndexRange(
+  std::size_t tof_index_begin,
+  std::size_t tof_index_end,
+  XicExtractMethod method,
+  std::size_t scan_index_begin,
+  std::size_t scan_index_end) const
 {
   Trace im_trace;
   DataPoint data_point;
-  for(quint32 i = 0; i < m_scanNumber; i++)
+  if(scan_index_end > m_scanCount)
+    scan_index_end = m_scanCount;
+  for(quint32 i = scan_index_begin; i < (scan_index_end + 1); i++)
     {
       data_point.x = i;
       data_point.y = 0;
-      qDebug() << "m_scanNumber=" << m_scanNumber << " i=" << i;
-      std::vector<quint32> index_list = getScanIndexList(i);
+      qDebug() << "m_scanNumber=" << m_scanCount << " i=" << i;
+      std::vector<quint32> index_list = getScanTofIndexList(i);
       auto it_lower                   = std::find_if(index_list.begin(),
                                    index_list.end(),
-                                   [mz_index_lower_bound](quint32 to_compare) {
-                                     if(to_compare < mz_index_lower_bound)
+                                   [tof_index_begin](quint32 to_compare) {
+                                     if(to_compare < tof_index_begin)
                                        {
                                          return false;
                                        }
@@ -503,17 +530,16 @@ TimsFrameBase::getIonMobilityTraceByMzIndexRange(
         {
 
 
-          auto it_upper =
-            std::find_if(index_list.begin(),
-                         index_list.end(),
-                         [mz_index_upper_bound](quint32 to_compare) {
-                           if(mz_index_upper_bound >= to_compare)
-                             {
-                               return false;
-                             }
-                           return true;
-                         });
-          std::vector<quint32> intensity_list = getScanIntensities(i);
+          auto it_upper                       = std::find_if(index_list.begin(),
+                                       index_list.end(),
+                                       [tof_index_end](quint32 to_compare) {
+                                         if(tof_index_end >= to_compare)
+                                           {
+                                             return false;
+                                           }
+                                         return true;
+                                       });
+          std::vector<quint32> intensity_list = getScanIntensityList(i);
           for(int j = std::distance(index_list.begin(), it_lower);
               j < std::distance(index_list.begin(), it_upper);
               j++)
@@ -536,32 +562,32 @@ TimsFrameBase::getIonMobilityTraceByMzIndexRange(
 }
 
 
-std::vector<TimsFrameBase::RawValuePair> &
-TimsFrameBase::downsizeMzRawValuePairList(
+std::vector<TimsFrameBase::TofIndexIntensityPair> &
+TimsFrameBase::downgradeResolutionOfTofIndexIntensityPairList(
   std::size_t mzindex_merge_window,
-  std::vector<TimsFrameBase::RawValuePair> &rawSpectrum) const
+  std::vector<TimsFrameBase::TofIndexIntensityPair> &rawSpectrum) const
 {
 
   qDebug() << rawSpectrum.size();
-  std::vector<TimsFrameBase::RawValuePair> new_spectrum;
+  std::vector<TimsFrameBase::TofIndexIntensityPair> new_spectrum;
 
-  TimsFrameBase::RawValuePair current_point;
+  TimsFrameBase::TofIndexIntensityPair current_point;
   current_point.intensity_index = 0;
-  current_point.mz_tof_index    = 0;
+  current_point.tof_index       = 0;
   for(auto &pair_mz_intensity : rawSpectrum)
     {
-      quint32 mzkey = (pair_mz_intensity.mz_tof_index / mzindex_merge_window);
+      quint32 mzkey = (pair_mz_intensity.tof_index / mzindex_merge_window);
       mzkey = (mzkey * mzindex_merge_window) + (mzindex_merge_window / 2);
 
-      if(current_point.mz_tof_index != mzkey)
+      if(current_point.tof_index != mzkey)
         {
-          if(current_point.mz_tof_index > 0)
+          if(current_point.tof_index > 0)
             {
               new_spectrum.push_back(current_point);
             }
 
           current_point.intensity_index = pair_mz_intensity.intensity_index;
-          current_point.mz_tof_index    = mzkey;
+          current_point.tof_index       = mzkey;
         }
       else
         {
@@ -569,7 +595,7 @@ TimsFrameBase::downsizeMzRawValuePairList(
         }
     }
 
-  if(current_point.mz_tof_index > 0)
+  if(current_point.tof_index > 0)
     {
       new_spectrum.push_back(current_point);
     }
