@@ -50,9 +50,9 @@ class TimsFrameBase
   public:
   /** @brief constructor for binary independant tims frame
    * @param timsId tims frame identifier in the database
-   * @param scanNum the total number of scans contained in this frame
+   * @param scanCount the number of scans in this frame
    */
-  TimsFrameBase(std::size_t timsId, quint32 scanNum);
+  TimsFrameBase(std::size_t frameId, quint32 scanCount);
   /**
    * Copy constructor
    *
@@ -72,10 +72,10 @@ class TimsFrameBase
 
   /** @brief get the number of peaks in this spectrum
    * need the binary file
-   * @param scanNum scan number in the frame in the order it lies in binary
-   * file, from 0 to N-1
+   * @param scanIndex scan index in the frame in the order it lies in
+frame's binary data, from 0 to N-1
    */
-  virtual std::size_t getNbrPeaks(std::size_t scanNum) const;
+  virtual std::size_t getScanPeakCount(std::size_t scanIndex) const;
 
   /** @brief get the number of scans contained in this frame
    * each scan represents an ion mobility slice
@@ -88,57 +88,59 @@ class TimsFrameBase
    */
   virtual quint32 getMaximumRawMassIndex() const;
 
-  /** @brief get Mass spectrum with peaks for this scan number
+  /** @brief get Mass spectrum with peaks for this scan index
    * need the binary file
-   * @param scanNum scan number in the frame in the order it lies in binary
+   * @param scan_index scan index in the frame in the order it lies in binary
    * file, from 0 to N-1 (this is the mobility index)
    */
-  virtual MassSpectrumSPtr getMassSpectrumSPtr(std::size_t scanNum) const;
+  virtual MassSpectrumSPtr getMassSpectrumSPtr(std::size_t scan_index) const;
 
 
-  /** @brief get the mass spectrum corresponding to a scan number
-   * @param scanNum the scan number to retrieve
+  /** @brief get the mass spectrum corresponding to a scan index
+   * @param scan_index the scan index of the mass spectrum to retrieve
    * */
   virtual pappso::MassSpectrumCstSPtr
-  getMassSpectrumCstSPtr(std::size_t scanNum) const final;
+  getMassSpectrumCstSPtr(std::size_t scan_index) const final;
 
   /** @brief cumulate spectrum given a scan number range
    * need the binary file
    * The intensities are normalized with respect to the frame accumulation time
    *
-   * @param scanNumBegin scan number in the frame in the order it lies in binary
-   * file, from 0 to N-1
-   * @param scanNumEnd scan number in the frame in the order it lies in binary
-   * file, from 0 to N-1
+   * @param scanIndexBegin scan index in the frame in the order it lies in the
+frame in the binary file, from 0 to N-1
+   * @param scanIndexEnd scan number in the frame in the order it lies in the
+frame in the binary file, from 0 to N-1
    */
-  virtual Trace cumulateScansToTrace(std::size_t scanNumBegin,
-                                     std::size_t scanNumEnd) const;
+  virtual Trace cumulateScansToTrace(std::size_t scanIndexBegin,
+                                     std::size_t scanIndexEnd) const;
 
 
-  /** @brief cumulate spectrum given a scan number range
+  /** @brief cumulate spectrum given a scan index range
    * need the binary file
    * The intensities are normalized with respect to the frame accumulation time
    * to leverage computing performance, this function decreases the mz
    * resolution
    *
-   * @param mzindex_merge_window width of the mzindex window used to merge all
+   * @param tof_index_merge_window width of the TOF index window used to merge
+all
    * intensities into a single point. This results in faster computing.
-   * @param scanNumBegin scan number in the frame in the order it lies in binary
+   * @param scanIndexBegin scan index in the frame in the order it lies in
+binary
    * file, from 0 to N-1
-   * @param scanNumEnd scan number in the frame in the order it lies in binary
+   * @param scanIndexEnd scan index in the frame in the order it lies in binary
    * file, from 0 to N-1
-   * @param mz_minimum_index report the minimum mz index contained in the
+   * @param minimum_tof_index_out report the minimum mz index contained in the
    * resulting trace
-   * @param mz_maximum_index report the maximum mz index contained in the
+   * @param maximum_tof_index_out report the maximum mz index contained in the
    * resulting trace
    *
    */
-  virtual Trace
-  cumulateScansToTraceMzDownResolution(std::size_t mzindex_merge_window,
-                                       std::size_t scanNumBegin,
-                                       std::size_t scanNumEnd,
-                                       quint32 &minimum_index,
-                                       quint32 &maximum_index) const;
+  virtual Trace combineScansToTraceWithDowngradedMzResolution(
+    std::size_t tof_index_merge_window,
+    std::size_t scanIndexBegin,
+    std::size_t scanIndexEnd,
+    quint32 &minimum_tof_index_out,
+    quint32 &maximum_tof_index_out) const;
 
 
   /** @brief cumulate spectrum given a scan number range
@@ -161,21 +163,22 @@ class TimsFrameBase
    * resulting trace (constrained by the mz_range_end)
    *
    */
-  virtual Trace
-  cumulateScansToTraceMzDownResolution2(std::size_t mz_index_merge_window,
-                                        double mz_range_begin,
-                                        double mz_range_end,
-                                        std::size_t mobility_scan_begin,
-                                        std::size_t mobility_scan_end,
-                                        quint32 &mz_minimum_index_out,
-                                        quint32 &mz_maximum_index_out) const;
+  virtual Trace combineScansToTraceWithDowngradedMzResolution2(
+    std::size_t mz_index_merge_window,
+    double mz_range_begin,
+    double mz_range_end,
+    std::size_t mobility_scan_begin,
+    std::size_t mobility_scan_end,
+    quint32 &mz_minimum_index_out,
+    quint32 &mz_maximum_index_out) const;
 
 
   /** @brief get a single mobility scan m/z + intensities
    *
-   * @param scanNum scan number in the frame in the order it lies in binary
+   * @param scanIndex scan number in the frame in the order it lies in binary
    * file, from 0 to N-1
-   * @param mzindex_merge_window width of the mzindex window used to merge all
+   * @param tof_index_merge_window width of the TOF index window used to merge
+all
    * intensities into a single point. This results in faster computing.
    * @param mz_range_begin
    * @param mz_range_end
@@ -185,8 +188,8 @@ class TimsFrameBase
    * resulting trace (constrained by the mz_range_end)
    *
    */
-  virtual Trace getMobilityScan(std::size_t scanNum,
-                                std::size_t mz_index_merge_window,
+  virtual Trace getMobilityScan(std::size_t scan_index,
+                                std::size_t tof_index_merge_window,
                                 double mz_range_begin,
                                 double mz_range_end,
                                 quint32 &mz_minimum_index_out,
@@ -196,21 +199,48 @@ class TimsFrameBase
    * The intensities are NOT normalized with respect to the frame accumulation
    * time
    *
-   * @param rawSpectrum simple map of integers to cumulate raw counts
-   * @param scanNumBegin scan number in the frame in the order it lies in binary
+   * @param tof_index_intensity_map simple map of integers to cumulate raw
+counts
+   * @param scan_index_begin scan index in the frame in the order it lies in
+binary
    * file, from 0 to N-1
-   * @param scanNumEnd scan number in the frame in the order it lies in binary
+   * @param scan_index_end scan index in the frame in the order it lies in
+binary
    * file, from 0 to N-1
    */
-  virtual void cumulateScansInRawMap(TimsDataFastMap &rawSpectrum,
-                                     std::size_t scanNumBegin,
-                                     std::size_t scanNumEnd) const;
+  virtual void
+  combineScansInTofIndexIntensityMap(TimsDataFastMap &tof_index_intensity_map,
+                                     std::size_t scan_index_begin,
+                                     std::size_t scan_index_end) const;
 
 
-  virtual quint64 cumulateSingleScanIntensities(std::size_t scanNum) const;
+  /** @brief cumulate scan list into a trace into a raw spectrum map
+   * The intensities are NOT normalized with respect to the frame accumulation
+   * time
+   *
+   * @param tof_index_intensity_map simple map of integers to cumulate raw
+counts
+   * @param scan_index_begin scan index in the frame in the order it lies in
+binary
+   * file, from 0 to N-1
+   * @param scan_index_end scan index in the frame in the order it lies in
+binary
+   * file, from 0 to N-1
+   * @param tof_index_begin
+   * @param tof_index_end
+   */
+  virtual void
+  combineScansInTofIndexIntensityMap(TimsDataFastMap &tof_index_intensity_map,
+                                     std::size_t scan_index_begin,
+                                     std::size_t scan_index_end,
+                                     quint32 tof_index_begin,
+                                     quint32 tof_index_end) const;
 
-  virtual quint64 cumulateScansIntensities(std::size_t scanNumBegin,
-                                           std::size_t scanNumEnd) const;
+  virtual quint64 cumulateScanIntensities(std::size_t scan_index) const;
+
+  virtual quint64
+  cumulateScanRangeIntensities(std::size_t scan_index_begin,
+                               std::size_t scan_index_end) const;
 
   /** @brief check that this scan number exists
    * @param scanNum scan number in the frame in the order it lies in binary
@@ -219,7 +249,7 @@ class TimsFrameBase
   bool checkScanNum(std::size_t scanNum) const;
 
 
-  void setAccumulationTime(double accumulation_time_ms);
+  void setAcqDurationInMilliseconds(double acquisition_duration_ms);
   void setMzCalibration(double T1_frame,
                         double T2_frame,
                         double digitizerTimebase,
@@ -244,10 +274,10 @@ class TimsFrameBase
                           double C7,
                           double C8,
                           double C9);
-  void setTime(double time);
+  void setRtInSeconds(double time);
   void setMsMsType(quint8 type);
   unsigned int getMsLevel() const;
-  double getTime() const;
+  double getRtInSeconds() const;
 
   std::size_t getId() const;
 
@@ -256,13 +286,13 @@ class TimsFrameBase
    * file, from 0 to N-1
    * @return time in milliseconds of mobility delay (drift time)
    * */
-  double getDriftTime(std::size_t scanNum) const;
+  double getDriftTimeInMilliseconds(std::size_t scan_index) const;
 
   /** @brief get 1/K0 value of a given scan (mobility value)
    * @param scanNum scan number in the frame in the order it lies in binary
    * file, from 0 to N-1
    * */
-  double getOneOverK0Transformation(std::size_t scanNum) const;
+  double getOneOverK0Transformation(std::size_t scan_index) const;
 
 
   /** @brief get the scan number from a given 1/Ko mobility value
@@ -270,7 +300,7 @@ class TimsFrameBase
    * @return integer the scan number in the frame in the order it lies in binary
    * file, from 0 to N-1
    */
-  std::size_t getScanNumFromOneOverK0(double one_over_k0) const;
+  std::size_t getScanIndexFromOneOverK0(double one_over_k0) const;
 
   /** @brief get voltage for a given scan number
    * @param scanNum scan number in the frame in the order it lies in binary
@@ -279,11 +309,10 @@ class TimsFrameBase
    * */
   double getVoltageTransformation(std::size_t scanNum) const;
 
-
   /** @brief transform accumulation of raw scans into a real mass spectrum
    */
   pappso::Trace
-  getTraceFromCumulatedScans(TimsDataFastMap &accumulated_scans) const;
+  getTraceFromTofIndexIntensityMap(TimsDataFastMap &accumulated_scans) const;
 
 
   /** @brief get the MzCalibration model to compute mz and TOF for this frame
@@ -297,61 +326,77 @@ class TimsFrameBase
   /** @brief get raw index list for one given scan
    * index are not TOF nor m/z, just index on digitizer
    */
-  virtual std::vector<quint32> getScanIndexList(std::size_t scanNum) const;
+  virtual std::vector<quint32>
+  getScanTofIndexList(std::size_t scan_index) const;
 
   /** @brief get raw intensities without transformation from one scan
    * it needs intensity normalization
    */
-  virtual std::vector<quint32> getScanIntensities(std::size_t scanNum) const;
+  virtual std::vector<quint32>
+  getScanIntensityList(std::size_t scan_index) const;
 
   /** @brief get a mobility trace cumulating intensities inside the given mass
    * index range
-   * @param mz_index_lower_bound raw mass index lower bound
-   * @param mz_index_upper_bound raw mass index upper bound
+   * @param tof_index_begin raw mass index lower bound
+   * @param tof_index_end raw mass index upper bound
    * @param method max or sum intensities
+   * @param scan_index_begin first mobility scan to integrate
+   * @param scan_index_end last mobility scan to integrate
    */
   virtual Trace
-  getIonMobilityTraceByMzIndexRange(std::size_t mz_index_lower_bound,
-                                    std::size_t mz_index_upper_bound,
-                                    XicExtractMethod method) const;
+  getIonMobilityTraceByTofIndexRange(std::size_t tof_index_begin,
+                                     std::size_t tof_index_end,
+                                     XicExtractMethod method,
+                                     std::size_t scan_index_begin,
+                                     std::size_t scan_index_end) const;
 
   protected:
-  struct RawValuePair
+  struct TofIndexIntensityPair
   {
-    quint32 mz_tof_index;
+    quint32 tof_index;
     quint32 intensity_index;
   };
 
-  /** @brief downsize mz resolution to lower the number of real mz computations
+  /** @brief Downgrade the TOF index resolution to lower the number of real m/z
+computations
+
+    This function merges together into a single TOF index bin all the TOF
+indices contained in the \a tof_index_merge_window. Then the window is shifted
+and the operation is performed again. When all the list of
+\l{TofIndexIntensityPair}s has been gone through, the resolution of the data
+has effectively been downgrade by a factor corresponding to \a
+tof_index_merge_window.
    *
-   * @param mzindex_merge_window width of the mzindex window used to merge all
+   * @param tof_index_merge_window width of the TOF index window used to merge
+all
    * intensities into a single point. This results in faster computing.
    * @param rawSpectrum the spectrum to shrink
    */
-  virtual std::vector<RawValuePair> &
-  downsizeMzRawValuePairList(std::size_t mzindex_merge_window,
-                             std::vector<RawValuePair> &spectrum) const;
+  virtual std::vector<TofIndexIntensityPair> &
+  downgradeResolutionOfTofIndexIntensityPairList(
+    std::size_t tof_index_merge_window,
+    std::vector<TofIndexIntensityPair> &spectrum) const;
 
   protected:
   /** @brief total number of scans contained in this frame
    */
-  quint32 m_scanNumber;
+  quint32 m_scanCount;
 
   /** @brief Tims frame database id (the SQL identifier of this frame)
    * @warning in sqlite, there is another field called TimsId : this is not
    * that, because it is in fact an offset in bytes in the binary file.
    * */
-  std::size_t m_timsId;
+  std::size_t m_frameId;
 
-  /** @brief accumulation time in milliseconds
+  /** @brief acquisition duration in milliseconds
    */
-  double m_accumulationTime = 0;
+  double m_acqDurationInMilliseconds = 0;
 
   quint8 m_msMsType = 0;
 
   /** @brief retention time
    */
-  double m_time = 0;
+  double m_rtInSeconds = 0;
 
   double m_timsDvStart = 0; // C2 from TimsCalibration
   double m_timsSlope =
