@@ -37,8 +37,8 @@ TimsMs2CentroidFilter::~TimsMs2CentroidFilter()
 {
 }
 
-TimsMs2CentroidFilter::TimsMs2CentroidFilter([
-  [maybe_unused]] const TimsMs2CentroidFilter &other)
+TimsMs2CentroidFilter::TimsMs2CentroidFilter(
+  [[maybe_unused]] const TimsMs2CentroidFilter &other)
 {
 }
 
