@@ -77,7 +77,7 @@ pappso::TimsDirectXicExtractor::protectedExtractXicCoordSPtrList(
 
 
   std::vector<std::size_t> tims_frameid_list =
-    mp_timsData->getTimsMS1FrameIdRange(
+    mp_timsData->getTimsMS1FrameIdsInRtRange(
       xic_coord_tims_list[0]->rtTarget - m_retentionTimeAroundTarget,
       xic_coord_tims_list.back()->rtTarget + m_retentionTimeAroundTarget);
 
@@ -99,7 +99,7 @@ pappso::TimsDirectXicExtractor::protectedExtractXicCoordSPtrList(
       TimsFrameCstSPtr frame_sptr =
         mp_timsData->getTimsFrameCstSPtrCached(frame_id);
       qDebug();
-      double rtframe = frame_sptr.get()->getTime();
+      double rtframe = frame_sptr.get()->getRtInSeconds();
       qDebug();
 
       double rtbeginframe = rtframe - m_retentionTimeAroundTarget;
