@@ -26,21 +26,29 @@
  ******************************************************************************/
 
 #include "timsxicextractorinterface.h"
+#include "../../../msrun/private/timsmsrunreaderms2.h"
+#include "../../../exception/exceptionnotpossible.h"
 
 using namespace pappso;
 
 TimsXicExtractorInterface::TimsXicExtractorInterface(
-  const TimsData *mp_tims_data)
-  : mp_timsData(mp_tims_data)
+  MsRunReaderSPtr &msrun_reader)
+  : MsRunXicExtractorInterface(msrun_reader)
 {
+
+  pappso::TimsMsRunReaderMs2 *tims2_reader =
+    dynamic_cast<pappso::TimsMsRunReaderMs2 *>(msrun_reader.get());
+  if(tims2_reader != nullptr)
+    {
+      mp_timsData = tims2_reader->getTimsDataSPtr().get();
+    }
+  else
+    {
+      throw pappso::ExceptionNotPossible(QObject::tr(
+        "error: TimsXicExtractorInterface must use a TimsMsRunReaderMs2"));
+    }
 }
 
 TimsXicExtractorInterface::~TimsXicExtractorInterface()
 {
 }
-
-void
-TimsXicExtractorInterface::setXicExtractMethod(XicExtractMethod method)
-{
-  m_xicExtractMethod = method;
-}
