@@ -48,7 +48,7 @@ MassSpectrumWidget::MassSpectrumWidget(QWidget *parent)
 
   this->setLayout(new QHBoxLayout(this));
 
-  this->layout()->setContentsMargins(0,0,0,0);
+  this->layout()->setContentsMargins(0, 0, 0, 0);
   setVisibleMassDelta(false);
   qDebug();
 }
@@ -194,6 +194,7 @@ MassSpectrumWidget::peptideAnnotate()
     {
       if(_ms_level > 1)
         {
+          qDebug();
           PeptideIsotopeSpectrumMatch psm_match(*(_spectrum_sp.get()),
                                                 _peptide_sp,
                                                 _peptide_charge,
@@ -203,6 +204,8 @@ MassSpectrumWidget::peptideAnnotate()
                                                 _max_isotope_rank);
 
           _peak_ion_isotope_match_list = psm_match.getPeakIonIsotopeMatchList();
+          qDebug() << "_peak_ion_isotope_match_list.size()="
+                   << _peak_ion_isotope_match_list.size();
         }
       else
         {
@@ -264,12 +267,14 @@ void
 MassSpectrumWidget::plot()
 {
 
-  qDebug();
+  qDebug() << "_ms_level=" << _ms_level;
   peptideAnnotate();
   if(_ms_level == 1)
     {
+      qDebug();
       if(_spectrum_sp != nullptr)
         {
+          qDebug();
           if(_isotope_mass_list.size() > 0)
             {
 
@@ -318,6 +323,8 @@ MassSpectrumWidget::plot()
     }
   else
     {
+      qDebug() << "_peak_ion_isotope_match_list.size()="
+               << _peak_ion_isotope_match_list.size();
       _peak_ion_isotope_match_list.sort(
         [](const PeakIonIsotopeMatch &a, const PeakIonIsotopeMatch &b) {
           return a.getPeak().y > b.getPeak().y;
@@ -448,6 +455,7 @@ MassSpectrumWidget::computeIsotopeMassList()
             }
         }
     }
+  qDebug() << "_isotope_mass_list.size()=" << _isotope_mass_list.size();
 }
 
 void
