@@ -52,6 +52,23 @@
 namespace pappso
 {
 
+ enum class SelectionDrawingLines
+ {
+  NOT_SET = 0x0000,
+  
+  TOP_LINE    = 1 << 0,
+  BOTTOM_LINE = 1 << 1,
+  
+  HORIZONTAL_LINES = (TOP_LINE | BOTTOM_LINE),
+  
+  RIGHT_LINE = 1 << 2,
+  LEFT_LINE  = 1 << 3,
+  
+  VERTICAL_LINES = (RIGHT_LINE | LEFT_LINE),
+  
+  FULL_POLYGON = (HORIZONTAL_LINES | VERTICAL_LINES)
+ };
+ 
 enum class RangeType
 {
   outermost = 1,
@@ -183,8 +200,8 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
   virtual void showTracers();
   virtual void hideTracers();
 
-  virtual void drawXDeltaFeatures();
-  virtual void drawYDeltaFeatures();
+  virtual void drawXScopeSpanFeatures();
+  virtual void drawYScopeSpanFeatures();
 
   virtual void calculateDragDeltas();
 
@@ -194,13 +211,13 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
   drawSelectionRectangleAndPrepareZoom(bool as_line_segment = false,
                                        bool for_integration = false);
 
-  virtual void updateSelectionRectangle(bool as_line_segment = false,
+  virtual void updateIntegrationScopeDrawing(bool as_line_segment = false,
                                         bool for_integration = false);
 
   virtual void resetSelectionRectangle();
   virtual void hideSelectionRectangle(bool reset_values = false);
   virtual bool isSelectionRectangleVisible();
-  virtual PolygonType whatIsVisibleOfTheSelectionRectangle();
+  virtual SelectionDrawingLines whatIsVisibleOfTheSelectionRectangle();
 
   /// PLOT ITEMS : TRACER TEXT ITEMS...
 
@@ -339,9 +356,11 @@ class PMSPP_LIB_DECL BasePlotWidget : public QCustomPlot
   QPen m_pen;
 
   virtual void createAllAncillaryItems();
-  virtual void update1DSelectionRectangle(bool for_integration = false);
-  virtual void update2DSelectionRectangleSquare(bool for_integration = false);
-  virtual void update2DSelectionRectangleSkewed(bool for_integration = false);
+  virtual void updateIntegrationScope(bool for_integration = false);
+  virtual void updateIntegrationScopeRect(bool for_integration = false);
+  virtual void updateIntegrationScopeHorizontalRhomb(bool for_integration = false);
+  virtual void updateIntegrationScopeVerticalRhomb(bool for_integration = false);
+  virtual void updateIntegrationScopeRhomb(bool for_integration = false);
   virtual QString allLayerNamesToString() const;
   virtual QString layerableLayerName(QCPLayerable *layerable_p) const;
   virtual int layerableLayerIndex(QCPLayerable *layerable_p) const;
