@@ -219,10 +219,31 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
 #endif
 
   for(auto &value : trace.xValues())
-    key_qvector.push_back(value);
+    {
+      key_qvector.push_back(value);
+    }
 
   for(auto &value : trace.yValues())
-    value_qvector.push_back(value);
+    {
+      value_qvector.push_back(value);
+    }
+
+#if 0
+
+  qDebug() << "The size of the x values for trace is:" << key_qvector.size()
+           << "and for y values is:" << value_qvector.size();
+
+  QString text;
+
+  for(qsizetype iter = 0; iter < key_qvector.size(); ++iter)
+    text += QString("(%1,%2)\n")
+              .arg(key_qvector.at(iter), 0, 'f', 6)
+              .arg(value_qvector.at(iter), 0, 'f', 6);
+
+  qDebug().noquote() << text;
+
+#endif
+
 
   graph_p->setData(key_qvector, value_qvector, true);
 
@@ -504,13 +525,13 @@ BaseTracePlotWidget::axisDoubleClickHandler(
   [[maybe_unused]] QCPAxis::SelectablePart part,
   QMouseEvent *event)
 {
-  //qDebug();
+  // qDebug();
 
   m_context.m_keyboardModifiers = QGuiApplication::queryKeyboardModifiers();
 
   if(m_context.m_keyboardModifiers & Qt::ControlModifier)
     {
-      //qDebug();
+      // qDebug();
 
       // If the Ctrl modifiers is active, then both axes are to be reset. Also
       // the histories are reset also.
@@ -520,7 +541,7 @@ BaseTracePlotWidget::axisDoubleClickHandler(
     }
   else
     {
-      //qDebug();
+      // qDebug();
 
       // Only the axis passed as parameter is to be rescaled.
       // Reset the range of that axis to the max view possible, but for the y
@@ -691,7 +712,7 @@ BaseTracePlotWidget::axisRescale()
 void
 BaseTracePlotWidget::axisReframe()
 {
-  //qDebug();
+  // qDebug();
 
   // double sorted_start_drag_point_x =
   // std::min(m_context.m_startDragPoint.x(), m_context.m_currentDragPoint.x());
@@ -774,7 +795,7 @@ BaseTracePlotWidget::axisZoom()
 void
 BaseTracePlotWidget::axisPan()
 {
-  //qDebug();
+  // qDebug();
 
   // Sanity check
   if(!m_context.m_wasClickOnXAxis && !m_context.m_wasClickOnYAxis)
@@ -809,7 +830,7 @@ BaseTracePlotWidget::axisPan()
 
   updateContextXandYAxisRanges();
 
-  //qDebug() << "The updated context:" << m_context.toString();
+  // qDebug() << "The updated context:" << m_context.toString();
 
   // We cannot store the new ranges in the history, because the pan operation
   // involved a huge quantity of micro-movements elicited upon each mouse move
