@@ -55,10 +55,10 @@ namespace pappso
 MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent)
   : BaseTracePlotWidget(parent)
 {
-  m_context.m_dataKind = DataKind::mz;
+  BasePlotWidget::m_context.m_dataKind = DataKind::mz;
+  m_context.m_dataKind                 = DataKind::mz;
 
-  // qDebug() << "Data kind:" <<
-  // static_cast<int>(m_context.m_baseContext.m_dataKind);
+  // qDebug() << "Data kind:" << static_cast<int>(m_context.m_dataKind);
 }
 
 MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent,
@@ -68,10 +68,10 @@ MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent,
 {
   // Set the base context to be of kind DataKind::mz;
 
-  m_context.m_dataKind = DataKind::mz;
+  BasePlotWidget::m_context.m_dataKind = DataKind::mz;
+  m_context.m_dataKind                 = DataKind::mz;
 
-  // qDebug() << "Data kind:" <<
-  // static_cast<int>(m_context.m_baseContext.m_dataKind);
+  // qDebug() << "Data kind:" << static_cast<int>(m_context.m_dataKind);
 }
 
 
@@ -101,11 +101,11 @@ MassSpecTracePlotWidget::keyPressEvent(QKeyEvent *event)
 void
 MassSpecTracePlotWidget::keyReleaseEvent(QKeyEvent *event)
 {
-  BasePlotWidget::keyReleaseEvent(event);
+ // Before working on the various data belonging to the base context, we need
+ // to get it from the base class and refresh our local context with it.
+ refreshBaseContext();
 
-  // Before working on the various data belonging to the base context, we need
-  // to get it from the base class and refresh our local context with it.
-  refreshBaseContext();
+ BasePlotWidget::keyReleaseEvent(event);
 }
 
 
@@ -125,22 +125,22 @@ MassSpecTracePlotWidget::keyReleaseEvent(QKeyEvent *event)
 void
 MassSpecTracePlotWidget::mouseMoveHandler(QMouseEvent *event)
 {
-  BasePlotWidget::mouseMoveHandler(event);
+ // Before working on the various data belonging to the base context, we need
+ // to get it from the base class and refresh our local context with it.
+ refreshBaseContext();
 
-  // Before working on the various data belonging to the base context, we need
-  // to get it from the base class and refresh our local context with it.
-  refreshBaseContext();
+  BasePlotWidget::mouseMoveHandler(event);
 }
 
 
 void
 MassSpecTracePlotWidget::mouseMoveHandlerNotDraggingCursor()
 {
-  BasePlotWidget::mouseMoveHandlerNotDraggingCursor();
-
-  // Before working on the various data belonging to the base context, we need
+   // Before working on the various data belonging to the base context, we need
   // to get it from the base class and refresh our local context with it.
   refreshBaseContext();
+
+  BasePlotWidget::mouseMoveHandlerNotDraggingCursor();
 }
 
 
@@ -171,11 +171,11 @@ MassSpecTracePlotWidget::mouseMoveHandlerDraggingCursor()
 void
 MassSpecTracePlotWidget::mousePressHandler(QMouseEvent *event)
 {
-  BasePlotWidget::mousePressHandler(event);
-
   // Before working on the various data belonging to the base context, we need
   // to get it from the base class and refresh our local context with it.
   refreshBaseContext();
+
+  BasePlotWidget::mousePressHandler(event);
 }
 
 
@@ -183,11 +183,11 @@ MassSpecTracePlotWidget::mousePressHandler(QMouseEvent *event)
 void
 MassSpecTracePlotWidget::mouseReleaseHandler(QMouseEvent *event)
 {
-  BasePlotWidget::mouseReleaseHandler(event);
+ // Before working on the various data belonging to the base context, we need
+ // to get it from the base class and refresh our local context with it.
+ refreshBaseContext();
 
-  // Before working on the various data belonging to the base context, we need
-  // to get it from the base class and refresh our local context with it.
-  refreshBaseContext();
+ BasePlotWidget::mouseReleaseHandler(event);
 }
 
 
@@ -205,8 +205,14 @@ MassSpecTracePlotWidget::refreshBaseContext() const
   // m_context member that is of type MassSpecTracePlotContext. We thus need to
   // resynchronize the data from BasePlotWidget::m_context to our m_context.
 
+  // qDebug().noquote() << "The base plot context:" <<
+  // BasePlotWidget::m_context.toString();
+
   m_context = BasePlotWidget::m_context;
 
+  // qDebug().noquote() << "After refreshing the base context, base context:"
+  //                    << m_context.toString();
+
   return m_context;
 }
 
