@@ -43,6 +43,7 @@
 #include <pappsomspp/processing/filters/filtersuitestring.h>
 #include <pappsomspp/xicextractor/msrunxicextractorfactory.h>
 #include <pappsomspp/processing/uimonitor/uimonitortextpercent.h>
+#include <pappsomspp/vendors/tims/timsddaprecursors.h>
 #include "tests/config.h"
 #include "../common.h"
 #include <time.h>
@@ -112,7 +113,7 @@ TEST_CASE("Extracting XIC from timsdata", "[TimsXicExtractor]")
 
   std::vector<std::size_t> precursor_list = {2159};
   std::vector<pappso_double> mz_list      = {
-    466.738, 467.239, 420, 421, 422, 423, 424, 425, 426};
+         466.738, 467.239, 420, 421, 422, 423, 424, 425, 426};
 
   std::vector<pappso::XicCoordSPtr> xic_list;
   std::vector<pappso::XicCoordSPtr> xic_struct_list;
@@ -122,6 +123,7 @@ TEST_CASE("Extracting XIC from timsdata", "[TimsXicExtractor]")
     {
       xic_list.push_back(
         tims_data.get()
+          ->getTimsDdaPrecursorsPtr()
           ->getXicCoordTimsFromPrecursorId(
             precursor_id, PrecisionFactory::getPpmInstance(30.0))
           .initializeAndClone());
