@@ -42,6 +42,7 @@
 #include <pappsomspp/processing/filters/filtersuitestring.h>
 #include <pappsomspp/xicextractor/msrunxicextractorfactory.h>
 #include <pappsomspp/processing/uimonitor/uimonitortext.h>
+#include <pappsomspp/vendors/tims/timsddaprecursors.h>
 #include "tests/config.h"
 #include "../common.h"
 #include <time.h>
@@ -132,6 +133,7 @@ TEST_CASE("Creating mass spectrum via TIMS XIC extraction from timsdata",
     {
       XicCoordSPtr xic_coord_tims_struct_sp =
         tims_data.get()
+          ->getTimsDdaPrecursorsPtr()
           ->getXicCoordTimsFromPrecursorId(precursor_id,
                                            PrecisionFactory::getPpmInstance(30))
           .initializeAndClone();
