@@ -43,3 +43,8 @@ class XicOdsWriter
 };
 
 bool compareTextFiles(const QString &file1, const QString &file2);
+
+std::vector<std::size_t>
+getMapKeys(const std::map<std::size_t, std::size_t> &map_table);
+std::vector<std::size_t>
+getMapValues(const std::map<std::size_t, std::size_t> &map_table);
