@@ -27,12 +27,8 @@
 
 // ./tests/catch2-only-tests [C13N15] -s
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
 
 #include <QDebug>
 #include <QString>
@@ -67,7 +63,7 @@ TEST_CASE("C13N15 amino acid labeling test suite.", "[C13N15]")
     REQUIRE(lysine.getNumberOfAtom(AtomIsotopeSurvey::C) == 6);
     REQUIRE(lysine.getNumberOfAtom(AtomIsotopeSurvey::N) == 2);
 
-    REQUIRE(lysine.getMass() == Approx(128.09496301));
+    REQUIRE(lysine.getMass() == Catch::Approx(128.09496301));
 
     AaModificationP k_c13n15 = AaModification::getInstance("C13N15:K");
     lysine.addAaModification(k_c13n15);
@@ -77,7 +73,7 @@ TEST_CASE("C13N15 amino acid labeling test suite.", "[C13N15]")
     REQUIRE(lysine.getNumberOfIsotope(Isotope::N15) == 2);
     REQUIRE(lysine.getNumberOfAtom(AtomIsotopeSurvey::N) == 2);
 
-    REQUIRE(lysine.getMass() == Approx(136.1091618297));
+    REQUIRE(lysine.getMass() == Catch::Approx(136.1091618297));
 
     Aa aspartic_acid('D');
 
@@ -174,8 +170,8 @@ TEST_CASE("C13N15 amino acid labeling test suite.", "[C13N15]")
     REQUIRE(alanine.getNumberOfAtom(AtomIsotopeSurvey::C) == 3);
     REQUIRE(alanine.getNumberOfIsotope(Isotope::N15) == 1);
     REQUIRE(alanine.getNumberOfAtom(AtomIsotopeSurvey::N) == 1);
-    REQUIRE(alanine.getMass() == Approx(75.0442131924));
-    REQUIRE(a_c13n15->getMass() == Approx(4.0070994068));
+    REQUIRE(alanine.getMass() == Catch::Approx(75.0442131924));
+    REQUIRE(a_c13n15->getMass() == Catch::Approx(4.0070994068));
 
     PeptideSp sample = PeptideStrParser::parseString(
       "S(C13N15:S)A(C13N15:A)M(C13N15:M)P(C13N15:P)L(C13N15:L)E(C13N15:E)R("
@@ -224,7 +220,7 @@ TEST_CASE("C13N15 amino acid labeling test suite.", "[C13N15]")
 
     Peptide sampler("MQVILLDK");
 
-    REQUIRE(sampler.getMass() == Approx(958.5521391716));
+    REQUIRE(sampler.getMass() == Catch::Approx(958.5521391716));
 
     sampler.addAaModificationOnAllAminoAcid(
       AaModification::getInstance("C13N15:M"), AminoAcidChar::methionine);
@@ -247,6 +243,6 @@ TEST_CASE("C13N15 amino acid labeling test suite.", "[C13N15]")
             "D(C13N15:D)K(MOD:00582)");
 
 
-    REQUIRE(sampler.getMass() == Approx(1011.666746131));
+    REQUIRE(sampler.getMass() == Catch::Approx(1011.666746131));
   }
 }
