@@ -28,12 +28,7 @@
 
 // ./tests/catch2-only-tests [hyperscore] -s
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
 
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/peptide/peptidenaturalisotopelist.h>
@@ -81,7 +76,8 @@ TEST_CASE("Hyperscore test suite.", "[hyperscore]")
     std::list<PeptideIon> ion_list;
     ion_list.push_back(PeptideIon::y);
     ion_list.push_back(PeptideIon::b);
-    std::cout << "spectrum_simple size  " << spectrum_simple.size() << std::endl;
+    std::cout << "spectrum_simple size  " << spectrum_simple.size()
+              << std::endl;
 
     qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
     XtandemHyperscore hyperscore_withxtspectrum(spectrum_simple,
@@ -93,8 +89,8 @@ TEST_CASE("Hyperscore test suite.", "[hyperscore]")
 
     qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
     std::cout << "spectrum_simple " << peptide.getSequence().toStdString()
-         << " hyperscore=" << hyperscore_withxtspectrum.getHyperscore()
-         << std::endl;
+              << " hyperscore=" << hyperscore_withxtspectrum.getHyperscore()
+              << std::endl;
     float test_tandem =
       std::round(10 * hyperscore_withxtspectrum.getHyperscore()) / 10;
     REQUIRE(test_tandem == (float)33.5);
@@ -110,8 +106,9 @@ TEST_CASE("Hyperscore test suite.", "[hyperscore]")
                                        ion_list,
                                        refine_spectrum_synthesis);
     std::cout << "spectrum_simple with spectrum model "
-         << peptide.getSequence().toStdString()
-         << " hyperscore=" << hyperscore_model.getHyperscore() << std::endl;
+              << peptide.getSequence().toStdString()
+              << " hyperscore=" << hyperscore_model.getHyperscore()
+              << std::endl;
     // hyperscore="35.4"
     test_tandem = round(10 * hyperscore_model.getHyperscore()) / 10;
     REQUIRE(test_tandem == (float)35.4);
@@ -157,7 +154,7 @@ TEST_CASE("Hyperscore test suite.", "[hyperscore]")
 
     qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
     std::cout << "peptide " << peptide.getSequence().toStdString()
-         << " hyperscore=" << hyperscore.getHyperscore() << std::endl;
+              << " hyperscore=" << hyperscore.getHyperscore() << std::endl;
     // SUCCESS
 
     qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
@@ -189,7 +186,7 @@ TEST_CASE("Hyperscore test suite.", "[hyperscore]")
 
     qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
     std::cout << "peptide " << pep.getSequence().toStdString()
-         << " hyperscore=" << hyperscoreb.getHyperscore() << std::endl;
+              << " hyperscore=" << hyperscoreb.getHyperscore() << std::endl;
 
     qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
     // match ion ED b 245.077, pi=15 for X!Tandem
@@ -224,10 +221,11 @@ TEST_CASE("Hyperscore test suite.", "[hyperscore]")
                                       ion_list,
                                       refine_spectrum_synthesis);
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " hyperscore15968=" << hyperscore15968.getHyperscore() << std::endl;
+              << " hyperscore15968=" << hyperscore15968.getHyperscore()
+              << std::endl;
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << std::endl;
+              << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
+              << std::endl;
 
     std::vector<PeptideIon> ion_vec;
     ion_vec.push_back(PeptideIon::y);
@@ -237,13 +235,13 @@ TEST_CASE("Hyperscore test suite.", "[hyperscore]")
     if(hyperscore15968bis.computeXtandemHyperscore(spectrum, pep15968, 2))
       {
         std::cout << "XtandemHyperscoreBis peptide "
-             << pep15968.getSequence().toStdString()
-             << " hyperscore15968bis=" << hyperscore15968bis.getHyperscore()
-             << std::endl;
+                  << pep15968.getSequence().toStdString()
+                  << " hyperscore15968bis="
+                  << hyperscore15968bis.getHyperscore() << std::endl;
         std::cout << "XtandemHyperscoreBis peptide "
-             << pep15968.getSequence().toStdString()
-             << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-             << std::endl;
+                  << pep15968.getSequence().toStdString()
+                  << " mz1=" << pep15968.getMz(1)
+                  << " mz2=" << pep15968.getMz(2) << std::endl;
       }
 
     // FISLQLGQPPAMGSHM(MOD:00719)TDSNSR
