@@ -28,14 +28,10 @@
 
 // ./tests/catch2-only-tests [massrange] -s
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-using namespace Catch;
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-using namespace Catch::Matchers;
-#endif
+
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
+#include <catch2/matchers/catch_matchers_vector.hpp>
 
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/utils.h>
@@ -101,33 +97,30 @@ TEST_CASE("MassRange test suite.", "[massrange]")
     MzRange mz_range_test_ref(pappso_double(633.29706487392),
                               PrecisionFactory::getPpmInstance(10));
 
-    REQUIRE(mz_range_test_ref.getMz() ==
-            Catch::Detail::Approx(633.29706487392));
+    REQUIRE(mz_range_test_ref.getMz() == Catch::Approx(633.29706487392));
 
-    REQUIRE(mz_range_test_ref.lower() ==
-            Catch::Detail::Approx(633.290731903271));
+    REQUIRE(mz_range_test_ref.lower() == Catch::Approx(633.290731903271));
 
-    REQUIRE(mz_range_test_ref.upper() ==
-            Catch::Detail::Approx(633.303397844569));
+    REQUIRE(mz_range_test_ref.upper() == Catch::Approx(633.303397844569));
     // test :
     MzRange mz_range_test(pappso_double(633.29706487392),
                           PrecisionFactory::getPpmInstance(10),
                           PrecisionFactory::getPpmInstance(10));
-    REQUIRE(mz_range_test.getMz() == Catch::Detail::Approx(633.29706487392));
+    REQUIRE(mz_range_test.getMz() == Catch::Approx(633.29706487392));
 
 
-    REQUIRE(mz_range_test.lower() == Catch::Detail::Approx(633.290731903271));
-    REQUIRE(mz_range_test.upper() == Catch::Detail::Approx(633.303397844569));
+    REQUIRE(mz_range_test.lower() == Catch::Approx(633.290731903271));
+    REQUIRE(mz_range_test.upper() == Catch::Approx(633.303397844569));
 
     MzRange mz_range_lower_upper_test(pappso_double(633.29706487392),
                                       PrecisionFactory::getPpmInstance(10),
                                       PrecisionFactory::getDaltonInstance(1));
 
     REQUIRE(mz_range_lower_upper_test.getMz() ==
-            Catch::Detail::Approx(633.79389838859572));
+            Catch::Approx(633.79389838859572));
     REQUIRE(mz_range_lower_upper_test.lower() ==
-            Catch::Detail::Approx(633.290731903271));
+            Catch::Approx(633.290731903271));
     REQUIRE(mz_range_lower_upper_test.upper() ==
-            Catch::Detail::Approx(634.29706487392));
+            Catch::Approx(634.29706487392));
   }
 }
