@@ -26,12 +26,8 @@
 
 // cmake .. -DCMAKE_BUILD_TYPE=Debug  -DMAKE_TEST=1  -DUSEPAPPSOTREE=1
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
+
 
 #include <iostream>
 // #include <odsstream/tsvreader.h>
@@ -216,7 +212,8 @@ TEST_CASE("MSrun alignment test suite.", "[alignment]")
     QTime timer;
 
 #if USEPAPPSOTREE == 1
-    std::cout << std::endl << "..:: Test MSrun alignment starts ::.." << std::endl;
+    std::cout << std::endl
+              << "..:: Test MSrun alignment starts ::.." << std::endl;
     pappso::MsFileAccessor file_access_A01(
       "/gorgone/pappso/data_extraction_pappso/mzXML/"
       //"/home/langella/data1/mzxml/"
@@ -285,8 +282,8 @@ TEST_CASE("MSrun alignment test suite.", "[alignment]")
     writeTrace("delta_rt.tsv", common_delta_rt);
     writeTrace("rt_align.tsv", rt_align);
     std::cout << std::endl
-         << "rt_msrunA02 seamarks in common with rt_msrunA01 "
-         << common_delta_rt.size() << std::endl;
+              << "rt_msrunA02 seamarks in common with rt_msrunA01 "
+              << common_delta_rt.size() << std::endl;
 
     REQUIRE(common_delta_rt.size() == 4251);
 
@@ -302,7 +299,7 @@ TEST_CASE("MSrun alignment test suite.", "[alignment]")
     qDebug() << " first=" << rt_msrunA01.getMs1RetentionTimeVector().front()
              << " last=" << rt_msrunA01.getMs1RetentionTimeVector().back();
     std::cerr << "corrected values " << rt_msrunA02.getNumberOfCorrectedValues()
-         << " " << std::endl;
+              << " " << std::endl;
 
 
     REQUIRE(
