@@ -25,12 +25,7 @@
 
 //./tests/catch2-only-tests [MsRun] -s
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
 
 
 #include <iostream>
@@ -58,8 +53,8 @@ TEST_CASE("Test MsRun output", "[MsRun]")
   {
     // QCoreApplication a(argc, argv);
     std::cout << std::endl
-         << "..:: Test Qexception transferred accross threads ::.."
-         << std::endl;
+              << "..:: Test Qexception transferred accross threads ::.."
+              << std::endl;
     QFuture<void> future = QtConcurrent::run([=]() {
       throw pappso::ExceptionNotPossible(
         QObject::tr("Not possible, but possible to catch it accross threads"));
@@ -83,7 +78,7 @@ TEST_CASE("Test MsRun output", "[MsRun]")
       "20120906_balliau_extract_1_A01_urnb-1.mzXML",
       "");
     std::cout << "number of runIds = " << file_access_A01.getMsRunIds().size()
-         << std::endl;
+              << std::endl;
     pappso::MsRunReaderSPtr msrunA01 =
       file_access_A01.getMsRunReaderSPtrByRunId("", "runa01");
 
