@@ -1,10 +1,6 @@
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
 
 
 #include <QDebug>
@@ -132,9 +128,7 @@ TEST_CASE("Create bins with Da-based bin size", "[MzIntegrationParams]")
     // REQUIRE_THAT(1.0, Catch::Matchers::WithinAbs(1.3, 0.2)); // failure
     // REQUIRE_THAT(1.3, Catch::Matchers::WithinAbs(1.0, 0.2)); // failure
 
-    REQUIRE_THAT(bins.back(),
-                 Catch::Matchers::WithinAbs(
-                   manual_value, std::numeric_limits<double>::epsilon() * 10));
+    REQUIRE(bins.back() == Catch::Approx(manual_value));
   }
 }
 
