@@ -24,12 +24,8 @@
 // ./tests/catch2-only-tests [peptidenaturalisotopeaverage] -s
 
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
 
 #include <iostream>
 #include <pappsomspp/peptide/peptidenaturalisotopeaverage.h>
@@ -53,7 +49,8 @@ TEST_CASE("Test peptidenaturalisotopeaverage", "[peptidenaturalisotopeaverage]")
           "[peptidenaturalisotopeaverage]")
   {
 
-    std::cout << std::endl << "..:: Test natural isotope average ::.." << std::endl;
+    std::cout << std::endl
+              << "..:: Test natural isotope average ::.." << std::endl;
 
     Peptide peptide("ALLDEMAVVATEEYR");
     peptide.addAaModification(AaModification::getInstance("MOD:00397"), 0);
@@ -81,9 +78,9 @@ TEST_CASE("Test peptidenaturalisotopeaverage", "[peptidenaturalisotopeaverage]")
 
 
     std::cout << "monosiotope mz=" << peptide.getMz(charge)
-         << "average mz=" << isotopeAverage.getMz() << std::endl;
+              << "average mz=" << isotopeAverage.getMz() << std::endl;
     std::cout << "intensity ratio =" << isotopeAverage.getIntensityRatio()
-         << std::endl;
+              << std::endl;
 
     std::cout << "z=" << isotopeAverage.getCharge() << std::endl;
 
@@ -91,14 +88,13 @@ TEST_CASE("Test peptidenaturalisotopeaverage", "[peptidenaturalisotopeaverage]")
     unsigned int rank = 1;
     for(auto &&peptideNaturalIsotope : isotopeAverage.getComponents())
       {
-        std::cout << "number=" << isotopeAverage.getIsotopeNumber()
-             << " rank=" << rank
-             << " mz=" << peptideNaturalIsotope.get()->getMz(charge)
-             << " ratio="
-             << peptideNaturalIsotope.get()->getIntensityRatio(charge)
-             << " formula="
-             << peptideNaturalIsotope.get()->getFormula(charge).toStdString()
-             << std::endl;
+        std::cout
+          << "number=" << isotopeAverage.getIsotopeNumber() << " rank=" << rank
+          << " mz=" << peptideNaturalIsotope.get()->getMz(charge)
+          << " ratio=" << peptideNaturalIsotope.get()->getIntensityRatio(charge)
+          << " formula="
+          << peptideNaturalIsotope.get()->getFormula(charge).toStdString()
+          << std::endl;
         rank++;
       }
     REQUIRE(isotopeAverage.getComponents().size() == 8);
@@ -108,23 +104,22 @@ TEST_CASE("Test peptidenaturalisotopeaverage", "[peptidenaturalisotopeaverage]")
       peptide.makePeptideSp(), 1, isotopeLevel, charge, precision2);
 
     std::cout << "monosiotope mz=" << peptide.getMz(charge)
-         << "average mz=" << isotopeAverage2.getMz() << std::endl;
+              << "average mz=" << isotopeAverage2.getMz() << std::endl;
     std::cout << "intensity ratio =" << isotopeAverage2.getIntensityRatio()
-         << std::endl;
+              << std::endl;
     std::cout << "z=" << isotopeAverage2.getCharge() << std::endl;
 
     std::cout << "sum of :" << std::endl;
     rank = 1;
     for(auto &&peptideNaturalIsotope : isotopeAverage2.getComponents())
       {
-        std::cout << "number=" << isotopeAverage2.getIsotopeNumber()
-             << " rank=" << rank
-             << " mz=" << peptideNaturalIsotope.get()->getMz(charge)
-             << " ratio="
-             << peptideNaturalIsotope.get()->getIntensityRatio(charge)
-             << " formula="
-             << peptideNaturalIsotope.get()->getFormula(charge).toStdString()
-             << std::endl;
+        std::cout
+          << "number=" << isotopeAverage2.getIsotopeNumber() << " rank=" << rank
+          << " mz=" << peptideNaturalIsotope.get()->getMz(charge)
+          << " ratio=" << peptideNaturalIsotope.get()->getIntensityRatio(charge)
+          << " formula="
+          << peptideNaturalIsotope.get()->getFormula(charge).toStdString()
+          << std::endl;
         rank++;
       }
     REQUIRE(isotopeAverage2.getComponents().size() == 11);
@@ -137,14 +132,14 @@ TEST_CASE("Test peptidenaturalisotopeaverage", "[peptidenaturalisotopeaverage]")
 
 
     std::cout << std::endl
-         << "..:: Test natural isotope average on labelled peptide ::.."
-         << std::endl;
+              << "..:: Test natural isotope average on labelled peptide ::.."
+              << std::endl;
 
     peptide.addAaModification(AaModification::getInstance("MOD:00587"), 14);
 
     std::cout << std::endl
-         << "labelled formula " << peptide.getFormula(1).toStdString()
-         << std::endl;
+              << "labelled formula " << peptide.getFormula(1).toStdString()
+              << std::endl;
 
     PeptideNaturalIsotopeAverage isotopeAverage_labeled(peptide.makePeptideSp(),
                                                         askedIsotopeRank,
@@ -154,23 +149,23 @@ TEST_CASE("Test peptidenaturalisotopeaverage", "[peptidenaturalisotopeaverage]")
 
 
     std::cout << "labeled monosiotope mz=" << peptide.getMz(charge)
-         << "average mz=" << isotopeAverage_labeled.getMz() << std::endl;
-    std::cout << "intensity ratio =" << isotopeAverage_labeled.getIntensityRatio()
-         << std::endl;
+              << "average mz=" << isotopeAverage_labeled.getMz() << std::endl;
+    std::cout << "intensity ratio ="
+              << isotopeAverage_labeled.getIntensityRatio() << std::endl;
     std::cout << "z=" << isotopeAverage_labeled.getCharge() << std::endl;
 
     std::cout << "sum of :" << std::endl;
     rank = 1;
     for(auto &&peptideNaturalIsotope : isotopeAverage_labeled.getComponents())
       {
-        std::cout << "labeled number=" << isotopeAverage_labeled.getIsotopeNumber()
-             << " rank=" << rank
-             << " mz=" << peptideNaturalIsotope.get()->getMz(charge)
-             << " ratio="
-             << peptideNaturalIsotope.get()->getIntensityRatio(charge)
-             << " formula="
-             << peptideNaturalIsotope.get()->getFormula(charge).toStdString()
-             << std::endl;
+        std::cout
+          << "labeled number=" << isotopeAverage_labeled.getIsotopeNumber()
+          << " rank=" << rank
+          << " mz=" << peptideNaturalIsotope.get()->getMz(charge)
+          << " ratio=" << peptideNaturalIsotope.get()->getIntensityRatio(charge)
+          << " formula="
+          << peptideNaturalIsotope.get()->getFormula(charge).toStdString()
+          << std::endl;
         rank++;
       }
 
@@ -184,6 +179,6 @@ TEST_CASE("Test peptidenaturalisotopeaverage", "[peptidenaturalisotopeaverage]")
       isotope_list, askedIsotopeRank, isotopeLevel, charge, precision);
 
     REQUIRE(isotopeAverage_labeled.getMz() ==
-            Approx(isotopeAverage_labeled2.getMz()).epsilon(0.0001));
+            Catch::Approx(isotopeAverage_labeled2.getMz()));
   }
 }
