@@ -42,6 +42,7 @@
 #include <iostream>
 #include <QDebug>
 #include <QString>
+#include <pappsomspp/exception/exceptionnotpossible.h>
 
 using namespace pappso;
 using namespace std;
@@ -53,6 +54,9 @@ TEST_CASE("Test Peptide", "[Peptide]")
 
   SECTION("..:: Test ProForma parser ::..", "[proforma]")
   {
+    REQUIRE_THROWS_AS(PeptideProFormaParser::parseString(
+      "C[MOD:00397][MOD:01160]C[MOD:00397]AADDKEAC[FAVEGPK"),
+                      pappso::ExceptionNotPossible);
     PeptideSp peptide_from_str = PeptideProFormaParser::parseString(
       "C[MOD:00397][MOD:01160]C[MOD:00397]AADDKEAC[MOD:00397]FAVEGPK");
     REQUIRE(peptide_from_str.get()->getMass() == Catch::Approx(1909.764470427));
