@@ -28,13 +28,8 @@
 // make test ARGS="-V -I 7,7"
 // ./tests/catch2-only-tests [peptidenaturalisotope] -s
 
-
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
 
 #include <pappsomspp/precision.h>
 #include <pappsomspp/peptide/peptidenaturalisotopelist.h>
@@ -59,11 +54,12 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
 
     std::cout << std::endl << "..:: peptide init ::.." << std::endl;
     std::cout << std::endl
-         << "..:: peptide natural isotope list init ::.." << std::endl;
+              << "..:: peptide natural isotope list init ::.." << std::endl;
     Peptide peptide("LA");
 
     PeptideNaturalIsotopeList isotopeList(peptide.makePeptideSp());
-    std::cout << std::endl << "isotope list OK" << isotopeList.size() << std::endl;
+    std::cout << std::endl
+              << "isotope list OK" << isotopeList.size() << std::endl;
 
     PeptideNaturalIsotopeList::const_iterator it(isotopeList.begin());
 
@@ -82,7 +78,7 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         std::cout.flush();
 
         std::cout << " ratio=" << it->get()->getIntensityRatio(1) << " ::.."
-             << std::endl;
+                  << std::endl;
         it++;
       }
     std::cout << std::endl << "print isotope list OK" << std::endl;
@@ -111,7 +107,7 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
       {
         if(it->get()->getIsotopeNumber() == 0)
           {
-            REQUIRE(it->get()->getMass() == Approx(mass_before).epsilon(0.001));
+            REQUIRE(it->get()->getMass() == Catch::Approx(mass_before));
           }
         REQUIRE(it->get()->size() == peptideb.size());
         // C55 H98 N15 O18 + C2 H3 N1 O1
@@ -121,13 +117,13 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         REQUIRE(it->get()->getNumberOfAtom(AtomIsotopeSurvey::O) == 19);
         // qDebug() <<  it->getIntensityRatio();
         std::cout << std::endl
-             << it->get()->getSequence().toStdString()
-             << "..:: " << it->get()->getFormula(1).toStdString()
-             << " C13=" << it->get()->getNumberOfIsotope(Isotope::C13)
-             << " mass=" << it->get()->getMz(1)
-             << " mz(2)=" << it->get()->getMz(2)
-             << " ratio=" << it->get()->getIntensityRatio(1) << " ::.."
-             << std::endl;
+                  << it->get()->getSequence().toStdString()
+                  << "..:: " << it->get()->getFormula(1).toStdString()
+                  << " C13=" << it->get()->getNumberOfIsotope(Isotope::C13)
+                  << " mass=" << it->get()->getMz(1)
+                  << " mz(2)=" << it->get()->getMz(2)
+                  << " ratio=" << it->get()->getIntensityRatio(1) << " ::.."
+                  << std::endl;
         it++;
       }
 
@@ -137,12 +133,13 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
     std::cout << "isotope levels" << std::endl;
     for(unsigned int i = 0; i < map_isotope_number.size(); i++)
       {
-        std::cout << "isotope " << i << " " << map_isotope_number[i] << std::endl;
+        std::cout << "isotope " << i << " " << map_isotope_number[i]
+                  << std::endl;
       }
 
     std::cout << std::endl
-         << "..:: peptide natural isotope list init test on fragment ::.."
-         << std::endl;
+              << "..:: peptide natural isotope list init test on fragment ::.."
+              << std::endl;
 
     std::list<PeptideIon> cid_ion = PeptideFragmentIonListBase::getCIDionList();
     PeptideFragmentIonListBase fragmentation_cid(peptideSp, cid_ion);
@@ -155,7 +152,7 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
     for(unsigned int i = 0; i < map_isotope_number.size(); i++)
       {
         std::cout << "frag isotope " << i << " " << map_isotope_number[i]
-             << std::endl;
+                  << std::endl;
       }
 
     std::vector<PeptideNaturalIsotopeAverageSp> naturalIsotopeAverageList =
@@ -166,10 +163,10 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         naturalIsotopeAverageList)
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
     // SUCCESS
 
@@ -187,10 +184,10 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         natural_isotope_average_list)
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
 
 
@@ -200,10 +197,10 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
           3, PrecisionFactory::getPpmInstance(5), 0.6))
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
 
 
@@ -213,10 +210,10 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
           3, PrecisionFactory::getPpmInstance(3), 0.6))
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
 
 
@@ -226,10 +223,10 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
           3, PrecisionFactory::getPpmInstance(2), 0.6))
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
 
 
@@ -239,22 +236,22 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
           3, PrecisionFactory::getPpmInstance(1), 0.6))
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
 
 
     std::cout << std::endl
-         << "..:: peptide natural isotope list from labeled peptide ::.."
-         << std::endl;
+              << "..:: peptide natural isotope list from labeled peptide ::.."
+              << std::endl;
     PeptideSp peptide_lys_label =
       PeptideStrParser::parseString("CCAAL(MOD:00582)DDKEACFAVEGPK");
 
     PeptideNaturalIsotopeList isotopeList_lys(peptide_lys_label);
     std::cout << std::endl
-         << "isotope list OK" << isotopeList_lys.size() << std::endl;
+              << "isotope list OK" << isotopeList_lys.size() << std::endl;
 
     map_isotope_number = isotopeList_lys.getIntensityRatioPerIsotopeNumber();
 
@@ -262,12 +259,13 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
     for(unsigned int i = 0; i < map_isotope_number.size(); i++)
       {
         std::cout << "frag isotope " << i << " " << map_isotope_number[i]
-             << std::endl;
+                  << std::endl;
       }
 
-    std::cout << std::endl
-         << "..:: get 80 % intensity of natural isotope average PPM = 2 ::.."
-         << std::endl;
+    std::cout
+      << std::endl
+      << "..:: get 80 % intensity of natural isotope average PPM = 2 ::.."
+      << std::endl;
     naturalIsotopeAverageList = isotopeList_lys.getByIntensityRatio(
       1, PrecisionFactory::getPpmInstance(2), 0.8);
 
@@ -275,18 +273,19 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         naturalIsotopeAverageList)
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
 
     std::cout << std::endl << "print lys isotope list OK" << std::endl;
 
-    std::cout << std::endl
-         << "..:: get 10 % intensity of small peptide natural isotope average "
-            "dalton = 0.2 ::.."
-         << std::endl;
+    std::cout
+      << std::endl
+      << "..:: get 10 % intensity of small peptide natural isotope average "
+         "dalton = 0.2 ::.."
+      << std::endl;
     naturalIsotopeAverageList = isotopeList_lys.getByIntensityRatio(
       1, PrecisionFactory::getDaltonInstance(0.2), 0.1);
 
@@ -294,18 +293,19 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         naturalIsotopeAverageList)
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
     REQUIRE(naturalIsotopeAverageList.size() == 1);
     REQUIRE(naturalIsotopeAverageList.at(0).get()->getIsotopeNumber() == 0);
 
-    std::cout << std::endl
-         << "..:: get 10 % intensity of big peptide natural isotope average "
-            "dalton = 0.2 ::.."
-         << std::endl;
+    std::cout
+      << std::endl
+      << "..:: get 10 % intensity of big peptide natural isotope average "
+         "dalton = 0.2 ::.."
+      << std::endl;
     naturalIsotopeAverageList = isotopeListBig.getByIntensityRatio(
       1, PrecisionFactory::getDaltonInstance(0.2), 0.1);
 
@@ -313,10 +313,10 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         naturalIsotopeAverageList)
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
       }
     REQUIRE(naturalIsotopeAverageList.size() == 1);
     REQUIRE(naturalIsotopeAverageList.at(0).get()->getIsotopeNumber() == 2);
@@ -334,16 +334,16 @@ TEST_CASE("Test peptidenaturalisotope", "[peptidenaturalisotope]")
         natural_isotope_average_list_ratio_test)
       {
         std::cout << "average isotope "
-             << isotopeAverageSp.get()->getIntensityRatio()
-             << " average mz=" << isotopeAverageSp.get()->getMz()
-             << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
-             << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
-             << std::endl;
+                  << isotopeAverageSp.get()->getIntensityRatio()
+                  << " average mz=" << isotopeAverageSp.get()->getMz()
+                  << " number=" << isotopeAverageSp.get()->getIsotopeNumber()
+                  << " rank=" << isotopeAverageSp.get()->getIsotopeRank()
+                  << std::endl;
         /*
               if(isotopeAverageSp.get()->getIsotopeRank() == 3)
                 {
-                  std::cerr << "isotopeAverageSp.get()->getIsotopeRank()== 3 ERROR,
-           not " "possible with 10ppm"
+                  std::cerr << "isotopeAverageSp.get()->getIsotopeRank()== 3
+           ERROR, not " "possible with 10ppm"
                        << std::endl;
                   return 1;
                 }
