@@ -30,13 +30,7 @@
 // ./tests/catch2-only-tests [Protein] -s
 
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
-
+#include <catch2/catch_test_macros.hpp>
 #include <iostream>
 
 #include <pappsomspp/mzrange.h>
@@ -310,7 +304,7 @@ TEST_CASE("Test Protein", "[Protein]")
 
     digestion.clear();
     std::cout << std::endl
-         << "..:: Test trypsin peptides on fake prot ::.." << std::endl;
+              << "..:: Test trypsin peptides on fake prot ::.." << std::endl;
     kinase.eat(0, fake, false, digestion);
 
     REQUIRE(digestion.contain("K"));
@@ -324,7 +318,7 @@ TEST_CASE("Test Protein", "[Protein]")
 
     // BSA
     std::cout << std::endl
-         << "..:: Test semi tryptic peptides on BSA ::.." << std::endl;
+              << "..:: Test semi tryptic peptides on BSA ::.." << std::endl;
     kinase.setMiscleavage(0);
     PeptideSemiEnzyme semi_tryptic;
     semi_tryptic.setSink(&digestion);
@@ -375,8 +369,8 @@ TEST_CASE("Test Protein", "[Protein]")
 
     // reverse protein :
     std::cout << std::endl
-         << "reverse :"
-         << Protein(*fake.get()).reverse().getSequence().toStdString();
+              << "reverse :"
+              << Protein(*fake.get()).reverse().getSequence().toStdString();
 
     PeptideSp peptide_test = PeptideStrParser::parseString(
       "E(MOD:00429)C(MOD:00419)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
@@ -385,27 +379,27 @@ TEST_CASE("Test Protein", "[Protein]")
       "E(MOD:00429)C(MOD:00419)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
     REQUIRE(modification_sink.contain(peptide_test));
     std::cout << peptide_test.get()->toString().toStdString() << " is present"
-         << std::endl;
+              << std::endl;
 
 
     peptide_test =
       PeptideStrParser::parseString("V(MOD:00552)VVMAMEEK(MOD:00429)");
     REQUIRE_FALSE(modification_sink.contain(peptide_test));
     std::cout << peptide_test.get()->toString().toStdString() << " is absent"
-         << std::endl;
+              << std::endl;
 
     peptide_test =
       PeptideStrParser::parseString("V(MOD:00552)VVMAMEEK(MOD:00552)");
     REQUIRE(modification_sink.contain(peptide_test));
     std::cout << peptide_test.get()->toString().toStdString() << " is present"
-         << std::endl;
+              << std::endl;
 
 
     peptide_test = PeptideStrParser::parseString(
       "E(MOD:00429)C(MOD:00397)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
     REQUIRE(modification_sink.contain(peptide_test));
     std::cout << peptide_test.get()->toString().toStdString() << " is present"
-         << std::endl;
+              << std::endl;
 
     std::cout << std::endl << "..:: test modification motifs ::.." << std::endl;
 
@@ -428,12 +422,12 @@ TEST_CASE("Test Protein", "[Protein]")
     REQUIRE(modification_sink.contain(peptide_test));
     REQUIRE(modification_sink.size() == 1);
     std::cout << peptide_test.get()->toString().toStdString() << " is present"
-         << std::endl;
+              << std::endl;
 
 
     qDebug() << "init test protein";
     std::cout << std::endl
-         << "..:: Test Protein with B and Z wildcard ::.." << std::endl;
+              << "..:: Test Protein with B and Z wildcard ::.." << std::endl;
 
     // BSA
     qDebug() << "init bsa with B and Z wildcard";
