@@ -32,12 +32,9 @@
 
 #include <algorithm>
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
 
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/psm/peptidespectrummatch.h>
@@ -81,7 +78,8 @@ TEST_CASE("psm test suite.", "[psm]")
     std::list<PeptideIon> ion_list;
     ion_list.push_back(PeptideIon::y);
     ion_list.push_back(PeptideIon::b);
-    std::cout << "spectrum_simple size  " << spectrum_simple.size() << std::endl;
+    std::cout << "spectrum_simple size  " << spectrum_simple.size()
+              << std::endl;
     REQUIRE(spectrum_simple.size() == 100);
 
     PeptideSpectrumMatch psm(
@@ -235,11 +233,11 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
     LinearRegression lr = features.getIonIsotopeLinearRegression();
     REQUIRE(lr.getCoefficientOfDetermination() == 0.0);
-    REQUIRE(features.getTotalIntensity() == Approx(248641.8659667977));
+    REQUIRE(features.getTotalIntensity() == Catch::Approx(248641.8659667977));
     REQUIRE(features.getIntensityOfMatchedIon(PeptideIon::b) ==
-            Approx(1751.5864257813).epsilon(0.001));
+            Catch::Approx(1751.5864257813).epsilon(0.001));
     REQUIRE(features.getIntensityOfMatchedIon(PeptideIon::y) ==
-            Approx(57112.2947998047).epsilon(0.001));
+            Catch::Approx(57112.2947998047).epsilon(0.001));
 
 
     REQUIRE(features.countMatchedIonComplementPairs() == 0);
@@ -276,17 +274,17 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
     REQUIRE(features2.getIonIsotopeLinearRegression()
               .getCoefficientOfDetermination() ==
-            Approx(0.6323680888).epsilon(0.01));
+            Catch::Approx(0.6323680888).epsilon(0.01));
 
     features.setPeptideSpectrumCharge(peptide_sp, &spectrum_simple, 2, 1);
 
 
     REQUIRE(features.getIonIsotopeLinearRegression()
               .getCoefficientOfDetermination() ==
-            Approx(0.6323680888).epsilon(0.01));
+            Catch::Approx(0.6323680888).epsilon(0.01));
     REQUIRE(
       features.getMaxIntensityMatchedIonComplementPairPrecursorMassDelta() ==
-      Approx(-0.0036778069).epsilon(0.00001));
+      Catch::Approx(-0.0036778069).epsilon(0.00001));
     REQUIRE(features.countMatchedIonComplementPairs() == 3);
 
     REQUIRE(features.getPeakIonPairs().size() == 3);
@@ -309,13 +307,13 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
     REQUIRE(
       features.getIonPairPrecursorMassDelta(features.getPeakIonPairs()[0]) ==
-      Approx(-0.0036778069).epsilon(0.001));
+      Catch::Approx(-0.0036778069).epsilon(0.001));
     REQUIRE(
       features.getIonPairPrecursorMassDelta(features.getPeakIonPairs()[1]) ==
-      Approx(-0.0118262069).epsilon(0.001));
+      Catch::Approx(-0.0118262069).epsilon(0.001));
     REQUIRE(
       features.getIonPairPrecursorMassDelta(features.getPeakIonPairs()[2]) ==
-      Approx(-0.0114600069).epsilon(0.001));
+      Catch::Approx(-0.0114600069).epsilon(0.001));
 
 
     REQUIRE(features.getMaxConsecutiveIon(PeptideIon::y) == 9);
@@ -333,7 +331,8 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
 
     REQUIRE(features.getIonIsotopeLinearRegression()
-              .getCoefficientOfDetermination() == Approx(0.0).epsilon(0.01));
+              .getCoefficientOfDetermination() ==
+            Catch::Approx(0.0).epsilon(0.01));
 
     REQUIRE(features.getMaxConsecutiveIon(PeptideIon::y) == 10);
     REQUIRE(features.getMaxConsecutiveIon(PeptideIon::b) == 3);
@@ -342,16 +341,16 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
 
     REQUIRE(features.getIntensityOfMatchedIon(PeptideIon::y) ==
-            Approx(654880.6992189999));
+            Catch::Approx(654880.6992189999));
     REQUIRE(features.getMaxIntensityPeakIonMatch(PeptideIon::y) ==
-            Approx(114514.0625));
+            Catch::Approx(114514.0625));
 
     features.setPeptideSpectrumCharge(peptide_sp, &spectrum_simple, 2, 1);
 
 
     REQUIRE(features.getIonIsotopeLinearRegression()
               .getCoefficientOfDetermination() ==
-            Approx(0.5991012161).epsilon(0.04));
+            Catch::Approx(0.5991012161).epsilon(0.04));
 
     REQUIRE(features.getMaxConsecutiveIon(PeptideIon::y) == 10);
     REQUIRE(features.getMaxConsecutiveIon(PeptideIon::b) == 3);
@@ -360,32 +359,32 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
 
     REQUIRE(features.getIntensityOfMatchedIon(PeptideIon::y) ==
-            Approx(863068.6967769999));
+            Catch::Approx(863068.6967769999));
     REQUIRE(features.getMaxIntensityPeakIonMatch(PeptideIon::y) ==
-            Approx(114514.0625));
+            Catch::Approx(114514.0625));
 
     REQUIRE(features.getIntensityOfMatchedIon(PeptideIon::b) ==
-            Approx(254791.342651));
+            Catch::Approx(254791.342651));
     REQUIRE(features.getMaxIntensityPeakIonMatch(PeptideIon::b) ==
-            Approx(161016.984375));
+            Catch::Approx(161016.984375));
 
 
     // SeqCoverComplementPeaks
     REQUIRE(features.getComplementPairsAaSequenceCoverage() == 5);
     REQUIRE(((double)features.getComplementPairsAaSequenceCoverage() /
-             (double)peptide_sp.get()->size()) == Approx(5.0 / 12.0));
-    REQUIRE(((double)0 / (double)peptide_sp.get()->size()) == Approx(0));
+             (double)peptide_sp.get()->size()) == Catch::Approx(5.0 / 12.0));
+    REQUIRE(((double)0 / (double)peptide_sp.get()->size()) == Catch::Approx(0));
 
 
     REQUIRE((features.getTotalIntensityOfMatchedIonComplementPairs() /
-             features.getTotalIntensity()) == Approx(0.1727291768));
+             features.getTotalIntensity()) == Catch::Approx(0.1727291768));
 
     REQUIRE((features.getTotalIntensityOfMatchedIonComplementPairs() <
              features.getTotalIntensity()));
 
     REQUIRE(
       features.getMaxIntensityMatchedIonComplementPairPrecursorMassDelta() ==
-      Approx(0.0008592852).epsilon(0.00001));
+      Catch::Approx(0.0008592852).epsilon(0.00001));
 
 
     features.setPeptideSpectrumCharge(peptide_sp, &spectrum_simple, 2, 2);
@@ -393,7 +392,7 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
     REQUIRE(features.getIonIsotopeLinearRegression()
               .getCoefficientOfDetermination() ==
-            Approx(0.5991012161).epsilon(0.04));
+            Catch::Approx(0.5991012161).epsilon(0.04));
 
     REQUIRE(features.getMaxConsecutiveIon(PeptideIon::y) == 10);
     REQUIRE(features.getMaxConsecutiveIon(PeptideIon::b) == 3);
@@ -402,31 +401,31 @@ TEST_CASE("psm features test suite.", "[psmfeature]")
 
 
     REQUIRE(features.getIntensityOfMatchedIon(PeptideIon::y) ==
-            Approx(911305.6467289998));
+            Catch::Approx(911305.6467289998));
     REQUIRE(features.getMaxIntensityPeakIonMatch(PeptideIon::y) ==
-            Approx(114514.0625));
+            Catch::Approx(114514.0625));
 
     REQUIRE(features.getIntensityOfMatchedIon(PeptideIon::b) ==
-            Approx(271127.594604));
+            Catch::Approx(271127.594604));
     REQUIRE(features.getMaxIntensityPeakIonMatch(PeptideIon::b) ==
-            Approx(161016.984375));
+            Catch::Approx(161016.984375));
 
 
     // SeqCoverComplementPeaks
     REQUIRE(features.getComplementPairsAaSequenceCoverage() == 5);
     REQUIRE(((double)features.getComplementPairsAaSequenceCoverage() /
-             (double)peptide_sp.get()->size()) == Approx(5.0 / 12.0));
-    REQUIRE(((double)0 / (double)peptide_sp.get()->size()) == Approx(0));
+             (double)peptide_sp.get()->size()) == Catch::Approx(5.0 / 12.0));
+    REQUIRE(((double)0 / (double)peptide_sp.get()->size()) == Catch::Approx(0));
 
 
     REQUIRE((features.getTotalIntensityOfMatchedIonComplementPairs() /
-             features.getTotalIntensity()) == Approx(0.1790448148));
+             features.getTotalIntensity()) == Catch::Approx(0.1790448148));
 
     REQUIRE((features.getTotalIntensityOfMatchedIonComplementPairs() <
              features.getTotalIntensity()));
 
     REQUIRE(
       features.getMaxIntensityMatchedIonComplementPairPrecursorMassDelta() ==
-      Approx(0.0008592852).epsilon(0.00001));
+      Catch::Approx(0.0008592852).epsilon(0.00001));
   }
 }
