@@ -30,12 +30,7 @@
 // ./tests/catch2-only-tests [rawmasslist] -s
 
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
 
 #include <iostream>
 #include <pappsomspp/peptide/peptiderawfragmentmasses.h>
