@@ -29,12 +29,8 @@
 // ./tests/catch2-only-tests [scan15968] -s
 
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
 
 #include <pappsomspp/mzrange.h>
 #include <pappsomspp/peptide/peptidenaturalisotopelist.h>
@@ -713,17 +709,18 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
                                       ion_list,
                                       refine_spectrum_synthesis);
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " hyperscore15968=" << hyperscore15968.getHyperscore() << std::endl;
+              << " hyperscore15968=" << hyperscore15968.getHyperscore()
+              << std::endl;
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << std::endl;
+              << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
+              << std::endl;
 
     // Spectrum::getHyperscore  "b"  itmap->second  1   1
     //  Spectrum::getHyperscore  "y"  itmap->second  9   362880
     REQUIRE(hyperscore15968.getHyperscore() ==
-            Approx(29.088471341).margin(0.001));
-    REQUIRE(pep15968.getMz(1) == Approx(1275.73).margin(0.01));
-    REQUIRE(pep15968.getMz(2) == Approx(638.369).margin(0.001));
+            Catch::Approx(29.088471341).margin(0.001));
+    REQUIRE(pep15968.getMz(1) == Catch::Approx(1275.73).margin(0.01));
+    REQUIRE(pep15968.getMz(2) == Catch::Approx(638.369).margin(0.001));
     /*
     <group id="15968" mh="1275.731419" z="2" rt="PT2843.58S" expect="1.7e-04"
   label="GRMZM5G815453_P01 P00874 Ribulose bisphosphate carboxylase large chain
