@@ -1,9 +1,4 @@
-
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-#endif
+#include <catch2/catch_test_macros.hpp>
 
 #include <QDebug>
 #include <QString>
@@ -61,7 +56,7 @@ TEST_CASE("Test tims XIC data extraction right form the SQLite db",
 
     pappso::MsFileAccessor accessor(file_path_name, "a1");
 
-    accessor.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
+    accessor.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
                                         pappso::FileReaderType::tims);
 
     pappso::MsRunReaderSPtr p_msreader =
@@ -100,7 +95,7 @@ TEST_CASE("Test tims XIC data extraction right form the SQLite db",
 
     pappso::MsFileAccessor accessor(file_path_name, "a1");
 
-    accessor.setPreferredFileReaderType(pappso::MzFormat::brukerTims,
+    accessor.setPreferredFileReaderType(pappso::MsDataFormat::brukerTims,
                                         pappso::FileReaderType::tims_ms2);
 
     pappso::MsRunReaderSPtr p_msreader =
