@@ -176,7 +176,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
                              131.440113097798,
                              12.9712317295887,
                              2558.71692505931);
-    frame.setTime(2402.64305686123);
+    frame.setRtInSeconds(2402.64305686123);
     frame.setMsMsType(0);
     quint32 index =
       frame.getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
@@ -206,7 +206,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     double one_over_k0 = frame.getOneOverK0Transformation(400);
     qDebug() << " 400 => one_over_k0=" << QString::number(one_over_k0, 'g', 10);
-    std::size_t scan_num = frame.getScanNumFromOneOverK0(one_over_k0);
+    std::size_t scan_num = frame.getScanIndexFromOneOverK0(one_over_k0);
 
     REQUIRE(scan_num == 400);
     std::cout << std::endl << "..:: Test 1 OK ::.." << std::endl;
@@ -256,7 +256,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
                              131.053614,
                              9.656516,
                              2095.24199);
-    frame.setTime(1.7950832);
+    frame.setRtInSeconds(1.7950832);
     frame.setMsMsType(0);
 
     std::size_t index =
@@ -283,7 +283,7 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     double one_over_k0 = frame.getOneOverK0Transformation(400);
     qDebug() << " 400 => one_over_k0=" << QString::number(one_over_k0, 'g', 10);
-    std::size_t scan_num = frame.getScanNumFromOneOverK0(one_over_k0);
+    std::size_t scan_num = frame.getScanIndexFromOneOverK0(one_over_k0);
 
     REQUIRE(scan_num == 400);
 
@@ -495,8 +495,8 @@ TEST_CASE("Test tims frames", "[timsframe]")
 
     pappso::TimsDataSp timsdata_sp = tims1_reader->getTimsDataSPtr();
 
-    REQUIRE_NOTHROW(timsdata_sp.get()->getRawMsBySpectrumIndex(0));
-    REQUIRE_NOTHROW(timsdata_sp.get()->getRawMsBySpectrumIndex(1));
+    REQUIRE_NOTHROW(timsdata_sp.get()->getScanByGlobalScanIndex(0));
+    REQUIRE_NOTHROW(timsdata_sp.get()->getScanByGlobalScanIndex(1));
     REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(0));
     // REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(1000));
 
