@@ -31,12 +31,9 @@
 
 // #define CATCH_CONFIG_MAIN
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_approx.hpp>
 
 #include <QDebug>
 #include <QString>
@@ -82,13 +79,13 @@ TEST_CASE("test cosine similarity.", "[cosinesim]")
     CosineSimilarity cosine(pappso::PrecisionFactory::getDaltonInstance(0.02));
 
     REQUIRE(cosine.similarity(spectrum_simple, spectrum_simple) ==
-            Approx(1.0).epsilon(0.004));
+            Catch::Approx(1.0).epsilon(0.004));
 
     MassSpectrum orig = spectrum_simple;
     pappso::FilterGreatestY(10).filter(spectrum_simple);
 
     REQUIRE(cosine.similarity(orig, spectrum_simple) ==
-            Approx(0.963327).epsilon(0.004));
+            Catch::Approx(0.963327).epsilon(0.004));
 
     // AIADGSLLDLLR
   }
@@ -120,7 +117,8 @@ TEST_CASE("trace filter peak delta.", "[filterpeakdelta]")
     filter_peak_delta.filter(spectrum_simple);
 
     REQUIRE(spectrum_simple.size() == 45);
-    REQUIRE(spectrum_simple.at(0).x == Approx(result.at(0).x).epsilon(0.001));
+    REQUIRE(spectrum_simple.at(0).x ==
+            Catch::Approx(result.at(0).x).epsilon(0.001));
     REQUIRE(spectrum_simple.at(0).y == result.at(0).y);
 
     // AIADGSLLDLLR
@@ -519,7 +517,8 @@ TEST_CASE("trace filters test suite.", "[filters]")
                        DataPoint(11, 5),
                        DataPoint(12, 6)});
     REQUIRE(deca.size() == deca_median.size());
-    std::cout << "deca.size() == deca_median.size() " << deca.size() << std::endl;
+    std::cout << "deca.size() == deca_median.size() " << deca.size()
+              << std::endl;
     REQUIRE(deca == deca_median);
 
     std::cout << std::endl << "..:: FilterTandemDeisotope ::.." << std::endl;
@@ -534,8 +533,10 @@ TEST_CASE("trace filters test suite.", "[filters]")
 
     QualifiedMassSpectrum spectrum_scan_15968 = readQualifiedMassSpectrumMgf(
       QString(CMAKE_SOURCE_DIR).append("/tests/data/scan_15968.mgf"));
-    REQUIRE(spectrum_scan_15968.getPrecursorMz() == Approx(638.3693473259));
-    REQUIRE(spectrum_scan_15968.getPrecursorMass() == Approx(1274.724141718));
+    REQUIRE(spectrum_scan_15968.getPrecursorMz() ==
+            Catch::Approx(638.3693473259));
+    REQUIRE(spectrum_scan_15968.getPrecursorMass() ==
+            Catch::Approx(1274.724141718));
     qDebug();
     QualifiedMassSpectrum spectrum_removed_tandem_deisotope =
       QualifiedMassSpectrum(spectrum_scan_15968).cloneMassSpectrumSPtr();
@@ -594,13 +595,14 @@ TEST_CASE("trace filters test suite.", "[filters]")
       ion_list,
       true);
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " hyperscore15968=" << hyperscore15968.getHyperscore() << std::endl;
+              << " hyperscore15968=" << hyperscore15968.getHyperscore()
+              << std::endl;
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << std::endl;
+              << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
+              << std::endl;
 
     REQUIRE(hyperscore15968.getHyperscore() ==
-            Approx(50.9568806832).margin(0.1));
+            Catch::Approx(50.9568806832).margin(0.1));
 
     XtandemHyperscore hyperscore15968_remove_c13(
       *spectrum_removed_c13.getMassSpectrumSPtr().get(),
@@ -610,15 +612,16 @@ TEST_CASE("trace filters test suite.", "[filters]")
       ion_list,
       true);
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " hyperscore15968_remove_c13="
-         << hyperscore15968_remove_c13.getHyperscore() << std::endl;
+              << " hyperscore15968_remove_c13="
+              << hyperscore15968_remove_c13.getHyperscore() << std::endl;
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << std::endl;
+              << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
+              << std::endl;
 
 
     std::cout << std::endl
-         << "..:: FilterMassSpectrumComplementIonEnhancer ::.." << std::endl;
+              << "..:: FilterMassSpectrumComplementIonEnhancer ::.."
+              << std::endl;
     qDebug();
 
     QualifiedMassSpectrum spectrum_complement_ion =
@@ -645,12 +648,12 @@ TEST_CASE("trace filters test suite.", "[filters]")
       ion_list,
       true);
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " hyperscore15968_complement_ion_enhancer="
-         << hyperscore15968_complement_ion_enhancer.getHyperscore()
-         << std::endl;
+              << " hyperscore15968_complement_ion_enhancer="
+              << hyperscore15968_complement_ion_enhancer.getHyperscore()
+              << std::endl;
     std::cout << "peptide " << pep15968.getSequence().toStdString()
-         << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << std::endl;
+              << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
+              << std::endl;
 
 
     std::cout << std::endl << "..:: FilterGreatestYperWindow ::.." << std::endl;
@@ -674,8 +677,8 @@ TEST_CASE("trace filters test suite.", "[filters]")
 
 
     std::cout << std::endl
-         << "..:: FilterGreatestYperWindow  on scan_PXD001468.mgf ::.."
-         << std::endl;
+              << "..:: FilterGreatestYperWindow  on scan_PXD001468.mgf ::.."
+              << std::endl;
     QualifiedMassSpectrum spectrum_scan_PXD001468 =
       readQualifiedMassSpectrumMgf(
         QString(CMAKE_SOURCE_DIR).append("/tests/data/scan_PXD001468.mgf"));
@@ -729,12 +732,12 @@ TEST_CASE("trace filters test suite.", "[filters]")
 
 
     std::cout << std::endl
-         << "filter_suite_str = "
-         << filter_suite_str.get()->toString().toStdString() << std::endl;
+              << "filter_suite_str = "
+              << filter_suite_str.get()->toString().toStdString() << std::endl;
 
     std::cout << std::endl
-         << "..:: FilterChargeDeconvolution from FilterSuiteString ::.."
-         << std::endl;
+              << "..:: FilterChargeDeconvolution from FilterSuiteString ::.."
+              << std::endl;
 
     std::shared_ptr<pappso::FilterChargeDeconvolution>
       filter_charge_deconvolution =
@@ -770,7 +773,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     if(loaded_trace != theorical_trace)
       {
         std::cerr << "transformed Trace are different from theorical trace :"
-             << std::endl;
+                  << std::endl;
 
         if(loaded_trace.xValues().size() == theorical_trace.xValues().size())
           {
@@ -778,22 +781,22 @@ TEST_CASE("trace filters test suite.", "[filters]")
             for(std::size_t i = 0; i < loaded_trace.xValues().size(); i++)
               {
                 std::cerr << "(" << loaded_trace.xValues()[i] << ", "
-                     << loaded_trace.yValues()[i] << ") ";
+                          << loaded_trace.yValues()[i] << ") ";
               }
             std::cerr << std::endl;
             std::cerr << "theorical trace : \t";
             for(std::size_t i = 0; i < theorical_trace.xValues().size(); i++)
               {
                 std::cerr << "(" << theorical_trace.xValues()[i] << ", "
-                     << theorical_trace.yValues()[i] << ") ";
+                          << theorical_trace.yValues()[i] << ") ";
               }
             std::cerr << std::endl;
           }
         else
           {
             std::cerr << "Number of peaks is different : "
-                 << loaded_trace.xValues().size() << " vs "
-                 << theorical_trace.xValues().size();
+                      << loaded_trace.xValues().size() << " vs "
+                      << theorical_trace.xValues().size();
           }
       }
 
@@ -856,17 +859,17 @@ TEST_CASE("trace filters test suite.", "[filters]")
   SECTION("..:: check FilterQuantileBasedRemoveY ::..", "[filters]")
   {
 
-    Trace xic_PXD0014777 =
-      *(readQualifiedMassSpectrumMgf(
-          QString(CMAKE_SOURCE_DIR).append("/tests/data/xic/PXD014777_xic.tsv"))
-          .getMassSpectrumSPtr()
-          .get());
+    QualifiedMassSpectrum qspectrum = readQualifiedMassSpectrumMgf(
+      QString(CMAKE_SOURCE_DIR).append("/tests/data/xic/PXD014777_xic.tsv"));
+    REQUIRE(qspectrum.size() == 12028);
+    Trace xic_PXD0014777 = *(qspectrum.getMassSpectrumSPtr().get());
 
-    REQUIRE(Approx(62.43).epsilon(0.01) ==
+
+    REQUIRE(Catch::Approx(62.43).epsilon(0.01) ==
             quantileYTrace(xic_PXD0014777.begin(), xic_PXD0014777.end(), 0.1));
-    REQUIRE(Approx(250.75).epsilon(0.01) ==
+    REQUIRE(Catch::Approx(250.75).epsilon(0.01) ==
             quantileYTrace(xic_PXD0014777.begin(), xic_PXD0014777.end(), 0.5));
-    REQUIRE(Approx(136.96).epsilon(0.01) ==
+    REQUIRE(Catch::Approx(136.96).epsilon(0.01) ==
             quantileYTrace(xic_PXD0014777.begin(), xic_PXD0014777.end(), 0.3));
 
 
