@@ -31,12 +31,9 @@
 
 // #define CATCH_CONFIG_MAIN
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_test_macros.hpp>
 #include <catch2/catch_approx.hpp>
-using namespace Catch;
-#endif
+#include <catch2/matchers/catch_matchers_vector.hpp>
 
 #include <iostream>
 #include <odsstream/odsdocreader.h>
@@ -341,11 +338,13 @@ TEST_CASE("XIC test suite.", "[XIC]")
     qDebug();
     REQUIRE_THAT(
       ods_sink.m_beginList,
-      Catch::Approx(std::vector<double>({1221.79, 1268.65})).margin(0.00001));
-    REQUIRE_THAT(ods_sink.m_areaList,
-                 Catch::Approx(std::vector<double>(
-                                 {317787751.7834287882, 3251982.1006667931}))
-                   .margin(0.01));
+      Catch::Matchers::Approx(std::vector<double>({1221.79, 1268.65}))
+        .margin(0.00001));
+    REQUIRE_THAT(
+      ods_sink.m_areaList,
+      Catch::Matchers::Approx(
+        std::vector<double>({317787751.7834287882, 3251982.1006667931}))
+        .margin(0.01));
 
 
     Xic realxic_test;
@@ -362,7 +361,7 @@ TEST_CASE("XIC test suite.", "[XIC]")
     qDebug();
     REQUIRE_THAT(
       real_ods_sink.m_beginList,
-      Catch::Approx(
+      Catch::Matchers::Approx(
         std::vector<double>(
           {2374.88, 2385.45, 2490.35, 2653.21, 2730.29, 2750.84, 2761.72,
            3262.35, 3277.68, 3755.51, 3808.5,  4104.5,  4151.45, 4447.09,
@@ -372,55 +371,56 @@ TEST_CASE("XIC test suite.", "[XIC]")
            5704.19, 5839.75, 6205.72, 6224.08, 6273.97, 6292.98, 6401.19,
            6510.97, 6587.42, 6838.34, 6875.56, 7039.36}))
         .margin(0.00001));
-    REQUIRE_THAT(real_ods_sink.m_areaList,
-                 Catch::Approx(std::vector<double>({453563.5099999703,
-                                                    4719046.3000000007,
-                                                    1090639.7850001103,
-                                                    1348880.5900000208,
-                                                    7630963.3250000998,
-                                                    779452.6100000609,
-                                                    2040112.6650001134,
-                                                    5756570.0800003475,
-                                                    8225201.0500001209,
-                                                    105329906.8750005662,
-                                                    0.0,
-                                                    647415.2500000162,
-                                                    421852.445000008,
-                                                    10305033.5250001848,
-                                                    3621950.2699998645,
-                                                    544684.8950001382,
-                                                    37944845.6299999952,
-                                                    3698171.8149995869,
-                                                    5664123.3300000867,
-                                                    420474.2849998939,
-                                                    1008899.3299999861,
-                                                    805031.2899999407,
-                                                    335121.1350001062,
-                                                    338425.5199998079,
-                                                    340164.8050002141,
-                                                    12118740.7800003588,
-                                                    1643557.1449998224,
-                                                    488535.5099999903,
-                                                    3979415.1600000304,
-                                                    337714.1250001371,
-                                                    1028555.1399998174,
-                                                    905212.215000038,
-                                                    256353.7100000874,
-                                                    273830.9199999579,
-                                                    10611321.4649997819,
-                                                    18939923.7850016505,
-                                                    571598.5350001995,
-                                                    2796306.4700002563,
-                                                    39837543.8999998271,
-                                                    3572057.4000001787,
-                                                    2218517.9099999457,
-                                                    2539285.7649998385,
-                                                    881227.1150000142,
-                                                    726500.5700001301,
-                                                    17818048.1899999045,
-                                                    571815.7450000376,
-                                                    2592136.4730000873}))
-                   .margin(0.01));
+    REQUIRE_THAT(
+      real_ods_sink.m_areaList,
+      Catch::Matchers::Approx(std::vector<double>({453563.5099999703,
+                                                   4719046.3000000007,
+                                                   1090639.7850001103,
+                                                   1348880.5900000208,
+                                                   7630963.3250000998,
+                                                   779452.6100000609,
+                                                   2040112.6650001134,
+                                                   5756570.0800003475,
+                                                   8225201.0500001209,
+                                                   105329906.8750005662,
+                                                   0.0,
+                                                   647415.2500000162,
+                                                   421852.445000008,
+                                                   10305033.5250001848,
+                                                   3621950.2699998645,
+                                                   544684.8950001382,
+                                                   37944845.6299999952,
+                                                   3698171.8149995869,
+                                                   5664123.3300000867,
+                                                   420474.2849998939,
+                                                   1008899.3299999861,
+                                                   805031.2899999407,
+                                                   335121.1350001062,
+                                                   338425.5199998079,
+                                                   340164.8050002141,
+                                                   12118740.7800003588,
+                                                   1643557.1449998224,
+                                                   488535.5099999903,
+                                                   3979415.1600000304,
+                                                   337714.1250001371,
+                                                   1028555.1399998174,
+                                                   905212.215000038,
+                                                   256353.7100000874,
+                                                   273830.9199999579,
+                                                   10611321.4649997819,
+                                                   18939923.7850016505,
+                                                   571598.5350001995,
+                                                   2796306.4700002563,
+                                                   39837543.8999998271,
+                                                   3572057.4000001787,
+                                                   2218517.9099999457,
+                                                   2539285.7649998385,
+                                                   881227.1150000142,
+                                                   726500.5700001301,
+                                                   17818048.1899999045,
+                                                   571815.7450000376,
+                                                   2592136.4730000873}))
+        .margin(0.01));
 
     TracePeakOdsWriterSink real_detect_moulonods_sink;
 
@@ -430,7 +430,7 @@ TEST_CASE("XIC test suite.", "[XIC]")
     qDebug();
     REQUIRE_THAT(
       real_detect_moulonods_sink.m_beginList,
-      Catch::Approx(
+      Catch::Matchers::Approx(
         std::vector<double>(
           {2379.83, 2385.1,  2402.82, 2491.04, 2495.16, 2652.79, 2733.2,
            3262.35, 3276.04, 3755.51, 3807.81, 3814.14, 4103.81, 4152.75,
@@ -442,7 +442,7 @@ TEST_CASE("XIC test suite.", "[XIC]")
         .margin(0.00001));
     REQUIRE_THAT(
       real_detect_moulonods_sink.m_areaList,
-      Catch::Approx(
+      Catch::Matchers::Approx(
         std::vector<double>(
           {350636.0699999726,    4719046.3000000007, 1199928.0000002729,
            232712.6200000431,    857927.1650000673,  1229759.8900000337,
@@ -613,17 +613,17 @@ TEST_CASE("test operations on tracepeaklist", "[tracepeaklist]")
     TracePeak peak(
       xicprm_test.begin() + 9079, xicprm_test.begin() + 9142, false);
 
-    REQUIRE(peak.getArea() == Approx(96163224.06));
+    REQUIRE(peak.getArea() == Catch::Approx(96163224.06));
 
     TracePeak peak_nobase(
       xicprm_test.begin() + 9079, xicprm_test.begin() + 9142, true);
 
-    REQUIRE(peak_nobase.getArea() == Approx(76281621.60));
+    REQUIRE(peak_nobase.getArea() == Catch::Approx(76281621.60));
 
     REQUIRE(
       peak_nobase.getLeftBoundary().y *
         (peak_nobase.getRightBoundary().x - peak_nobase.getLeftBoundary().x) ==
-      Approx(peak.getArea() - peak_nobase.getArea()));
+      Catch::Approx(peak.getArea() - peak_nobase.getArea()));
 
     INFO("readOdsXic OK");
     REQUIRE_NOTHROW(_zivy.detect(xicprm_test, peak_list, true));
@@ -634,7 +634,7 @@ TEST_CASE("test operations on tracepeaklist", "[tracepeaklist]")
             peak_list.end());
 
     REQUIRE(findTracePeakGivenRt(peak_list.begin(), peak_list.end(), 2380)
-              ->getArea() == Approx(453563.50999997));
+              ->getArea() == Catch::Approx(453563.50999997));
 
 
     REQUIRE(findTracePeakGivenRt(peak_list.begin(), peak_list.end(), 4754) ==
@@ -645,12 +645,12 @@ TEST_CASE("test operations on tracepeaklist", "[tracepeaklist]")
     std::size_t nb_match;
     REQUIRE(findBestTracePeakGivenRtList(
               peak_list.begin(), peak_list.end(), {4754, 4760, 4761}, nb_match)
-              ->getArea() == Approx(3698171.81499959));
+              ->getArea() == Catch::Approx(3698171.81499959));
     REQUIRE(nb_match == 1);
     REQUIRE(
       findBestTracePeakGivenRtList(
         peak_list.begin(), peak_list.end(), {4754, 4760, 4761, 5000}, nb_match)
-        ->getArea() == Approx(5664123.33000009));
+        ->getArea() == Catch::Approx(5664123.33000009));
     REQUIRE(nb_match == 2);
     REQUIRE(findBestTracePeakGivenRtList(
               peak_list.begin(), peak_list.end(), {4754, 5460}, nb_match) ==
