@@ -24,12 +24,7 @@
 
 //./tests/catch2-only-tests [XICextractor] -s
 
-#ifdef CATCH2_MAJOR_VERSION_2
-#include <catch2/catch.hpp>
-#elif CATCH2_MAJOR_VERSION_3
-#include <catch2/catch_all.hpp>
-using namespace Catch;
-#endif
+#include <catch2/catch_test_macros.hpp>
 
 #include <iostream>
 #include <odsstream/odsdocreader.h>
@@ -114,8 +109,8 @@ TEST_CASE("XIC extractor test suite.", "[XICextractor]")
       pappso::MsRunXicExtractorFactory::getInstance().buildMsRunXicExtractorSp(
         msrun);
     std::cout << std::endl
-         << "XicExtractorDiskSp built " << timer.elapsed() / 1000 << " seconds"
-         << std::endl;
+              << "XicExtractorDiskSp built " << timer.elapsed() / 1000
+              << " seconds" << std::endl;
 
 
     xic_coord_list.clear();
@@ -126,10 +121,12 @@ TEST_CASE("XIC extractor test suite.", "[XICextractor]")
 
     REQUIRE(*xic_pwiz == *xic_disk);
 
-    std::cout << std::endl << "..:: XIC extractor on disk is OK ::.." << std::endl;
+    std::cout << std::endl
+              << "..:: XIC extractor on disk is OK ::.." << std::endl;
     // return 0;
 
-    std::cout << std::endl << "building XicExtractorDiskBufferSp .." << std::endl;
+    std::cout << std::endl
+              << "building XicExtractorDiskBufferSp .." << std::endl;
     timer.restart();
 
     pappso::MsRunXicExtractorFactory::getInstance()
@@ -139,8 +136,8 @@ TEST_CASE("XIC extractor test suite.", "[XICextractor]")
       pappso::MsRunXicExtractorFactory::getInstance().buildMsRunXicExtractorSp(
         msrun);
     std::cout << std::endl
-         << "XicExtractorDiskBufferSp built " << timer.elapsed() / 1000
-         << " seconds" << std::endl;
+              << "XicExtractorDiskBufferSp built " << timer.elapsed() / 1000
+              << " seconds" << std::endl;
 
 
     xic_coord_list.clear();
@@ -153,7 +150,7 @@ TEST_CASE("XIC extractor test suite.", "[XICextractor]")
     REQUIRE(*xic_pwiz == *xic_buffer);
 
     std::cout << std::endl
-         << "..:: XIC extractor buffered on disk is OK ::.." << std::endl;
+              << "..:: XIC extractor buffered on disk is OK ::.." << std::endl;
 #endif
   }
 }
